<?php
namespace SEOQCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
Use \Elementor\Core\Schemes\Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_About extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
			'seoq_left_side',
			[
				'label' => esc_html__( 'Left Side Content', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->add_control(
            'seoq_shape_img',
            [
                'label' => esc_html__( 'Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_side_text',
            [
                'label' => esc_html__('Left Side Text', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('ABOUT Us', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Choose Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_image_animation',
            [
                'label' => esc_html__( 'Choose Image Animation', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->end_controls_section();

        // seoq_section_title
        $this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__('Title & Content', 'seoq-core'),
            ]
        );
        
        $this->add_control(
            'seoq_subheading',
            [
                'label' => esc_html__('Subheading', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('About Us', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );       
        
        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('We Have 25 Years Of Experience In This Field', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        ); 
        
        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'seoq_description',
            [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('will reenergize your ome and enhance your life. From everyday housekeeping to routine cleanings, our professional this to members can provide you.', 'seoq-core'),
                'placeholder' => esc_html__('Type section description here', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->end_controls_section();

        // Features group
        $this->start_controls_section(
            'seoq_features',
            [
                'label' => esc_html__('Features List', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => 'layout-2',
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
			'seoq_features_image',
			[
				'label' => esc_html__( 'Choose Image', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

        $repeater->add_control(
            'seoq_features_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Service Title', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_features_description', [
                'label' => esc_html__('Description', 'seoq-core'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Service Title', 'seoq-core'),
                'label_block' => true,
            ]
        );
     
        $this->add_control(
            'seoq_features_list',
            [
                'label' => esc_html__('Services - List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_features_title' => esc_html__('We provide janitorial and specialized is services.', 'seoq-core'),
                    ],
                    [
                        'seoq_features_title' => esc_html__('Tonstantly evolving and your brand must evolve.', 'seoq-core')
                    ],
                    [
                        'seoq_features_title' => esc_html__('Tempor incididunt ut labore dolore magna aliqua.', 'seoq-core')
                    ]
                ],
                'title_field' => '{{{ seoq_features_title }}}',
            ]
        );
        $this->end_controls_section();

        // fun-fact

        $this->start_controls_section(
            'seoq_fun_fact',
            [
                'label' => esc_html__('Fun Fact', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );
        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_funfact_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => esc_html__('13', 'seoq-core'),
            ]
        );  

        $repeater->add_control(
			'seoq_funfact_sign',
			[
				'label' => esc_html__( 'Sign', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '+', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your sign here', 'seoq-core' ),
			]
		);

        $repeater->add_control(
			'seoq_funfact_description',
			[
				'label' => esc_html__( 'Description', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'YEAR OF EXPERIENCES', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'seoq-core' ),
                'label_block' => true,
			]
		);
        
        $this->add_control(
            'seoq_funfact_list',
            [
                'label' => esc_html__('Funfact', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_features_title' => esc_html__('13', 'seoq-core'),
                        'seoq_funfact_sign' => esc_html__('+', 'seoq-core'),
                        'seoq_funfact_description' => esc_html__('YEAR OF EXPERIENCES', 'seoq-core'),
                    ],
                    [
                        'seoq_features_title' => esc_html__('Tonstantly evolving and your brand must evolve.', 'seoq-core'),
                        'seoq_funfact_sign' => esc_html__('K+', 'seoq-core'),
                        'seoq_funfact_description' => esc_html__('SATISFIED CUSTOMERS', 'seoq-core'),
                    ],
                ],
                'title_field' => '{{{ seoq_funfact_title }}}',
            ]
        );

        $this->end_controls_section();

        // Style tab
		$this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'content_options',
            [
                'label' => esc_html__( 'Content Options', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .about-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .about-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
					'top' => 120,
					'right' => 0,
					'bottom' => 120,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false,
				],
            ]
        );

        $this->add_control(
            'content_background_color',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-one' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .about-two' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_title_style',
			[
				'label' => __( 'Title & Content', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        // Title
        $this->add_control(
            '_subheading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subheading', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_responsive_control(
            'subheading_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content span' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_control(
            'subheading_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subheading_typography',
                'selector' => '{{WRAPPER}} .about-one .about-one__right .about-one__right-content span',
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content .section-title__one-title' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .about-two .about-two__content .about-two__title' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
                'default' => [
					'unit' => 'px',
					'size' => 60,
				],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content .section-title__one-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .about-two .about-two__content .about-two__title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .about-one .about-one__right .about-one__right-content .section-title__one-title, .about-two .about-two__content .about-two__title',
            ]
        );

        // Description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .about-one__right-content p' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .about-one .about-one__right .about-one__right-content p',
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'seoq_features_list_style',
			[
				'label' => __( 'Features List', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'seoq_design_style' => 'layout-2',
                ],
			]
		);

        $this->add_responsive_control(
            'feature_box_padding',
            [
                'label' => __( 'Box Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .about-two .about-two__info-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
					'top' => 30,
					'right' => 40,
					'bottom' => 30,
					'left' => 40,
					'unit' => 'px',
					'isLinked' => false,
				],
            ]
        );

        $this->add_control(
			'features_list_title',
			[
				'label' => esc_html__( 'Feature Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
			]
		);

        $this->add_responsive_control(
            'features_list_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .about-two .about-two__info-box h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'default' => [
					'unit' => 'px',
					'size' => 10,
				],
            ]
        );

        $this->add_control(
            'features_list_title_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-two .about-two__info-box h4' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'features_list_title_typography',
                'selector' => '{{WRAPPER}} .about-two .about-two__info-box h4',
            ]
        );

        $this->add_control(
			'features_list_description',
			[
				'label' => esc_html__( 'Description', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
            'features_list_description_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-two .about-two__info-box .text p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'features_list_description_typography',
                'selector' => '{{WRAPPER}} .about-two .about-two__info-box .text p',
            ]
        );

		$this->end_controls_section();


        // Fun Fact Style
        $this->start_controls_section(
			'seoq_funfact_list_style',
			[
				'label' => __( 'Fun Fact', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
			]
		);

        $this->add_control(
            'seoq_funfact_title_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .text-box .counter' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .about-one .about-one__right .counter-two__single span' => 'color: {{VALUE}}',
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'seoq_funfact_title_typography',
                'selector' => '{{WRAPPER}} .text-box .counter, .about-one .about-one__right .counter-two__single span',
            ]
        );

        $this->add_control(
			'seoq_funfact_des',
			[
				'label' => esc_html__( 'Description', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
            'seoq_funfact_des_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-one .about-one__right .counter-two__text' => 'color: {{VALUE}}',
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'seoq_funfact_des_typography',
                'selector' => '{{WRAPPER}} .about-one .about-one__right .counter-two__text',
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        $this->add_render_attribute('title_args', 'class', 'section-title__one-title');
        $this->add_render_attribute('title_args2', 'class', 'about-two__title');

		?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
            <!-- about one start -->
            <div class="about-one">
                <?php if(!empty($settings['seoq_side_text'])): ?>
                    <div class="about-one__animation_text">
                        <h2><?php echo rrdevs_kses($settings['seoq_side_text']);?></h2>
                    </div>
                <?php endif; ?>
                <?php if ( !empty($settings['seoq_shape_img']) ) : ?>
                    <div class="about-one_animation1">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/1.svg" alt="shape">
                    </div>
                    <div class="about-one_animation2">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/2.svg" alt="shape">
                    </div>
                    <div class="about-one_animation3">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/3.svg" alt="shape">
                    </div>
                    <div class="about-one_animation4">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/4.svg" alt="shape">
                    </div>
                <?php endif; ?>
                <div class="about-one_circle1"></div>
                <div class="about-one_circle2"></div>
                <div class="about-one_circle3"></div>
                <div class="page-header__bg" data-background="<?php echo get_template_directory_uri(); ?>/assets/img/about/about-bg-1.png"></div>
                <div class="about-one__animation_3"></div>
                <div class="container">
                    <div class="row align-items-end">
                        <div class="col-xxl-6 col-xl-6 col-lg-6 wow fadeInLeft" data-wow-delay=".3s">
                            <div class="about-one__img">
                                <?php if(!empty($settings['seoq_image']['url'])): ?>
                                    <img src="<?php echo $settings['seoq_image']['url']; ?>" alt="<?php echo $settings['seoq_image']['alt']; ?>">
                                <?php endif; ?>
                                <?php if(!empty($settings['seoq_image_animation']['url'])): ?>
                                    <div class="about-one__img2">
                                        <img src="<?php echo $settings['seoq_image_animation']['url']; ?>" alt="<?php echo $settings['seoq_image_animation']['alt']; ?>">
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="col-xxl-6 col-xl-6 col-lg-6">
                            <div class="about-one__right wow fadeInUp" data-wow-delay=".5s">
                                <div class="about-one__right-content">
                                    <?php if(!empty($settings['seoq_subheading'])): ?>
                                        <span><?php echo $settings['seoq_subheading']; ?></span>
                                    <?php endif; ?>

                                    <?php
                                        if ( !empty($settings['seoq_title' ]) ) :
                                            printf( '<%1$s %2$s>%3$s</%1$s>',
                                                tag_escape( $settings['seoq_title_tag'] ),
                                                $this->get_render_attribute_string( 'title_args' ),
                                                rrdevs_kses( $settings['seoq_title' ] )
                                                );
                                        endif;
                                    ?>

                                    <?php if(!empty($settings['seoq_description'])): ?>
                                        <p><?php echo $settings['seoq_description']; ?></p>
                                    <?php endif; ?>
                                </div>
                                <div class="about-one__counter">
                                    <div class="row">
                                        <?php 
                                            if($settings['seoq_funfact_list']):
                                                foreach ($settings['seoq_funfact_list'] as $index => $item) :
                                        ?>
                                            <div class="col-xxl-5 col-xl-5 col-lg-5 col-md-6 col-sm-6">
                                                <div class="counter-two__single">
                                                    <div class="counter-two__single-inner">
                                                        <div class="text-box">
                                                            <?php if(!empty($item['seoq_funfact_title'])): ?>
                                                                <h3 class="counter"><?php echo rrdevs_kses($item['seoq_funfact_title']); ?></h3>
                                                            <?php endif; ?>
                                                            <?php if(!empty($item['seoq_funfact_sign'])): ?>
                                                                <span class="counter-two__letter"><?php echo rrdevs_kses($item['seoq_funfact_sign']); ?></span>
                                                            <?php endif; ?>
                                                            <?php if(!empty($item['seoq_funfact_description'])): ?>
                                                                <p class="counter-two__text"><?php echo rrdevs_kses($item['seoq_funfact_description']); ?></p>
                                                            <?php endif; ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach; endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- about one end -->
        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>
            <!-- about two start -->
            <div class="about-two">
                <div class="about-two__wrapper position-relative">
                    <?php if ( !empty($settings['seoq_shape_img']) ) : ?>
                        <div class="about-two-img-animation2">
                            <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/2.svg" alt="shape">
                        </div>
                        <div class="about-two-img-animation3">
                            <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/1.svg" alt="shape">
                        </div>
                        <div class="about-two-img-animation4">
                            <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/3.svg" alt="shape">
                        </div>
                    <?php endif; ?>
                    <div class="container">
                        <div class="row">
                            <div class="col-xxl-6 col-xl-6 col-lg-6">
                                <div class="about-two__content">
                                    <?php
                                        if ( !empty($settings['seoq_title' ]) ) :
                                            printf( '<%1$s %2$s>%3$s</%1$s>',
                                                tag_escape( $settings['seoq_title_tag'] ),
                                                $this->get_render_attribute_string( 'title_args2' ),
                                                rrdevs_kses( $settings['seoq_title' ] )
                                                );
                                        endif;
                                    ?>
                                    <div class="about-two__info-list">
                                        <?php 
                                            if($settings['seoq_features_list']):
                                                foreach ($settings['seoq_features_list'] as $index => $item) :
                                        ?>
                                            <div class="about-two__info-box mb-20 wow fadeInUp" data-wow-delay=".3s">
                                                    <div class="img">
                                                        <?php if(!empty($item['seoq_features_image']['url'])): ?>
                                                            <img src="<?php echo $item['seoq_features_image']['url']; ?>" >
                                                        <?php endif; ?>
                                                    </div>
                                                
                                                <div class="text">
                                                    <?php if(!empty($item['seoq_features_title'])): ?>
                                                        <h4><?php echo rrdevs_kses($item['seoq_features_title']); ?></h4>
                                                    <?php endif; ?>
                                                    <?php if(!empty($item['seoq_features_description'])): ?>
                                                        <p><?php echo rrdevs_kses($item['seoq_features_description']); ?></p>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        <?php endforeach; endif; ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-xxl-6 col-xl-6 col-lg-6">
                                <div class="about-two__img text-end wow fadeInRight" data-wow-delay=".5s">
                                    <div class="about-two__img-animation1">
                                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/star.svg" alt="star shape">
                                    </div>
                                    <?php if(!empty($settings['seoq_image']['url'])): ?>
                                        <img src="<?php echo $settings['seoq_image']['url']; ?>" alt="<?php echo $settings['seoq_image']['alt']; ?>">
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- about two end -->
        <?php 
            endif;
	}
}

$widgets_manager->register( new seoq_About() );