<?php
namespace SEOQCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Advanced_Tab extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_advanced_tab';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Advanced Tab', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
            '_section_price_tabs',
            [
                'label' => __('Advanced Tabs', 'seoq-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

		$this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => __('Title', 'seoq-core'),
                'default' => __('Tab Title', 'seoq-core'),
                'placeholder' => __('Type Tab Title', 'seoq-core'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'active_tab',
            [
                'label' => __('Is Active Tab?', 'seoq-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'seoq-core'),
                'label_off' => __('No', 'seoq-core'),
                'return_value' => 'yes',
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

		$repeater->add_control(
			'icon_switcher',
			[
				'label' => esc_html__( 'Image Type', 'seoq-core' ),
				'description' => esc_html__( 'Icon options are available for layout 2', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'image' => esc_html__( 'Image', 'seoq-core' ),
					'icon' => esc_html__( 'Icon', 'seoq-core' ),
				],
			]
		);

        $repeater->add_control(
            'advanced_tab_image',
            [
                'label' => esc_html__('Upload Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'icon_switcher' => 'image',
                ],
            ]
        );

        $repeater->add_control(
            'advanced_tab_image_white',
            [
                'label' => esc_html__('Upload Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'icon_switcher' => 'image',
                ],
            ]
        );

        if (seoq_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'advanced_tab_icon',
                [
                    'label' => esc_html__('Icon', 'seoq-core'),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'icon-house',
                    'condition' => [
                        'icon_switcher' => 'icon',
                    ],
                ]
            );
        } else {
            $repeater->add_control(
                'advanced_tab_selected_icon',
                [
                    'label' => esc_html__('Icon', 'seoq-core'),
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'icon-house',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'icon_switcher' => 'icon',
                    ],
                ]
            );
        }

        $repeater->add_control(
            'template',
            [
                'label' => __('Section Template', 'seoq-core'),
                'placeholder' => __('Select a section template for as tab content', 'seoq-core'),
  
                'type' => Controls_Manager::SELECT2,
                'options' => get_elementor_templates()
            ]
        );

        $this->add_control(
            'tabs',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{title}}',
                'default' => [
                    [
                        'title' => 'Tab 1',
                    ],
                    [
                        'title' => 'Tab 2',
                    ]
                ]
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
            'content_align',
            [
                'label' => esc_html__('Alignment', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'seoq-core'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'seoq-core'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'seoq-core'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .tab-one__tabs' => 'text-align: {{VALUE}};',
				],
				'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->add_control(
			'content_border_color',
			[
				'label' => esc_html__( 'Border Color', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one li.nav-item' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_border_right_color',
			[
				'label' => esc_html__( 'Border Color', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tabs-one li.nav-item:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
			]
		);

		$this->start_controls_tabs( '_advanced_tabs' );
		
		$this->start_controls_tab(
			'advanced_tab_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'seoq-core' ),
			]
		);
		
		$this->add_control(
			'advanced_tab_color',
			[
				'label' => esc_html__( 'Color', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li' => 'color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'advanced_tab_background',
			[
				'label' => esc_html__( 'Background', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link' => 'background-color: {{VALUE}}',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'advanced_tab_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'seoq-core' ),
			]
		);
		
		$this->add_control(
			'advanced_tab_color_hover',
			[
				'label' => esc_html__( 'Color', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link:hover' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'advanced_tab_background_hover',
			[
				'label' => esc_html__( 'Background', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link:hover' => 'background-color: {{VALUE}}',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'advanced_tab_active_tab',
			[
				'label' => esc_html__( 'Active', 'seoq-core' ),
			]
		);
		
		$this->add_control(
			'advanced_tab_color_active',
			[
				'label' => esc_html__( 'Color', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li.active-btn' => 'color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link.active' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'advanced_tab_background_active',
			[
				'label' => esc_html__( 'Background', 'seoq-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tab-one__tabs .tab-buttons li.active-btn' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .tabs-one .nav-link.active' => 'background-color: {{VALUE}}',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>

		<?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>

			<div class="tab-one__tabs tabs-box">
                <ul class="tab-buttons clearfix">
                    <?php foreach ($settings['tabs'] as $key => $tab):
                        $active = ($key == 0) ? 'active-btn' : '';
                    ?>
                        <li data-tab="#<?php echo esc_attr($key); ?>" class="tab-btn <?php echo esc_attr($active); ?>"><span><?php echo rrdevs_kses($tab['title']); ?></span></li>
	                <?php endforeach; ?>
                </ul>
                <div class="tabs-content">
                    <?php foreach ($settings['tabs'] as $key => $tab):
                        $active = ($key == 0) ? 'active-tab' : '';
                    ?>
	                <div class="tab <?php echo esc_attr($active); ?>" id="<?php echo esc_attr($key); ?>">
                        <?php echo \Elementor\Plugin::instance()->frontend->get_builder_content($tab['template'], true); ?>
                    </div>
	                <?php endforeach; ?>
                </div>
            </div>
		
		<?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>

			<div class="about-three">
				<div class="container custom-container-1">
					<div class="row g-0">
						<div class="about-three__wrapper">
							<div class="col-xxl-12">
								<div class="tabs-one">
									<ul class="nav nav-pills" id="pills-tab" role="tablist">
										<?php foreach ($settings['tabs'] as $key => $tab):
											$active = ($key == 0) ? 'active' : '';
										?>
										<li class="nav-item" role="presentation">
											<button class="nav-link <?php echo esc_attr($active); ?>" id="pills-home-tab-<?php echo esc_attr($key); ?>" data-bs-toggle="pill" data-bs-target="#pills-<?php echo esc_attr($key); ?>" type="button" role="tab" aria-controls="pills-<?php echo esc_attr($key); ?>" aria-selected="true">
												<?php if (!empty($tab['advanced_tab_image']['url'])): ?>
													<img src="<?php echo $tab['advanced_tab_image']['url']; ?>" class="no-active" alt="<?php echo get_post_meta(attachment_url_to_postid($tab['advanced_tab_image']['url']), '_wp_attachment_image_alt', true); ?>">
													<img src="<?php echo $tab['advanced_tab_image_white']['url']; ?>" class="active-tab-icon" alt="<?php echo get_post_meta(attachment_url_to_postid($tab['advanced_tab_image_white']['url']), '_wp_attachment_image_alt', true); ?>">
												<?php endif; ?>
												<?php if (!empty($tab['advanced_tab_icon']) || !empty($tab['advanced_tab_selected_icon']['value'])) : ?>
													<?php seoq_render_icon($tab, 'advanced_tab_icon', 'advanced_tab_selected_icon'); ?>
												<?php endif; ?>
												<span><?php echo rrdevs_kses($tab['title']); ?></span>
											</button>
										</li>
										<?php endforeach; ?>
									</ul>
									<div class="tab-content" id="pills-tabContent">
										<?php foreach ($settings['tabs'] as $key => $tab):
											$active = ($key == 0) ? 'show active' : '';
										?>
											<div class="tab-pane fade <?php echo esc_attr($active); ?>" id="pills-<?php echo esc_attr($key); ?>" role="tabpanel" aria-labelledby="pills-home-tab-<?php echo esc_attr($key); ?>">
												<?php echo \Elementor\Plugin::instance()->frontend->get_builder_content($tab['template'], true); ?>
											</div>
										<?php endforeach; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		
		<?php endif; ?>

            

		<?php
	}

}
$widgets_manager->register( new SEOQ_Advanced_Tab() );