<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Case_Study_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_case_study_slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Case Study Slider', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__('Title & Content', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => __('The Power of Optimization <br> SEO Case Studies.', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_case_study',
            [
                'label' => esc_html__('Case Slide List', 'seoq-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );                      

        $repeater->add_control(
            'logo',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );   
        
        $repeater->add_control(
            'title_main',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'Heading', 'seoq-core' ),
                'default' => __( 'How Visme Facilitates Communication between Insurance Marketers and Business Experts', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'Title', 'seoq-core' ),
                'default' => __( 'Photo Retouching', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'title_two',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'Title Two', 'seoq-core' ),
                'default' => __( 'Photo Retouching', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'subtitle',
            [
                'label' => __( 'Subtitle', 'seoq-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'show_label' => true,
                'default' => __( 'Digital Design', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'subtitle_two',
            [
                'label' => __( 'Subtitle', 'seoq-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'show_label' => true,
                'default' => __( 'Digital Design', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'seoq_link_switcher',
            [
                'label' => esc_html__( 'Add link', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'seoq_link_text',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('View Case Study', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_link_switcher' => 'yes'
                ]
            ]
        );

        $repeater->add_control(
            'seoq_link_type',
            [
                'label' => esc_html__( 'Link Type', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'condition' => [
                    'seoq_link_switcher' => 'yes'
                ]
            ]
        );

        $repeater->add_control(
            'seoq_link',
            [
                'label' => esc_html__( 'Link', 'seoq-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'seoq-core' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'seoq_link_type' => '1',
                    'seoq_link_switcher' => 'yes',
                ]
            ]
        );

        $repeater->add_control(
            'seoq_page_link',
            [
                'label' => esc_html__( 'Select Page Link', 'seoq-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_link_type' => '2',
                    'seoq_link_switcher' => 'yes',
                ]
            ]
        );

        // REPEATER
        $this->add_control(
            'case_study_list',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'How Visme Facilitates Communication between Insurance Marketers and Business Experts.', 'seoq-core' ),
                        'title' => esc_html__( '2nd Position', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Donec tempus scelerisque malasada Nunc effector protium Bibendum.', 'seoq-core' ),
                        'title_two' => esc_html__( '2587', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Greatly hearted has who believe green son walls years for blush.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '2nd Position', 'seoq-core' ),
                        'subtitle' => esc_html__( 'drawings repeated recurred exercise laughing may you but.', 'seoq-core' ),
                        'title_two' => esc_html__( '300%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Do repeated whatever to welcomed absolute surprise although outlived.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '5487', 'seoq-core' ),
                        'subtitle' => esc_html__( 'How Visme Transforms Insurance Marketing and Business Coordination.', 'seoq-core' ),
                        'title_two' => esc_html__( '1000%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Musical by me through he drawing savings an. No we stand avoid.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '9887', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Civilly why how end viewing attempt related enquire visitor.', 'seoq-core' ),
                        'title_two' => esc_html__( '150%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Particular insensible celebrated conviction stimulated principles day.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '9009', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Simple innate summer fat appear basket his desire joy.', 'seoq-core' ),
                        'title_two' => esc_html__( '180%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Sufficient particular impossible by reasonable oh expression is.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'How Visme Facilitates Communication between Insurance Marketers and Business Experts.', 'seoq-core' ),
                        'title' => esc_html__( '2nd Position', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Donec tempus scelerisque malasada Nunc effector protium Bibendum.', 'seoq-core' ),
                        'title_two' => esc_html__( '2587', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Greatly hearted has who believe green son walls years for blush.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '2nd Position', 'seoq-core' ),
                        'subtitle' => esc_html__( 'drawings repeated recurred exercise laughing may you but.', 'seoq-core' ),
                        'title_two' => esc_html__( '300%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Do repeated whatever to welcomed absolute surprise although outlived.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'How Visme Facilitates Communication between Insurance Marketers and Business Experts.', 'seoq-core' ),
                        'title' => esc_html__( '5487', 'seoq-core' ),
                        'subtitle' => esc_html__( 'How Visme Transforms Insurance Marketing and Business Coordination.', 'seoq-core' ),
                        'title_two' => esc_html__( '1000%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Musical by me through he drawing savings an. No we stand avoid.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'Bridging the Marketing and Business Divide How an Insurance Company Leverages Visme.', 'seoq-core' ),
                        'title' => esc_html__( '9887', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Civilly why how end viewing attempt related enquire visitor.', 'seoq-core' ),
                        'title_two' => esc_html__( '150%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Particular insensible celebrated conviction stimulated principles day.', 'seoq-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title_main' => esc_html__( 'How Visme Facilitates Communication between Insurance Marketers and Business Experts.', 'seoq-core' ),
                        'title' => esc_html__( '9009', 'seoq-core' ),
                        'subtitle' => esc_html__( 'Simple innate summer fat appear basket his desire joy.', 'seoq-core' ),
                        'title_two' => esc_html__( '180%', 'seoq-core' ),
                        'subtitle_two' => esc_html__( 'Sufficient particular impossible by reasonable oh expression is.', 'seoq-core' ),
                    ],
                ]
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'section_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .case-study-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
            'content_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-one' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .case-study-one:before',
			]
		);

        $this->add_control(
            '_arrows_heading',
            [
                'label' => esc_html__( 'Arrows', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->start_controls_tabs( '_arrow_tabs' );
        
        $this->start_controls_tab(
            'arrow_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two .owl-prev' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-two .owl-next' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two .owl-prev' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-two .owl-next' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'arrow_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );
        
        $this->add_control(
            'arrow_color_hover',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two .owl-prev:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-two .owl-next:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_background_hover',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two .owl-prev:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-two .owl-next:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->add_control(
            'content_dots_border',
            [
                'label' => __( 'Line Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .rr-scrollbar .swiper-scrollbar-drag' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );
        
        $this->add_control(
            'content_dots_background',
            [
                'label' => __( 'Line Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .rr-scrollbar' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
            '_section_style_content',
            [
                'label' => __( 'Title & Content', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // SubTitle
        $this->add_control(
            '_heading_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subtitle', 'seoq-core' ),
                'separator' => 'after',
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'subtitle_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_control(
            'subtitle_border_color',
            [
                'label' => __( 'Border Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span:before' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .case-study-two__single-box span',
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .section-title__one-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .section-title__one-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .case-study-two__single-box h4, .section-title__one-title',
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'section_case_study_style',
			[
				'label' => __( 'Case Slide List', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        // Content
        $this->add_control(
            '_heading_content_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'case_study_title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-one__single .header .content h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .case-study-two__single-box h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
            'case_study_title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one__single .header .content h2' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .case-study-two__single-box h4' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'case_study_title_typography',
                'selector' => '{{WRAPPER}} .case-study-one__single .header .content h2, .case-study-two__single-box h4',
            ]
        );

        $this->add_control(
            '_heading_content_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subtitle', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'case_study_subtitle_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
            'case_study_subtitle_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'case_study_subtitle_typography',
                'selector' => '{{WRAPPER}} .case-study-two__single-box span',
            ]
        );

		$this->add_control(
            'case_study_content_background',
            [
                'label' => __( 'Border Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-two__single-box span:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            '_slider_box_layout_heading',
            [
                'label' => esc_html__( 'Box Layout', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'slider_box_layout_spacing',
            [
                'label' => __( 'Title Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left h3' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->add_control(
            'slider_box_layout_color',
            [
                'label' => __( 'Title Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left h3' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_box_layout_typography',
                'selector' => '{{WRAPPER}} .case-study-one .footer__left h3',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'slider_box_layout_subtitle_spacing',
            [
                'label' => __( 'Subtitle Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->add_control(
            'slider_box_layout_subtitle_color',
            [
                'label' => __( 'Subtitle Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left p' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_box_layout_subtitle_typography',
                'selector' => '{{WRAPPER}} .case-study-one .footer__left p',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->add_control(
            'slider_box_layout_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'slider_box_layout_border_radius',
            [
                'label' => __( 'Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .case-study-one .footer__left' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_control(
            '_slider_layout_heading',
            [
                'label' => esc_html__( 'Layout', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->add_control(
            'slider_layout_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .case-study-one__single' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'slider_layout_border_radius',
            [
                'label' => __( 'Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .case-study-one__single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $this->add_render_attribute('title_args', 'class', 'section-title__one-title');
        if ( !empty($settings['seoq_team_img_bg']['url']) ) {
            $seoq_team_img_bg = !empty($settings['seoq_team_img_bg']['id']) ? wp_get_attachment_image_url( $settings['seoq_team_img_bg']['id'], 'full' ) : $settings['seoq_team_img_bg']['url'];
        }

		?>

            <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>

                <div class="case-study-one pt-110 pb-140">
                    <div class="case-study-one__color-effect1"></div>
                    <div class="case-study-one__color-effect2"></div>
                    <div class="container">
                        <div class="row">
                            <div class="col-xl-12">
                                <?php
                                    if ( !empty($settings['seoq_title' ]) ) :
                                        printf( '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape( $settings['seoq_title_tag'] ),
                                            $this->get_render_attribute_string( 'title_args' ),
                                            rrdevs_kses( $settings['seoq_title' ] )
                                            );
                                    endif;
                                ?>
                            </div>
                        </div>
                    </div>
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-xxl-12 wow fadeInUp" data-wow-delay=".3s">
                                <div class="has-scrollbar position-relative">
                                    <div class="case-study-one__active swiper-container">
                                        <div class="swiper-wrapper">
                                            <?php foreach ( $settings['case_study_list'] as $item ) :
                                                if ( !empty($item['image']['url']) ) {
                                                    $seoq_case_study_image_url = !empty($item['image']['id']) ? wp_get_attachment_image_url( $item['image']['id'], 'full') : $item['image']['url'];
                                                    $seoq_case_study_image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                                                    $seoq_case_study_logo = !empty($item['logo']['id']) ? wp_get_attachment_image_url( $item['logo']['id'], 'full') : $item['logo']['url'];
                                                    $seoq_case_study_logo_alt = get_post_meta($item["logo"]["id"], "_wp_attachment_image_alt", true);
                                                } 
                                                // Link
                                                if ('2' == $item['seoq_link_type']) {
                                                    $link = get_permalink($item['seoq_page_link']);
                                                    $target = '_self';
                                                    $rel = 'nofollow';
                                                } else {
                                                    $link = !empty($item['seoq_link']['url']) ? $item['seoq_link']['url'] : '';
                                                    $target = !empty($item['seoq_link']['is_external']) ? '_blank' : '';
                                                    $rel = !empty($item['seoq_link']['nofollow']) ? 'nofollow' : '';
                                                }           
                                            ?>
                                            <div class="case-study-one__single swiper-slide wow fadeInUp" data-wow-delay=".3s">
                                                <div class="header">
                                                    <div class="img">
                                                        <img src="<?php echo esc_url($seoq_case_study_image_url); ?>" alt="<?php echo esc_attr($seoq_case_study_image_alt); ?>">
                                                    </div>
                                                    <div class="content">
                                                        <img src="<?php echo esc_url($seoq_case_study_logo); ?>" alt="<?php echo esc_attr($seoq_case_study_logo_alt); ?>">
                                                        <h2>
                                                            <a target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($rel); ?>" href="<?php echo esc_url($link); ?>">
                                                                <?php echo $item['title_main']; ?>
                                                            </a>
                                                        </h2>
                                                    </div>
                                                </div>
                                                <div class="footer">
                                                    <div class="footer__left">
                                                        <h3><?php echo rrdevs_kses( $item['title'] ); ?></h3>
                                                        <p><?php echo rrdevs_kses( $item['subtitle'] ); ?></p>
                                                    </div>
                                                    <div class="footer__left">
                                                        <h3><?php echo rrdevs_kses( $item['title_two'] ); ?></h3>
                                                        <p><?php echo rrdevs_kses( $item['subtitle_two'] ); ?></p>
                                                    </div>
                                                </div>
                                            </div>
                                            <?php endforeach; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="rr-scrollbar mt-70 wow fadeInUp" data-wow-delay=".3s"></div>
                            </div>
                        </div>
                    </div>
                </div>

            <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>

                <div class="case-study-two pb-140">
                    <div class="case-study-two__active owl-carousel">
                        <?php foreach ( $settings['case_study_list'] as $item ) :
                            if ( !empty($item['image']['url']) ) {
                                $seoq_case_study_image_url = !empty($item['image']['id']) ? wp_get_attachment_image_url( $item['image']['id'], 'full') : $item['image']['url'];
                                $seoq_team_image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                            }    
                            
                            // Link
                            if ('2' == $item['seoq_link_type']) {
                                $link = get_permalink($item['seoq_page_link']);
                                $target = '_self';
                                $rel = 'nofollow';
                            } else {
                                $link = !empty($item['seoq_link']['url']) ? $item['seoq_link']['url'] : '';
                                $target = !empty($item['seoq_link']['is_external']) ? '_blank' : '';
                                $rel = !empty($item['seoq_link']['nofollow']) ? 'nofollow' : '';
                            }
                        ?>
                        <div class="case-study-two__single" data-merge="1" data-background="<?php echo esc_url($seoq_case_study_image_url); ?>">
                            <div class="case-study-two__single-box">
                                <span><?php echo rrdevs_kses( $item['subtitle'] ); ?></span>
                                <h4><?php echo rrdevs_kses( $item['title_main'] ); ?></h4>
                                <a target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($rel); ?>" href="<?php echo esc_url($link); ?>">
                                    <?php echo $item['seoq_link_text']; ?>
                                </a>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>

            <?php endif; ?>

		<?php
	}
}

$widgets_manager->register( new SEOQ_Case_Study_Slider() );