<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Contact_Form extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_contact_form';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact Form', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}


    public function get_seoq_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $seoq_cfa         = array();
        $seoq_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $seoq_forms       = get_posts( $seoq_cf_args );
        $seoq_cfa         = ['0' => esc_html__( 'Select Form', 'seoq-core' ) ];
        if( $seoq_forms ){
            foreach ( $seoq_forms as $seoq_form ){
                $seoq_cfa[$seoq_form->ID] = $seoq_form->post_title;
            }
        }else{
            $seoq_cfa[ esc_html__( 'No contact form found', 'seoq-core' ) ] = 0;
        }
        return $seoq_cfa;
    }


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );  
        $this->add_control(
            'seoq_shap_img',
            [
                'label' => esc_html__( 'Contact Shap', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Choose Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-1', 'layout-2']
                ],
            ]
        );
        $this->add_control(
            'seoq_image_2',
            [
                'label' => esc_html__( 'Choose Image 2', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-2'
                ],
            ]
        );
        $this->add_control(
            'seoq_image_3',
            [
                'label' => esc_html__( 'Choose Image 3', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_design_style' => 'layout-2'
                ],
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__('Title & Content', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_sub_title',
            [
                'label' => esc_html__('Sub Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Contact With Us', 'seoq-core'),
                'placeholder' => esc_html__('Type Sub Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Write A Message', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_contact',
            [
                'label' => esc_html__('Contact Form', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'seoq-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_seoq_contact_form(),
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_inner_padding',
            [
                'label' => __( 'Content Inner Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_background',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one' => 'background-color: {{VALUE}}',
                ],
            ]
        );


        $this->end_controls_section();

		$this->start_controls_section(
            '_section_style_content',
            [
                'label' => __( 'Title / Content', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // Subtitle    
        $this->add_control(
            '_heading_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subtitle', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'subtitle_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .quote-form-one__content p',
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__one-title',
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_contact_style',
			[
				'label' => __( 'Contact Form', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'input_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input' => 'border-radius: {{SIZE}}px;',
                    '{{WRAPPER}} .quote-form-one__content textarea' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

		// Input
        $this->add_control(
            '_content_input',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Input', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->start_controls_tabs( '_form_input_tabs' );
        
        $this->start_controls_tab(
            'form_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );
        
        $this->add_control(
            'input_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input::placeholder' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea::placeholder' => 'color: {{VALUE}}',
                ],
            ]
        );

		$this->add_control(
            'input_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea' => 'background-color: {{VALUE}}',
                ],
            ]
        );

		$this->add_control(
            'input_border_color',
            [
                'label'     => esc_html__( 'Border', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        		// Button
                $this->add_control(
                    '_content_button',
                    [
                        'type' => Controls_Manager::HEADING,
                        'label' => __( 'Button', 'seoq-core' ),
                        'separator' => 'before'
                    ]
                );
        
                $this->add_control(
                    'button_color',
                    [
                        'label'     => esc_html__( 'Color', 'seoq-core' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .contact-btn'    => 'color: {{VALUE}}',
                        ],
                    ]
                );
        
                $this->add_control(
                    'button_background',
                    [
                        'label'     => esc_html__( 'Background', 'seoq-core' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .contact-btn' => 'background-color: {{VALUE}}',
                        ],
                    ]
                );
        
                $this->add_control(
                    'button_border_radius',
                    [
                        'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                        'type'      => Controls_Manager::SLIDER,
                        'selectors' => [
                            '{{WRAPPER}} .contact-btn' => 'border-radius: {{SIZE}}px;',
                        ],
                    ]
                );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'form_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'input_color_hover',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input:hover::placeholder' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea:hover::placeholder' => 'color: {{VALUE}}',
                ],
            ]
        );


		$this->add_control(
            'input_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

		$this->add_control(
            'input_border_color_hover',
            [
                'label'     => esc_html__( 'Border', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .quote-form-one__content input:hover' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .quote-form-one__content textarea:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        	// Button
            $this->add_control(
                '_content_button_hover',
                [
                    'type' => Controls_Manager::HEADING,
                    'label' => __( 'Button', 'seoq-core' ),
                    'separator' => 'before'
                ]
            );
    
            $this->add_control(
                'button_color_hover',
                [
                    'label'     => esc_html__( 'Color', 'seoq-core' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .contact-btn:hover'    => 'color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_control(
                'button_background_hover',
                [
                    'label'     => esc_html__( 'Background', 'seoq-core' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .contact-btn:hover' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_control(
                'button_border_radius_hover',
                [
                    'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                    'type'      => Controls_Manager::SLIDER,
                    'selectors' => [
                        '{{WRAPPER}} .contact-btn:hover' => 'border-radius: {{SIZE}}px;',
                    ],
                ]
            );
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

		$this->end_controls_section();
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$this->add_render_attribute('title_args', 'class', 'section-title__one-title mb-25');

		if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full' ) : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }
		?>

<?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
<div class="quote-form-one pt-120 pb-125">
    <div class="quote-form-one__wrapper">
        <?php if ( !empty($settings['seoq_shap_img']) ) : ?>
        <div class="quote-form-one__img1">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape1.svg" alt="">
        </div>
        <div class="quote-form-one__img2">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape2.svg" alt="">
        </div>
        <div class="quote-form-one__img3">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape3.svg" alt="">
        </div>
        <div class="quote-form-one__img4">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape4.svg" alt="">
        </div>
        <div class="quote-form-one__img5">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape5.svg" alt="">
        </div>
        <?php endif;?>
        <div class="container">
            <div class="row">
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 wow fadeInLeft" data-wow-delay=".3s"
                    style="visibility: visible; animation-delay: 0.3s; animation-name: fadeInLeft;">
                    <?php if(!empty($seoq_image)) : ?>
                    <div class="quote-form-one__img ">
                        <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                    </div>
                    <?php endif; ?>
                </div>
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 wow fadeInUp" data-wow-delay=".5s"
                    style="visibility: visible; animation-delay: 0.5s; animation-name: fadeInUp;">
                    <div class="quote-form-one__content">
                        <?php
                            if ( !empty($settings['seoq_title' ]) ) :
                                printf( '<%1$s %2$s>%3$s</%1$s>',
                                    tag_escape( $settings['seoq_title_tag'] ),
                                    $this->get_render_attribute_string( 'title_args' ),
                                    rrdevs_kses( $settings['seoq_title' ] )
                                    );
                            endif;
                        ?>
                        <?php if ( !empty($settings['seoq_sub_title']) ) : ?>
                        <p class="mb-40 "><?php echo rrdevs_kses( $settings['seoq_sub_title'] ); ?></p>
                        <?php endif; ?>
                        <?php if( !empty($settings['seoq_select_contact_form']) ) : ?>
                        <?php echo do_shortcode( '[contact-form-7  id="'.$settings['seoq_select_contact_form'].'"]' ); ?>

                        <?php else : ?>
                        <?php echo '<div class="alert alert-info"><p class="m-0">' . __('Please Select contact form.', 'seoq-core' ). '</p></div>'; ?>
                        <?php endif; ?>

                    </div>
                </div>
            </div>
        </div>
    </div>
</div>


<?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): 
    if ( !empty($settings['seoq_image']['url']) ) {
        $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full' ) : $settings['seoq_image']['url'];
        $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
    }  
    if ( !empty($settings['seoq_image_2']['url']) ) {
        $seoq_image_2 = !empty($settings['seoq_image_2']['id']) ? wp_get_attachment_image_url( $settings['seoq_image_2']['id'], 'full' ) : $settings['seoq_image_2']['url'];
        $seoq_image_alt = get_post_meta($settings["seoq_image_2"]["id"], "_wp_attachment_image_alt", true);
    }
    if ( !empty($settings['seoq_image_3']['url']) ) {
        $seoq_image_3 = !empty($settings['seoq_image_3']['id']) ? wp_get_attachment_image_url( $settings['seoq_image_3']['id'], 'full' ) : $settings['seoq_image_3']['url'];
        $seoq_image_alt = get_post_meta($settings["seoq_image_3"]["id"], "_wp_attachment_image_alt", true);
    }  
?>

<div class="quote-form-one pt-120 pb-125">
    <div class="quote-form-one__wrapper">
        <?php if ( !empty($settings['seoq_shap_img']) ) : ?>
        <div class="quote-form-one__img1">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape1.svg" alt="">
        </div>
        <div class="quote-form-one__img2">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape2.svg" alt="">
        </div>
        <div class="quote-form-one__img3">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape3.svg" alt="">
        </div>
        <div class="quote-form-one__img4">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape4.svg" alt="">
        </div>
        <div class="quote-form-one__img5">
            <img src="<?php echo get_template_directory_uri(  ); ?>/assets/img/quote-form/shape5.svg" alt="">
        </div>
        <?php endif;?>
        <div class="container">
            <div class="row">
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 wow fadeInLeft" data-wow-delay=".3s"
                    style="visibility: visible; animation-delay: 0.3s; animation-name: fadeInLeft;">

                    <div class="quote-form-one__img">
                        <?php if(!empty($seoq_image)) : ?>
                        <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                        <?php endif; ?>
                        <?php if(!empty($seoq_image_2)) : ?>
                        <div class="quote-form-one__img-animation1">
                            <img src="<?php echo esc_url($seoq_image_2); ?>"
                                alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                        </div>
                        <?php endif; ?>
                        <?php if(!empty($seoq_image_3)) : ?>
                        <div class="quote-form-one__img-animation2">
                            <img src="<?php echo esc_url($seoq_image_3); ?>"
                                alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                        </div>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 wow fadeInUp" data-wow-delay=".5s"
                    style="visibility: visible; animation-delay: 0.5s; animation-name: fadeInUp;">
                    <div class="quote-form-one__content">
                        <?php
                            if ( !empty($settings['seoq_title' ]) ) :
                                printf( '<%1$s %2$s>%3$s</%1$s>',
                                    tag_escape( $settings['seoq_title_tag'] ),
                                    $this->get_render_attribute_string( 'title_args' ),
                                    rrdevs_kses( $settings['seoq_title' ] )
                                    );
                            endif;
                        ?>
                        <?php if ( !empty($settings['seoq_sub_title']) ) : ?>
                        <p class="mb-40 "><?php echo rrdevs_kses( $settings['seoq_sub_title'] ); ?></p>
                        <?php endif; ?>
                        <?php if( !empty($settings['seoq_select_contact_form']) ) : ?>
                        <?php echo do_shortcode( '[contact-form-7  id="'.$settings['seoq_select_contact_form'].'"]' ); ?>

                        <?php else : ?>
                        <?php echo '<div class="alert alert-info"><p class="m-0">' . __('Please Select contact form.', 'seoq-core' ). '</p></div>'; ?>
                        <?php endif; ?>

                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php endif; ?>

<?php 
	}
}

$widgets_manager->register( new SEOQ_Contact_Form() );