<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Cta extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_cta';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'CTA', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

    public function get_seoq_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $seoq_cfa         = array();
        $seoq_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $seoq_forms       = get_posts( $seoq_cf_args );
        $seoq_cfa         = ['0' => esc_html__( 'Select Form', 'seoq-core' ) ];
        if( $seoq_forms ){
            foreach ( $seoq_forms as $seoq_form ){
                $seoq_cfa[$seoq_form->ID] = $seoq_form->post_title;
            }
        }else{
            $seoq_cfa[ esc_html__( 'No contact form found', 'seoq-core' ) ] = 0;
        }
        return $seoq_cfa;
    }
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_cta_content',
            [
                'label' => esc_html__('CTA', 'seoq-core'),
            ]
        );
        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );  
        $this->add_control(
            'seoq_shap_img',
            [
                'label' => esc_html__( 'Contact Shap', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Choose Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Our Best Service', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_desc',
            [
                'label' => esc_html__('Desc', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor adipiscing
                commodo imperdiet.', 'seoq-core'),
                'placeholder' => esc_html__('Type Desc Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_contact',
            [
                'label' => esc_html__('Contact Form', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'seoq-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_seoq_contact_form(),
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_cta_style',
			[
				'label' => __( 'CTA', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            '_heading_title',
            [
                'label' => esc_html__( 'Title', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper h2, .cta-two__content h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper h2, .cta-two__content h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .cta-one__wrapper h2, .cta-two__content h2',
            ]
        );

    

		$this->end_controls_section();
        $this->start_controls_section(
			'seoq_cta_style_2',
			[
				'label' => __( 'Desc ', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            '_heading_desc',
            [
                'label' => esc_html__( 'Desc', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_responsive_control(
            'desc_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper p, .cta-two__content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label' => esc_html__( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper p, .cta-two__content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'desc_typography',
                'selector' => '{{WRAPPER}} .cta-one__wrapper p, .cta-two__content p ',
            ]
        );
		$this->end_controls_section();

		$this->start_controls_section(
			'seoq_contact_style',
			[
				'label' => __( 'Contact Form', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		// Input
        $this->add_control(
            '_content_input',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Input', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->start_controls_tabs( '_form_input_tabs' );
        
        $this->start_controls_tab(
            'form_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );
        
        $this->add_control(
            'input_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input::placeholder' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input::placeholder' => 'color: {{VALUE}}',
                ],
            ]
        );

		$this->add_control(
            'input_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input' => 'background-color: {{VALUE}}',
                    
                ],
            ]
        );

		$this->add_control(
            'input_border_color',
            [
                'label'     => esc_html__( 'Border', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input' => 'border-color: {{VALUE}}',

                ],
            ]
        );
        $this->add_control(
            'input_border_color_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input' => 'border-radius: {{SIZE}}px;',
                    '{{WRAPPER}} .cta-two__content form input' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
        		// Button
                $this->add_control(
                    '_content_button',
                    [
                        'type' => Controls_Manager::HEADING,
                        'label' => __( 'Button', 'seoq-core' ),
                        'separator' => 'before'
                    ]
                );
        
                $this->add_control(
                    'button_color',
                    [
                        'label'     => esc_html__( 'Color', 'seoq-core' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .cta-one__btn'    => 'color: {{VALUE}}',
                        ],
                    ]
                );
        
                $this->add_control(
                    'button_background',
                    [
                        'label'     => esc_html__( 'Background', 'seoq-core' ),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .cta-one__btn' => 'background-color: {{VALUE}}',
                        ],
                    ]
                );
        
                $this->add_control(
                    'button_border_radius',
                    [
                        'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                        'type'      => Controls_Manager::SLIDER,
                        'selectors' => [
                            '{{WRAPPER}} .cta-one__btn' => 'border-radius: {{SIZE}}px;',
                        ],
                    ]
                );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'form_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'input_color_hover',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input:hover::placeholder' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input:hover::placeholder' => 'color: {{VALUE}}',
                ],
            ]
        );


		$this->add_control(
            'input_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

		$this->add_control(
            'input_border_color_hover',
            [
                'label'     => esc_html__( 'Border', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cta-one__wrapper-form input:hover' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .cta-two__content form input:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'input_border_radius_hover',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .cta-two__content form input:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
        	// Button
            $this->add_control(
                '_content_button_hover',
                [
                    'type' => Controls_Manager::HEADING,
                    'label' => __( 'Button', 'seoq-core' ),
                    'separator' => 'before'
                ]
            );
    
            $this->add_control(
                'button_color_hover',
                [
                    'label'     => esc_html__( 'Color', 'seoq-core' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cta-one__btn:hover'    => 'color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_control(
                'button_background_hover',
                [
                    'label'     => esc_html__( 'Background', 'seoq-core' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cta-one__btn:hover' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
    
            $this->add_control(
                'button_border_radius_hover',
                [
                    'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                    'type'      => Controls_Manager::SLIDER,
                    'selectors' => [
                        '{{WRAPPER}} .cta-one__btn:hover' => 'border-radius: {{SIZE}}px;',
                    ],
                ]
            );
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
      
        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full') : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

		?>
<?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
<div class="cta-one theme-gray-3 position-relative wow fadeInUp" data-wow-delay=".3s">
    <div class="container">
        <div class="cta-one__overlay"></div>
        <div class="cta-one__wrapper">
            <?php if ( !empty($settings['seoq_shap_img']) ) : ?>
            <div class="cta-one__img1">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/dotted.svg"
                    alt="shape">
            </div>
            <div class="cta-one__img2">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/leaf.png" alt="shape">
            </div>
            <div class="cta-one__img3">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/cta-1-2.png"
                    alt="shape">
            </div>
            <div class="cta-one__img4">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/cta-1-3.png"
                    alt="shape">
            </div>
            <div class="cta-one__img5">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow-top-corner.png"
                    alt="shape">
            </div>
            <div class="cta-one__img6">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow-down-corner.png"
                    alt="shape">
            </div>
            <div class="cta-one__img7">
                <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow-left.png"
                    alt="shape">
            </div>
            <?php endif; ?>
            <div class="container">
                <div class="row">
                    <div class="col-xxl-5 col-xl-5 col-lg-5 col-md-12 col-sm-12 text-center">
                        <?php if(!empty($seoq_image)) : ?>
                        <div class="cta-main__img">
                            <img src="<?php echo esc_url($seoq_image); ?>"
                                alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                        </div>
                        <?php endif; ?>
                    </div>
                    <div class="col-xxl-7 col-xl-7 col-lg-7 col-md-12 col-sm-12">
                        <?php if (!empty($settings['seoq_title'])) : ?>
                        <h2>
                            <?php echo $settings['seoq_title']; ?>
                        </h2>
                        <?php endif; ?>
                        <?php if (!empty($settings['seoq_desc'])) : ?>
                            <p><?php echo $settings['seoq_desc']; ?></p>
                        <?php endif; ?>
                        <div class="cta-one__wrapper-form">
                            <?php if ( !empty($settings['seoq_sub_title']) ) : ?>
                            <p class="mb-40 "><?php echo rrdevs_kses( $settings['seoq_sub_title'] ); ?></p>
                            <?php endif; ?>
                            <?php if( !empty($settings['seoq_select_contact_form']) ) : ?>
                            <?php echo do_shortcode( '[contact-form-7  id="'.$settings['seoq_select_contact_form'].'"]' ); ?>

                            <?php else : ?>
                            <?php echo '<div class="alert alert-info"><p class="m-0">' . __('Please Select contact form.', 'seoq-core' ). '</p></div>'; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): 
        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full') : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }
?>
<div class="cta-two">
    <?php if ( !empty($settings['seoq_shap_img']) ) : ?>
    <div class="cta-two__img">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/shape-top.png" alt="cta img">
    </div>
    <div class="cta-two__line1">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/line.png" alt="line img">
    </div>
    <div class="cta-two__line2">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/line.png" alt="line img">
    </div>
    <div class="cta-two__line3">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/line.png" alt="line img">
    </div>
    <div class="cta-two__line4">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/line.png" alt="line img">
    </div>
    <div class="cta-two__line5">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/line.png" alt="line img">
    </div>
    <div class="cta-two__arrow1">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow-right.png"
            alt="line img">
    </div>
    <div class="cta-two__arrow2">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow-left.png" alt="line img">
    </div>
    <?php endif; ?>
    <div class="container">
        <div class="row">
            <div class="col-xxl-5 col-xl-5 col-lg-5 d-lg-block d-xl-block d-xxl-block d-none">
                <div class="cta-two__img1 wow fadeInLeft" data-wow-delay=".3s">
                    <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                </div>
            </div>
            <div class="col-xxl-7 col-xl-7 col-lg-7 col-md-12">
                <div class="cta-two__content wow fadeInUp" data-wow-delay=".3s">
                    <?php if (!empty($settings['seoq_title'])) : ?>
                    <h2>
                    <?php echo $settings['seoq_title']; ?>
                    </h2>
                    <?php endif; ?>
                    <?php if (!empty($settings['seoq_desc'])) : ?>
                    <p><?php echo $settings['seoq_desc']; ?></p>
                    <?php endif; ?>
                    <?php if ( !empty($settings['seoq_sub_title']) ) : ?>
                    <p class="mb-40 "><?php echo rrdevs_kses( $settings['seoq_sub_title'] ); ?></p>
                    <?php endif; ?>
                    <?php if( !empty($settings['seoq_select_contact_form']) ) : ?>
                    <?php echo do_shortcode( '[contact-form-7  id="'.$settings['seoq_select_contact_form'].'"]' ); ?>

                    <?php else : ?>
                    <?php echo '<div class="alert alert-info"><p class="m-0">' . __('Please Select contact form.', 'seoq-core' ). '</p></div>'; ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
    <?php if ( !empty($settings['seoq_shap_img']) ) : ?>
    <div class="cta-two__img_animation3">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/arrow.png" alt="cta img">
    </div>
    <div class="cta-two__img2">
        <img src="https://rrdevs.net/demos/wp/seoq/wp-content/themes/seoq/assets/img/cta/cta-2-2.png" alt="cta img">
    </div>
    <?php endif; ?>
</div>
<?php endif; ?>
<?php 
	}
}

$widgets_manager->register( new seoq_Cta() );