<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Tp Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Faq extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_faq';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Faq', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );
        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                    'layout-3' => esc_html__('Layout 3', 'seoq-core'),
                    'layout-4' => esc_html__('Layout 4', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->add_control(
            'seoq_shape_switch',
            [
                'label' => esc_html__( 'Show/Hide Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'seoq_design_style' => ['layout-2', 'layout-3'],
                ],
            ]
        );

        $this->end_controls_section();

        // Title and description
        $this->start_controls_section(
            'seoq_faq',
            [
                'label' => esc_html__('Title & Description', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => ['layout-2','layout-3'],
                ],
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Recover From Google
                Penalties with SEO.', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_design_style' => ['layout-2', 'layout-3'],
                ],
            ]
        );

        $this->add_control(
            'seoq_description',
            [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Praesent mollis tortor augue, lacinia vestibulum sem cursus sed. Suspendisse quis sapien sed odio dictum fringilla eget eget ligula Duis varius ornare quam, interdum libero elementum bibendum arcu efficitur vehicula.', 'seoq-core'),
                'placeholder' => esc_html__('Type section description here', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => ['layout-3'],
                ],
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->end_controls_section();


        // Image
        $this->start_controls_section(
            'seoq_image_content',
            [
                'label' => esc_html__('Image', 'seoq-core'),
                'description' => esc_html__( 'Seoq Image', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-1', 'layout-2', 'layout-3'],
                ],
            ]
        );

        $this->add_control(
            'seoq_image_shape_01',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image Shape 01', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-2'],
                ],
            ]
        );

        $this->add_control(
            'seoq_image_shape_02',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image Shape 02', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-2'],
                ],
            ]
        );

        $this->end_controls_section();

        // seoq_faq_list
        $this->start_controls_section(
            '_seoq_faq_list',
            [
                'label' => esc_html__('FAQ List', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_faq_active',
            [
                'label' => esc_html__( 'Open', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'active',
                'default' => '',
            ]
        );

        $repeater->add_control(
            'seoq_faq_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_faq_description', [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_faq_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-10'],
                ],
            ]
        );

        $repeater->add_control(
            'template',
            [
                'label' => __('Section Template', 'seoq-core'),
                'placeholder' => __('Select a section template for as tab content', 'seoq-core'),

                'type' => Controls_Manager::SELECT2,
                'options' => get_elementor_templates()
            ]
        );

        $this->add_control(
            'seoq_faq_list',
            [
                'label' => esc_html__('Faq List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_faq_open' => 'active',
                        'seoq_faq_title' => esc_html__('Why is SEO important for my website?', 'seoq-core'),
                        'seoq_faq_description' => esc_html__('We denounce with righteous indignation and dislike men demoralized by the charms of pleasure of the moment, they cannot foresee the pain and trouble.', 'seoq-core'),
                        'seoq_faq_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_faq_title' => esc_html__('Why are the cleaning rate will be lowest price?', 'seoq-core'),
                        'seoq_faq_description' => esc_html__('We denounce with righteous indignation and dislike men demoralized by the charms of pleasure of the moment, they cannot foresee the pain and trouble.', 'seoq-core'),
                        'seoq_faq_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_faq_title' => esc_html__('Your pricing table will be possible?', 'seoq-core'),
                        'seoq_faq_description' => esc_html__('We denounce with righteous indignation and dislike men demoralized by the charms of pleasure of the moment, they cannot foresee the pain and trouble.', 'seoq-core'),
                        'seoq_faq_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_faq_title' => esc_html__('Why do I need to remove toys from the pool?', 'seoq-core'),
                        'seoq_faq_description' => esc_html__('We denounce with righteous indignation and dislike men demoralized by the charms of pleasure of the moment, they cannot foresee the pain and trouble.', 'seoq-core'),
                        'seoq_faq_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_faq_title' => esc_html__('Do I have to cover my pool when it rains?', 'seoq-core'),
                        'seoq_faq_description' => esc_html__('We denounce with righteous indignation and dislike men demoralized by the charms of pleasure of the moment, they cannot foresee the pain and trouble.', 'seoq-core'),
                        'seoq_faq_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ],
                'title_field' => '{{{ seoq_faq_title }}}',
            ]
        );
        $this->end_controls_section();


        // Design Style Control
        $this->start_controls_section(
            '_section_layout_style',
            [
                'label' => __( 'Design Layout', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .faq-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_background_color',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_title_style',
            [
                'label' => __( 'Title', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // Subheading
        $this->add_control(
            '_subheading_options',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subheading', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'subheading_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__tagline' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'subheading_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__tagline' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subheading_typography',
                'selector' => '{{WRAPPER}} .section-title__tagline',
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__title',
            ]
        );

        // Description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__text' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .section-title__style2 .text-box p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__text' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .section-title__style2 .text-box p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .section-title__text, .section-title__style2 .text-box p',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_faq_list_style',
            [
                'label' => __( 'Faq List', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            '_heading_icon',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Icon', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'faq_icon_size',
            [
                'label' => __( 'Font Size', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-title-inner .icon span::before' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            '_heading_faq_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'faq_title_typography',
                'selector' => '{{WRAPPER}} .faq-one-accrodion .accrodion-title h4',
            ]
        );

        $this->start_controls_tabs( 'faq_list_tabs' );

        $this->start_controls_tab(
            'faq_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'faq_title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-title h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-title::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-title-inner .icon span::before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'faq_title_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-title' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'faq_active_tab',
            [
                'label' => esc_html__( 'Active', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'faq_title_color_active',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion.active .accrodion-title h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .faq-one-accrodion  .accrodion.active .accrodion-title::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .faq-one-accrodion .accrodion.active .accrodion-title-inner .icon span::before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'faq_title_background_active',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion.active .accrodion-title' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            '_heading_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'faq_description_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'faq_description_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-content' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'faq_description_typography',
                'selector' => '{{WRAPPER}} .faq-one-accrodion .accrodion-content p',
            ]
        );

        $this->add_responsive_control(
            'faq_description_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .faq-one-accrodion .accrodion-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();
	?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ):
            $this->add_render_attribute('title_args', 'class', 'section-title__title');
            if ( !empty($settings['seoq_image']['url']) ) {
                $seoq_image_url = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'],'full') : $settings['seoq_image']['url'];
                $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
            }
        ?>

        <!-- faq start -->
        <div class="faq-one">
            <div class="container">
                <div class="row">
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-12">
                        <div class="faq-one-img">
                            <img src="<?php echo esc_url($seoq_image_url); ?>" alt="<?php echo esc_url($seoq_image_alt); ?>">
                        </div>
                    </div>

                    <div class="col-xxl-8 col-xl-8 col-lg-8 col-md-12">
                        <div class="faq-one__content">
                            <div class="faq-one__faq">
                                <div class="accordion" id="accordionExample">
                                    <?php foreach ($settings['seoq_faq_list'] as $id => $item) :
                                        // active class
                                        $collapsed_tab = ($id == 0) ? '' : 'collapsed';
                                        $area_expanded = ($id == 0) ? 'true' : 'false';
                                        $active_show_tab = ($id == 0) ? 'collapse show' : 'collapse';
                                    ?>
                                    <div class="accordion-items">
                                        <h2 class="accordion-header" id="headingOne">
                                            <button class="accordion-buttons <?php echo esc_attr($collapsed_tab); ?>"
                                            type="button"
                                            data-bs-toggle="collapse"
                                            data-bs-target="#collapseOne-<?php echo esc_attr($id); ?>"
                                            aria-expanded="<?php echo esc_attr($area_expanded); ?>"
                                            aria-controls="collapseOne-<?php echo esc_attr($id); ?>">
                                                <?php echo rrdevs_kses($item['seoq_faq_title' ]); ?>
                                            </button>
                                        </h2>

                                        <div id="collapseOne-<?php echo esc_attr($id); ?>"
                                        class="accordion-collapse collapse <?php echo esc_attr($active_show_tab); ?>"
                                        aria-labelledby="headingOne-<?php echo esc_attr($id); ?>"
                                        data-bs-parent="#accordionExample">
                                            <div class="accordion-body">
                                                <?php echo rrdevs_kses($item['seoq_faq_description' ]); ?>
                                            </div>
                                        </div>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- faq end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ):

            $this->add_render_attribute('title_args', 'class', 'section-title__one-title seoq-el-title');

            if ( !empty($settings['seoq_image']['url']) ) {
                $seoq_image_url = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'],'full') : $settings['seoq_image']['url'];
                $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_image_shape_01']['url']) ) {
                $seoq_image_shape_01_url = !empty($settings['seoq_image_shape_01']['id']) ? wp_get_attachment_image_url( $settings['seoq_image_shape_01']['id'],'full') : $settings['seoq_image_shape_01']['url'];
                $seoq_image_shape_01_alt = get_post_meta($settings["seoq_image_shape_01"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_image_shape_02']['url']) ) {
                $seoq_image_shape_02_url = !empty($settings['seoq_image_shape_02']['id']) ? wp_get_attachment_image_url( $settings['seoq_image_shape_02']['id'],'full') : $settings['seoq_image_shape_01']['url'];
                $seoq_image_shape_02_alt = get_post_meta($settings["seoq_image_shape_02"]["id"], "_wp_attachment_image_alt", true);
            }
        ?>

        <!-- faq two start -->
        <div class="faq-two">
            <div class="row g-0 align-items-center">
                <div class="col-xxl-6 col-xl-6 col-lg-12 col-md-12">
                    <div class="faq-two-content__wrapper">
                        <?php if(!empty($settings['seoq_shape_switch'])) : ?>
                            <div class="faq-two__animation1">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/arrow-snack.svg" alt="shape">
                            </div>
                            <div class="faq-two__animation2">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/6.svg" alt="shape">
                            </div>
                            <div class="faq-two__animation3">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/5.svg" alt="shape">
                            </div>
                            <div class="faq-two__animation4">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/11.svg" alt="shape">
                            </div>
                            <div class="faq-two__animation5">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/arrow-circle-line-2.png" alt="shape">
                            </div>
                        <?php endif; ?>

                        <div class="fac-two__content">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>

                            <div class="faq-two__faq">
                                <div class="accordion" id="accordionExample">
                                    <?php foreach ($settings['seoq_faq_list'] as $id => $item) :
                                        // active class
                                        $collapsed_tab = ($id == 0) ? '' : 'collapsed';
                                        $area_expanded = ($id == 0) ? 'true' : 'false';
                                        $active_show_tab = ($id == 0) ? 'collapse show' : 'collapse';
                                    ?>
                                    <div class="accordion-items wow fadeInUp" data-wow-delay=".3s">
                                        <h2 class="accordion-header" id="headingOne">
                                            <button class="accordion-buttons <?php echo esc_attr($collapsed_tab); ?>"
                                            type="button"
                                            data-bs-toggle="collapse"
                                            data-bs-target="#faqtwocollapseOne-<?php echo esc_attr($id); ?>"
                                            aria-expanded="<?php echo esc_attr($area_expanded); ?>"
                                            aria-controls="faqtwocollapseOne-<?php echo esc_attr($id); ?>">
                                                <?php echo rrdevs_kses($item['seoq_faq_title' ]); ?>
                                            </button>
                                        </h2>

                                        <div id="faqtwocollapseOne-<?php echo esc_attr($id); ?>"
                                        class="accordion-collapse collapse <?php echo esc_attr($active_show_tab); ?>"
                                        aria-labelledby="headingOne-<?php echo esc_attr($id); ?>"
                                        data-bs-parent="#accordionExample">
                                            <?php echo \Elementor\Plugin::instance()->frontend->get_builder_content($item['template'], true); ?>
                                        </div>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
                <div class="col-xxl-6 col-xl-6 col-lg-12 col-md-12">
                    <div class="faq-two__right wow fadeInUp" data-wow-delay=".3s">
                        <div class="faq-two__right-img">
                            <?php if(!empty($seoq_image_url)) : ?>
                            <img src="<?php echo esc_url($seoq_image_url); ?>" alt="faq img">
                            <?php endif; ?>

                            <?php if(!empty($seoq_image_shape_01_url)) : ?>
                            <div class="faq-two__right-img1">
                                <img src="<?php echo esc_url($seoq_image_shape_01_url); ?>" alt="faq img">
                            </div>
                            <?php endif; ?>

                            <?php if(!empty($seoq_image_shape_02_url)) : ?>
                            <div class="faq-two__right-img2">
                                <img src="<?php echo esc_url($seoq_image_shape_02_url); ?>" alt="faq img">
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- faq two end -->


        <?php elseif ( $settings['seoq_design_style']  == 'layout-3' ):

            $this->add_render_attribute('title_args', 'class', 'section-title__two-title mb-10 seoq-el-title');

            if ( !empty($settings['seoq_image']['url']) ) {
                $seoq_image_url = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'],'full') : $settings['seoq_image']['url'];
                $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
            }
        ?>

        <!-- faq three start -->
        <div class="faq-three pt-160 pb-100">
            <?php if(!empty($settings['seoq_shape_switch'])) : ?>
                <div class="faq-three__animation-1">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/12.svg" alt="shape icon">
                </div>
                <div class="faq-three__animation-2">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/13.svg" alt="shape icon">
                </div>
                <div class="faq-three__animation-3">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/14.svg" alt="shape icon">
                </div>
                <div class="faq-three__animation-4">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/arrow-circle-line-3.png" alt="shape icon">
                </div>
                <div class="faq-three__animation-5">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/arrow-circle-line-4.png" alt="shape icon">
                </div>
            <?php endif; ?>

            <div class="container">
                <div class="row">
                    <div class="col-xxl-6 col-xl-6">
                        <div class="faq-three__faq">
                            <div class="accordion" id="faqThree">
                                <?php foreach ($settings['seoq_faq_list'] as $id => $item) :
                                    // active class
                                    $collapsed_tab = ($id == 0) ? '' : 'collapsed';
                                    $area_expanded = ($id == 0) ? 'true' : 'false';
                                    $active_show_tab = ($id == 0) ? 'collapse show' : 'collapse';
                                ?>
                                <div class="accordion-items wow fadeInUp" data-wow-delay=".3s">
                                    <h2 class="accordion-header" id="faqthreeOne">
                                        <button class="accordion-buttons <?php echo esc_attr($collapsed_tab); ?>"
                                        type="button"
                                        data-bs-toggle="collapse"
                                        data-bs-target="#faqthreecollapseOne-<?php echo esc_attr($id); ?>"
                                        aria-expanded="<?php echo esc_attr($area_expanded); ?>"
                                        aria-controls="faqthreecollapseOne-<?php echo esc_attr($id); ?>">
                                            <?php echo rrdevs_kses($item['seoq_faq_title' ]); ?>
                                        </button>
                                    </h2>
                                    <div id="faqthreecollapseOne-<?php echo esc_attr($id); ?>"
                                    class="accordion-collapse collapse <?php echo esc_attr($active_show_tab); ?>"
                                    aria-labelledby="faqthreeOne-<?php echo esc_attr($id); ?>"
                                    data-bs-parent="#faqThree">
                                        <?php echo \Elementor\Plugin::instance()->frontend->get_builder_content($item['template'], true); ?>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                    <div class="col-xxl-6 col-xl-6">
                        <div class="faq-three__content wow fadeInRight" data-wow-delay=".5s">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>

                            <?php if ( !empty($settings['seoq_description']) ) : ?>
                            <p><?php echo rrdevs_kses( $settings['seoq_description'] ); ?></p>
                            <?php endif; ?>

                            <?php if(!empty($seoq_image_url)) : ?>
                            <img src="<?php echo esc_url($seoq_image_url); ?>" alt="faq img">
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- faq three end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-4' ): ?>

        <div class="faq-one">
            <div class="faq-one__content">
                <div class="faq-one__faq">
                    <div class="accordion" id="accordionExample">
                        <?php foreach ($settings['seoq_faq_list'] as $id => $item) :
                            // active class
                            $collapsed_tab = ($id == 0) ? '' : 'collapsed';
                            $area_expanded = ($id == 0) ? 'true' : 'false';
                            $active_show_tab = ($id == 0) ? 'collapse show' : 'collapse';
                        ?>
                        <div class="accordion-items">
                            <h2 class="accordion-header" id="headingOne">
                                <button class="accordion-buttons <?php echo esc_attr($collapsed_tab); ?>"
                                type="button"
                                data-bs-toggle="collapse"
                                data-bs-target="#collapseOne-<?php echo esc_attr($id); ?>"
                                aria-expanded="<?php echo esc_attr($area_expanded); ?>"
                                aria-controls="collapseOne-<?php echo esc_attr($id); ?>">
                                    <?php echo rrdevs_kses($item['seoq_faq_title' ]); ?>
                                </button>
                            </h2>

                            <div id="collapseOne-<?php echo esc_attr($id); ?>"
                            class="accordion-collapse collapse <?php echo esc_attr($active_show_tab); ?>"
                            aria-labelledby="headingOne-<?php echo esc_attr($id); ?>"
                            data-bs-parent="#accordionExample">
                                <div class="accordion-body">
                                    <?php echo rrdevs_kses($item['seoq_faq_description' ]); ?>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>


        <?php endif; ?>

        <?php
	}
}

$widgets_manager->register( new seoq_Faq() );