<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Utils;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Fun_Fact extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_fun_fact';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Fun Fact', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_fun_fact',
            [
                'label' => esc_html__('Fun Fact', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
			'seoq_fun_fact_icon_switcher',
			[
				'label' => esc_html__( 'Image Type', 'seoq-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'image' => esc_html__( 'Image', 'seoq-core' ),
					'icon' => esc_html__( 'Icon', 'seoq-core' ),
				],
			]
		);

        $this->add_control(
            'seoq_fun_fact_image',
            [
                'label' => esc_html__('Upload Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_fun_fact_icon_switcher' => 'image',
                ],
            ]
        );

        if (seoq_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'seoq_fun_fact_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'icon-certificate-1',
                    'condition' => [
                        'seoq_fun_fact_icon_switcher' => 'icon',
                    ],
                ]
            );
        } else {
            $this->add_control(
                'seoq_fun_fact_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'icon-certificate-1',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'seoq_fun_fact_icon_switcher' => 'icon',
                    ],
                ]
            );
        }

        $this->add_control(
            'seoq_fun_fact_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'default' => esc_html__('Happy Clients', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_fun_fact_count', [
                'label' => esc_html__('Count Number', 'seoq-core'),
                'default' => '53',
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_fun_fact_percent', [
                'label' => esc_html__('Count Percent', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'default' => esc_html__('K', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_fun_fact_style',
            [
                'label' => __( 'Fun Fact', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            '_heading_layout',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Layout', 'seoq-core' ),
            ]
        );

        $this->add_responsive_control(
            'layout_bottom_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_background',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'content_border',
                'selector' => '{{WRAPPER}} .counter-one__single',
            ]
        );

        $this->add_control(
            '_heading_icon',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Icon', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'icon_bottom_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single-inner .icon-box' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __( 'Icon Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single-inner .icon-box i::before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => __( 'Icon Size', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single-inner .icon-box i::before' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            '_content_count',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Count', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'count_left_spacing',
            [
                'label' => __( 'Left Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single .text-box h3' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'count_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .counter-one__single .text-box h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .counter-one__single .text-box h3' => '-webkit-text-stroke-color: {{VALUE}}',
                    '{{WRAPPER}} .counter-one__single .text-box span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .counter-one__single .text-box span' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'count_typography',
                'selector' => '{{WRAPPER}} .counter-one__single .text-box h3, .counter-one__single .text-box span',
            ]
        );

        $this->add_control(
            '_content_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_top_spacing',
            [
                'label' => __( 'Top Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .counter-one__text' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .counter-one__text' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .counter-one__text',
            ]
        );

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>

            <div class="counter-one__single mb-30">
                <div class="counter-one__single-inner">
                    <?php if (!empty($settings['seoq_fun_fact_image']['url'])): ?>
                        <div class="icon-box">
                            <img src="<?php echo $settings['seoq_fun_fact_image']['url']; ?>" alt="<?php echo get_post_meta(attachment_url_to_postid($settings['seoq_fun_fact_image']['url']), '_wp_attachment_image_alt', true); ?>">
                        </div>
                    <?php endif; ?>
                    <?php if (!empty($settings['seoq_fun_fact_icon']) || !empty($settings['seoq_fun_fact_selected_icon']['value'])) : ?>
                        <div class="icon-box">
                            <?php seoq_render_icon($settings, 'seoq_fun_fact_icon', 'seoq_fun_fact_selected_icon'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="text-box">
                        <h3 class="counter"><?php echo esc_attr($settings['seoq_fun_fact_count' ]); ?></h3>
                        <span class="counter-one__letter"><?php echo rrdevs_kses($settings['seoq_fun_fact_percent' ]); ?></span>
                        <p class="counter-one__text"><?php echo rrdevs_kses($settings['seoq_fun_fact_title' ]); ?></p>
                    </div>
                </div>
            </div>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Fun_Fact() );