<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Gallery_Info extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_gallery_info';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Gallery Info', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_gallery_info',
            [
                'label' => esc_html__('Gallery Info', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Testimonial Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_gallery_info_label', [
                'label' => esc_html__('Label', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_gallery_info_type',
            [
                'label' => esc_html__('Info Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'text' => esc_html__('Text', 'seoq-core'),
                    'url' => esc_html__('URL', 'seoq-core'),
                ],
                'default' => 'text',
            ]
        );

        $repeater->add_control(
            'seoq_gallery_info_title', [
                'label' => esc_html__('Text', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_gallery_info_url',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'URL', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Type url here', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_gallery_info_type' => [ 'url' ],
                ],
            ]
        );

        $this->add_control(
            'seoq_gallery_info_list',
            [
                'label' => esc_html__('Info List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_gallery_info_label' => esc_html__('Date', 'seoq-core'),
                        'seoq_gallery_info_title' => esc_html__('03 may, 2023', 'seoq-core'),
                    ],
                    [
                        'seoq_gallery_info_label' => esc_html__('Client', 'seoq-core'),
                        'seoq_gallery_info_title' => esc_html__('Themeforest, Envato', 'seoq-core'),
                    ],
                    [
                        'seoq_gallery_info_label' => esc_html__('Website', 'seoq-core'),
                        'seoq_gallery_info_title' => esc_html__('SEOQ.com', 'seoq-core'),
                    ],
                    [
                        'seoq_gallery_info_label' => esc_html__('Location', 'seoq-core'),
                        'seoq_gallery_info_title' => esc_html__('New York, USA', 'seoq-core'),
                    ],
                    [
                        'seoq_gallery_info_label' => esc_html__('Value', 'seoq-core'),
                        'seoq_gallery_info_title' => esc_html__('$65,2000', 'seoq-core'),
                    ],
                ],
                'title_field' => '{{{ seoq_gallery_info_label }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_layout_style',
            [
                'label' => __( 'Design Layout', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .list-unstyled.all-project__list li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .list-unstyled.all-project__list li' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_border_color',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .list-unstyled.all-project__list li' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'content_border_color_hover',
            [
                'label' => __( 'Border (Hover)', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .list-unstyled.all-project__list li:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_info_list_style',
            [
                'label' => __( 'Info List', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            '_heading_label',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Label', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'label_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .all-project__name' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'label_typography',
                'selector' => '{{WRAPPER}} .all-project__name',
            ]
        );

        $this->add_responsive_control(
            'label_width',
            [
                'label' => __( 'Width', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
				],
                'selectors' => [
                    '{{WRAPPER}} .all-project__name-box' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            '_content_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .all-project__content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .all-project__content',
            ]
        );

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full') : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

		?>

            <div class="gallery-details__wrapper">
                <div class="gallery-details__img">
                    <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_url($seoq_image_alt); ?>" />
                </div>

                <!--Projects Details Information Start-->
                <div class="gallery-details__information">
                    <ul>
                        <?php foreach ($settings['seoq_gallery_info_list'] as $item) : ?>
                        <li>
                            <?php if ( !empty($item['seoq_gallery_info_label']) ) : ?>
                                <h5><?php echo rrdevs_kses($item['seoq_gallery_info_label' ]); ?></h5>
                            <?php endif; ?>
                            <?php if ( !empty($item['seoq_gallery_info_title']) ) : ?>
                                <?php if ( $item['seoq_gallery_info_type']  == 'text' ): ?>
                                    <p><?php echo rrdevs_kses($item['seoq_gallery_info_title' ]); ?></p>
                               <?php elseif ( $item['seoq_gallery_info_type']  == 'url' ): ?>
                                    <p><a href="<?php echo esc_url($item['seoq_gallery_info_url' ]); ?>"><?php echo rrdevs_kses($item['seoq_gallery_info_title' ]); ?></a></p>
                                <?php endif; ?>
                                
                            <?php endif; ?>
                        </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Gallery_Info() );