<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Hero extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_hero';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Hero', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );
        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                    'layout-3' => esc_html__('Layout 3', 'seoq-core'),
                    'layout-4' => esc_html__('Layout 4', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->add_control(
            'seoq_shape_switch',
            [
                'label' => esc_html__( 'Show/Hide Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'seoq_design_style' => ['layout-2', 'layout-3', 'layout-4'],
                ],
            ]
        );

        $this->end_controls_section();


        // seoq_section_title
        $this->start_controls_section(
            'seoq_hero_content',
            [
                'label' => esc_html__('Hero Content', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Hero Title', 'seoq-core'),
                'placeholder' => esc_html__('Type Title Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_description',
            [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Hero Description', 'seoq-core'),
                'placeholder' => esc_html__('Type description here', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => ['layout-1','layout-3', 'layout-4'],
                ],
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'seoq_hero_rocket_switch',
            [
                'label' => esc_html__( 'Show Rocket Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $this->add_control(
            'seoq_hero_visit_switch',
            [
                'label' => esc_html__( 'Show Visit Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $this->end_controls_section();


        // seoq_section_title
        $this->start_controls_section(
            'seoq_hero_form',
            [
                'label' => esc_html__('Hero Form', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $this->add_control(
            'form_placeholder_text',
            [
                'label' => __( 'Form Placeholder Text', 'seoq-core' ),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'Analyze any website or app', 'seoq-core' ),
                'placeholder' => __( 'Enter placeholder text here', 'seoq-core' ),
                'rows' => 5,
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $this->add_control(
            'seoq_form_btn_text',
            [
                'label' => esc_html__('Form Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Search', 'seoq-core'),
                'title' => esc_html__('Enter from button text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // seoq_hero_box01_title
        $this->start_controls_section(
            'seoq_hero_box_01_form',
            [
                'label' => esc_html__('Hero Box 01', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-2'],
                ],
            ]
        );

        $this->add_control(
            'seoq_box_01_text',
            [
                'label' => esc_html__('Box 01 Text', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Improve your business in the digital platform.', 'seoq-core'),
                'placeholder' => esc_html__('Type Box Text Here', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_box_01_image',
            [
                'label' => esc_html__( 'Box 01 Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_box_user_01_image',
            [
                'label' => esc_html__( 'User Image 01', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_box_user_02_image',
            [
                'label' => esc_html__( 'User Image 02', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'seoq_box_user_03_image',
            [
                'label' => esc_html__( 'User Image 03', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_box_01_active_user',
            [
                'label' => esc_html__('Box 01 Active User', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('More Active Customer', 'seoq-core'),
                'placeholder' => esc_html__('Type Active User Text Here', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_box_01_active_user_number',
            [
                'label' => esc_html__('Box 01 Active User Number', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('100+', 'seoq-core'),
                'placeholder' => esc_html__('Type Active User Number Here', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        // seoq_hero_box02_title
        $this->start_controls_section(
            'seoq_hero_box_02',
            [
                'label' => esc_html__('Hero Box 02', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-2'],
                ],
            ]
        );

        $this->add_control(
            'seoq_box_02_image',
            [
                'label' => esc_html__( 'Box 02 Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_box_02_review_text',
            [
                'label' => esc_html__('Box 02 Review Text', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('4000+ Clients Reviews', 'seoq-core'),
                'placeholder' => esc_html__('Type review Text Here', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_rating_switch',
            [
                'label' => esc_html__( 'Show/Hide Rating', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_btn_button_show',
            [
                'label' => esc_html__( 'Show Button', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Let’s Talk ', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_btn_button_show' => 'yes'
                ],
            ]
        );
        $this->add_control(
            'seoq_btn_link_type',
            [
                'label' => esc_html__('Button Link Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'seoq_btn_button_show' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'seoq_btn_link',
            [
                'label' => esc_html__('Button link', 'seoq-core'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'seoq-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'seoq_btn_link_type' => '1',
                    'seoq_btn_button_show' => 'yes'
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_page_link',
            [
                'label' => esc_html__('Select Button Page', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_btn_link_type' => '2',
                    'seoq_btn_button_show' => 'yes'
                ]
            ]
        );

        $this->end_controls_section();


        // seoq_hero_background
        $this->start_controls_section(
            'seoq_hero_background_image',
            [
                'label' => esc_html__('Hero Background Image', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => ['layout-3'],
                ],
            ]
        );

        $this->add_control(
            'seoq_hero_bg_image',
            [
                'label' => esc_html__( 'BG Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();


        // seoq_hero_background
        $this->start_controls_section(
            'seoq_hero_04_image_section',
            [
                'label' => esc_html__('Hero Image', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => ['layout-4'],
                ],
            ]
        );

        $this->add_control(
            'seoq_hero_04_image',
            [
                'label' => esc_html__( 'Hero Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_shape_image_switch',
            [
                'label' => esc_html__( 'Show/Hide Shape Image', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();


        // seoq_section_title
        $this->start_controls_section(
            'seoq_hero_form_02',
            [
                'label' => esc_html__('Hero Form', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-3'],
                ],
            ]
        );

        $this->add_control(
            'form_02_placeholder_text',
            [
                'label' => __( 'Form Placeholder Text', 'seoq-core' ),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'Enter domain, keyword or URL here', 'seoq-core' ),
                'placeholder' => __( 'Enter placeholder text here', 'seoq-core' ),
                'rows' => 5,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'seoq_form_02_btn_text',
            [
                'label' => esc_html__('Form Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Search', 'seoq-core'),
                'title' => esc_html__('Enter from button text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        // seoq_section_title
        $this->start_controls_section(
            'seoq_hero_form_03',
            [
                'label' => esc_html__('Hero Form', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-4'],
                ],
            ]
        );

        $this->add_control(
            'form_03_placeholder_text',
            [
                'label' => __( 'Form Placeholder Text', 'seoq-core' ),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'www.example.com', 'seoq-core' ),
                'placeholder' => __( 'Enter placeholder text here', 'seoq-core' ),
                'rows' => 5,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'seoq_form_03_btn_text',
            [
                'label' => esc_html__('Form Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Analyze Your Site', 'seoq-core'),
                'title' => esc_html__('Enter from button text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


		// Main Slider
		$this->start_controls_section(
            'seoq_popular_search_slider',
            [
                'label' => esc_html__('Popular Search', 'seoq-core'),
                'description' => esc_html__( 'Popular Search Tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $this->add_control(
            'seoq_hero_popular',
            [
                'label' => esc_html__('Hero Popular', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Popular', 'seoq-core'),
                'placeholder' => esc_html__('Type Popular Here', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => [ 'layout-1'],
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'repeater_condition',
            [
                'label' => __( 'Field condition', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __( 'Style 1', 'seoq-core' ),
                    // 'style_2' => __( 'Style 2', 'seoq-core' ),
                    // 'style_3' => __( 'Style 3', 'seoq-core' ),
                    // 'style_4' => __( 'Style 4', 'seoq-core' ),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'seoq_hero_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('Image', 'seoq-core'),
                    'icon' => esc_html__('Icon', 'seoq-core'),
                ],
            ]
        );

        $repeater->add_control(
            'seoq_hero_popular_search_image',
            [
                'label' => esc_html__('Upload Icon Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_hero_icon_type' => 'image'
                ]

            ]
        );

        if (seoq_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'seoq_hero_popular_search_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fas fa-layer-group',
                    'condition' => [
                        'seoq_hero_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'seoq_hero_popular_search_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-layer-group',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'seoq_hero_icon_type' => 'icon'
                    ]
                ]
            );
        }

        $repeater->add_control(
            'seoq_popular_search_list_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Service Title', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_hero_search_link',
            [
                'label' => esc_html__( 'Select Hero Search Link', 'seoq-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
            ]
        );

        $this->add_control(
            'seoq_hero_search_list',
            [
                'label' => esc_html__('Hero Popular Search - List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ seoq_popular_search_list_title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_brand_section',
            [
                'label' => __( 'Brand Item', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => [ 'layout-3'],
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_brand_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'seoq_brand_url',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'URL', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Type url here', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'seoq_brand_slides',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => esc_html__( 'Brand Item', 'seoq-core' ),
                'default' => [
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->end_controls_section();


        // Style Control
		$this->start_controls_section(
            '_main_slider_style',
            [
                'label' => __( 'Main Slider', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // Dots
        $this->add_control(
            '_arrow_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Arrow', 'seoq-core' ),
                'separator' => 'before'
            ]
        );
        $this->start_controls_tabs( '_arrow_style_tabs' );

        $this->start_controls_tab(
            'arrow_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'text-domain' ),
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-prev' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-prev' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-prev' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-next' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-next' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-next' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'arrow_background_color',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-prev' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-prev' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-prev' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-next' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-next' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-next' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'arrow_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'text-domain' ),
            ]
        );

        $this->add_control(
            'arrow_color_hover',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-prev:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-prev:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-prev:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-next:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-next:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-next:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'arrow_background_color_hover',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-prev::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-prev::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-prev::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-one__carousel.owl-theme .owl-nav .owl-next::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__carousel.owl-theme .owl-nav .owl-next::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__carousel.owl-theme .owl-nav .owl-next::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        // Title
        $this->add_control(
            '_subheading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subheading', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'subheading_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__content .tagline' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .main-slider-two__content .tagline' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .main-slider-three__content .tagline' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'subheading_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .main-slider-one__content .tagline p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-two__content .tagline p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .main-slider-three__content .tagline p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subheading_typography',
                'selector' => '{{WRAPPER}} .main-slider-one__content .tagline p, .main-slider-two__content .tagline p, .main-slider-three__content .tagline p',
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .hero-one__content h1' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hero-one__content h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hero-one__content h3' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hero-one__content h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hero-one__content h5' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hero-one__content h6' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hero-one__content h1' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hero-one__content h2' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hero-one__content h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hero-one__content h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hero-one__content h5' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hero-one__content h6' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} ..hero-one__content h1, .hero-one__content h2, .hero-one__content h3, .hero-one__content h4, .hero-one__content h5, .hero-one__content h6',
            ]
        );

        // Description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .hero-one__content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hero-one__content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .hero-one__content p',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_button_style',
			[
				'label' => __( 'Button', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'button_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn span'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn .liquid' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:hover span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:hover .liquid' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .thm-btn',
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label'      => esc_html__( 'Padding', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button_margin',
            [
                'label'      => esc_html__( 'Margin', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .thm-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
			'seoq_brand_style',
			[
				'label' => __( 'Brand Item', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'seoq_design_style' => [ 'layout-3'],
                ],
			]
		);

		$this->start_controls_tabs( 'brand_slider_tabs' );
		
		$this->start_controls_tab(
			'brand_slider_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'text-domain' ),
			]
		);
		
		$this->add_control(
			'brand_slider_opacity',
			[
				'label'             => esc_html__( 'Opacity', 'seoq-core' ),
				'type'              => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min'       => .1,
						'max'       => 1,
						'step'      => .1,
					],
				],
				'default' => [
					'size'          => .4,
				],
				'selectors' => [
					'{{WRAPPER}} .brand-one__single a img' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'brand_slider_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'text-domain' ),
			]
		);
		
		$this->add_control(
			'brand_slider_opacity_hover',
			[
				'label'             => esc_html__( 'Opacity', 'seoq-core' ),
				'type'              => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min'       => .1,
						'max'       => 1,
						'step'      => .1,
					],
				],
				'default' => [
					'size'          => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .brand-one__single a:hover img' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
        <!-- hero one start -->
        <div class="hero-one" data-background="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-bg-1.png">
            <div class="hero-one__wrapper">
                <?php if(!empty( $settings['seoq_hero_rocket_switch'] )) : ?>
                <div class="hero-one__animation-1">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/rocket.png" alt="rocket img">
                </div>
                <?php endif; ?>

                <?php if(!empty( $settings['seoq_hero_visit_switch'] )) : ?>
                <div class="hero-one__animation-2">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/ranking.png" alt="rocket img">
                </div>
                <?php endif; ?>

                <div class="container-fluid">
                    <div class="row">
                        <div class="col-xxl-12 col-xl-7 col-lg-12 col-md-12 col-sm-12">
                            <div class="hero-one__content wow fadeInUp" data-wow-delay=".3s">
                                <?php
                                    if ( !empty($settings['seoq_title' ]) ) :
                                        printf( '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape( $settings['seoq_title_tag'] ),
                                            $this->get_render_attribute_string( 'title_args' ),
                                            rrdevs_kses( $settings['seoq_title' ] )
                                            );
                                    endif;
                                ?>
                                <?php if ( !empty($settings['seoq_description']) ) : ?>
                                <p><?php echo rrdevs_kses( $settings['seoq_description'] ); ?></p>
                                <?php endif; ?>

                                <form method="get" action="<?php print esc_url( home_url( '/' ) );?>">
                                    <div class="hero__input">
                                        <i class="fa-regular fa-magnifying-glass"></i>
                                        <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php echo rrdevs_kses( $settings['form_placeholder_text'] ); ?>">

                                        <?php if (!empty($settings['seoq_form_btn_text'])) : ?>
                                        <button type="submit" class="hero-btn-1 rr-btn-style-1"><?php echo $settings['seoq_form_btn_text']; ?></button>
                                        <?php endif; ?>
                                    </div>
                                </form>

                                <div class="hero-popular-search">
                                    <?php if ( !empty($settings['seoq_hero_popular']) ) : ?>
                                    <span><?php echo rrdevs_kses( $settings['seoq_hero_popular'] ); ?></span>
                                    <?php endif; ?>
                                    <ul>
                                        <li>
                                            <a href="https://rrdevs.net/demos/wp/seoq/contact/">
                                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/google.svg" alt="google icon"> Google.com
                                            </a>
                                        </li>
                                        <li>
                                            <a href="https://rrdevs.net/demos/wp/seoq/contact/"><img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/facebook-two.svg" alt="facebook icon">Facebook.com</a>
                                        </li>
                                        <li>
                                            <a href="https://rrdevs.net/demos/wp/seoq/contact/"><img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/twitter.svg" alt="facebook icon">Twitter.com</a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- hero one end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ):
            $this->add_render_attribute('title_args', 'class', 'wow fadeInUp section-title__title');
            $this->add_render_attribute('title_args', 'data-wow-delay', '.3s');

            if ( !empty($settings['seoq_box_01_image']['url']) ) {
                $seoq_box_01_image = !empty($settings['seoq_box_01_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_box_01_image']['id'], 'full') : $settings['seoq_box_01_image']['url'];
                $seoq_box_01_image_alt = get_post_meta($settings["seoq_box_01_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_box_user_01_image']['url']) ) {
                $seoq_box_user_01_image = !empty($settings['seoq_box_user_01_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_box_user_01_image']['id'], 'full') : $settings['seoq_box_user_01_image']['url'];
                $seoq_box_user_01_image_alt = get_post_meta($settings["seoq_box_user_01_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_box_user_02_image']['url']) ) {
                $seoq_box_user_02_image = !empty($settings['seoq_box_user_02_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_box_user_02_image']['id'], 'full') : $settings['seoq_box_user_02_image']['url'];
                $seoq_box_user_02_image_alt = get_post_meta($settings["seoq_box_user_02_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_box_user_03_image']['url']) ) {
                $seoq_box_user_03_image = !empty($settings['seoq_box_user_03_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_box_user_03_image']['id'], 'full') : $settings['seoq_box_user_03_image']['url'];
                $seoq_box_user_03_image_alt = get_post_meta($settings["seoq_box_user_03_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_box_02_image']['url']) ) {
                $seoq_box_02_image = !empty($settings['seoq_box_02_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_box_02_image']['id'], 'full') : $settings['seoq_box_02_image']['url'];
                $seoq_box_02_image_alt = get_post_meta($settings["seoq_box_02_image"]["id"], "_wp_attachment_image_alt", true);
            }

            // Link
            if ('2' == $settings['seoq_btn_link_type']) {
                $this->add_render_attribute('seoq-button-arg', 'href', get_permalink($settings['seoq_btn_page_link']));
                $this->add_render_attribute('seoq-button-arg', 'target', '_self');
                $this->add_render_attribute('seoq-button-arg', 'rel', 'nofollow');
                $this->add_render_attribute('seoq-button-arg', 'class', 'thm-btn about-one__btn');
            } else {
                if ( ! empty( $settings['seoq_btn_link']['url'] ) ) {
                    $this->add_link_attributes( 'seoq-button-arg', $settings['seoq_btn_link'] );
                    $this->add_render_attribute('seoq-button-arg', 'class', 'thm-btn about-one__btn');
                }
            }
        ?>

        <!-- hero two start -->
        <div class="hero-style-two d-flex align-items-end">
            <?php if(!empty($settings['seoq_shape_switch'])) : ?>
                <div class="hero-style-two__img-1">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/4.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-2">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/2.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-3">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/3.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-4">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/1.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-5">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/10.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-6">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/9.svg" alt="shape img">
                </div>
                <div class="hero-style-two__img-7">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/arrow-circle-line.png" alt="shape img">
                </div>
            <?php endif; ?>

            <div class="container">
                <div class="row">
                    <div class="col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-sm-12">
                        <div class="hero-style-two__content mb-30">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xxl-5 col-xl-5 col-lg-6 col-md-12 wow fadeInLeft" data-wow-delay=".5s">
                            <div class="hero-style-two__content-box-1">
                                <?php if ($settings['seoq_box_01_image']['url'] || $settings['seoq_box_01_image']['id']) : ?>
                                <img src="<?php echo esc_url($seoq_box_01_image); ?>" alt="hero img">
                                <?php endif; ?>
                                <?php if ( !empty($settings['seoq_box_01_text']) ) : ?>
                                <h3><?php echo rrdevs_kses( $settings['seoq_box_01_text'] ); ?></h3>
                                <?php endif; ?>
                            </div>

                            <div class="active-user">
                                <ul>
                                    <?php if ($settings['seoq_box_user_01_image']['url'] || $settings['seoq_box_user_01_image']['id']) : ?>
                                    <li><img src="<?php echo esc_url($seoq_box_user_01_image); ?>" alt="user img"></li>
                                    <?php endif; ?>

                                    <?php if ($settings['seoq_box_user_02_image']['url'] || $settings['seoq_box_user_02_image']['id']) : ?>
                                    <li><img src="<?php echo esc_url($seoq_box_user_02_image); ?>" alt="user img"></li>
                                    <?php endif; ?>

                                    <?php if ($settings['seoq_box_user_03_image']['url'] || $settings['seoq_box_user_03_image']['id']) : ?>
                                    <li><img src="<?php echo esc_url($seoq_box_user_03_image); ?>" alt="user img"></li>
                                    <?php endif; ?>

                                    <?php if ( !empty($settings['seoq_box_01_active_user_number']) ) : ?>
                                    <li class="user-number"><?php echo rrdevs_kses( $settings['seoq_box_01_active_user_number'] ); ?></li>
                                    <?php endif; ?>
                                </ul>

                                <?php if ( !empty($settings['seoq_box_01_active_user']) ) : ?>
                                <span><?php echo rrdevs_kses( $settings['seoq_box_01_active_user'] ); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>

                        <div class="col-xxl-7 col-xl-5 col-lg-6 col-md-12 text-end wow fadeInRight" data-wow-delay=".7s">

                            <div class="hero-style-two__content-box-2">
                                <?php if ($settings['seoq_box_02_image']['url'] || $settings['seoq_box_02_image']['id']) : ?>
                                <img src="<?php echo esc_url($seoq_box_02_image); ?>" alt="hero img">
                                <?php endif; ?>

                                <?php if (!empty($settings['seoq_btn_text'])) : ?>
                                <a <?php echo $this->get_render_attribute_string( 'seoq-button-arg' ); ?>>
                                    <?php echo $settings['seoq_btn_text']; ?> <i class="fa-sharp fa-regular fa-arrow-right"></i>
                                </a>
                                <?php endif; ?>
                            </div>

                            <div class="happy-client">
                                <?php if($settings['seoq_rating_switch']) : ?>
                                <div class="rating">
                                    <i class="fa-solid fa-star"></i>
                                    <i class="fa-solid fa-star"></i>
                                    <i class="fa-solid fa-star"></i>
                                    <i class="fa-solid fa-star"></i>
                                    <i class="fa-solid fa-star"></i>
                                </div>
                                <?php endif; ?>

                                <?php if ( !empty($settings['seoq_box_02_review_text']) ) : ?>
                                <p><?php echo rrdevs_kses( $settings['seoq_box_02_review_text'] ); ?></p>
                                <?php endif; ?>
                            </div>
                        </div>

                    </div>
                    <div class="hero-bottom-line"></div>
                </div>
            </div>
        </div>
        <!-- hero two end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-3' ):
            $this->add_render_attribute('title_args', 'class', 'mb-60 wow fadeInUp section-title__title');
            $this->add_render_attribute('title_args', 'data-wow-delay', '.3s');

            if ( !empty($settings['seoq_hero_bg_image']['url']) ) {
                $seoq_hero_bg_image = !empty($settings['seoq_hero_bg_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_hero_bg_image']['id'], 'full') : $settings['seoq_hero_bg_image']['url'];
                $seoq_hero_bg_image_alt = get_post_meta($settings["seoq_hero_bg_image"]["id"], "_wp_attachment_image_alt", true);
            }
        ?>

        <!-- hero three start -->
        <div class="hero-style-three d-flex align-items-center" data-background="<?php echo esc_url($seoq_hero_bg_image); ?>">
            <?php if(!empty($settings['seoq_shape_switch'])) : ?>
                <div class="hero-style-three__animation-1">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/line-1.png" alt="line shape">
                </div>
                <div class="hero-style-three__animation-2">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/line-2.png" alt="line shape">
                </div>
                <div class="hero-style-three__animation-3">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/line-3.png" alt="line shape">
                </div>
                <div class="hero-style-three__animation-4">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/line-4.png" alt="line shape">
                </div>
                <div class="hero-style-three__animation-5">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/line-5.png" alt="line shape">
                </div>
            <?php endif; ?>

            <div class="container">
                <div class="row">
                    <div class="col-xl-12">
                        <div class="hero-style-three__content text-center">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>

                            <div class="slider__form wow fadeInUp" data-wow-delay=".5s">
                                <form method="get" action="<?php print esc_url( home_url( '/' ) );?>">
                                    <div class="slider__form-wrapper flex-wrap">

                                        <div class="slider__form-input">
                                            <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php echo rrdevs_kses( $settings['form_02_placeholder_text'] ); ?>">
                                        </div>

                                        <div class="slider__form-input has-select">
                                            <select style="display: none;">
                                                <option value="1">google.com.bd</option>
                                                <option value="2">Wedding</option>
                                                <option value="3">Photography</option>
                                                <option value="4">Consulting</option>
                                            </select>
                                            <div class="nice-select" tabindex="0"><span class="current">google.com.bd</span>
                                                <ul class="list">
                                                    <li data-value="1" class="option selected focus">google.com.bd</li>
                                                    <li data-value="2" class="option">Wedding</li>
                                                    <li data-value="3" class="option">Photography</li>
                                                    <li data-value="4" class="option">Consulting</li>
                                                </ul>
                                            </div>
                                        </div>

                                        <?php if (!empty($settings['seoq_form_02_btn_text'])) : ?>
                                        <div class="slider__form-input">
                                            <button type="button" class="slider-form-btn tp-link-btn-3 rr-bounce-up"><?php echo $settings['seoq_form_02_btn_text']; ?></button>
                                        </div>
                                        <?php endif; ?>
                                    </div>
                                </form>
                            </div>
                            <div class="row justify-content-center wow fadeInUp" data-wow-delay=".7s">
                                <div class="col-xl-10">
                                    <div class="brand-one brand-one__active owl-carousel pt-75">
                                        <?php foreach ($settings['seoq_brand_slides'] as $item) : 
                                            if ( !empty($item['seoq_brand_image']['url']) ) {
                                                $seoq_brand_image_url = !empty($item['seoq_brand_image']['id']) ? wp_get_attachment_image_url( $item['seoq_brand_image']['id']) : $item['seoq_brand_image']['url'];
                                                $seoq_brand_image_alt = get_post_meta($item["seoq_brand_image"]["id"], "_wp_attachment_image_alt", true);
                                            }
                                            ?>
                                            <div class="brand-one__single">
                                                <a href="#"><img src="<?php echo esc_url($seoq_brand_image_url); ?>" alt="<?php echo esc_url($seoq_brand_image_alt); ?>"></a>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- hero three end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-4' ):
            $this->add_render_attribute('title_args', 'class', 'wow fadeInUp section-title__title');
            $this->add_render_attribute('title_args', 'data-wow-delay', '.3s');

            if ( !empty($settings['seoq_hero_04_image']['url']) ) {
                $seoq_hero_04_image = !empty($settings['seoq_hero_04_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_hero_04_image']['id'], 'full') : $settings['seoq_hero_04_image']['url'];
                $seoq_hero_04_image_alt = get_post_meta($settings["seoq_hero_04_image"]["id"], "_wp_attachment_image_alt", true);
            }
        ?>

        <!-- hero four start -->
        <div class="hero-four d-flex align-items-end">
            <?php if(!empty($settings['seoq_shape_switch'])) : ?>
                <div class="hero-four__img-1">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/4.svg" alt="shape img">
                </div>
                <div class="hero-four__img-2">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/2.svg" alt="shape img">
                </div>
                <div class="hero-four__img-3">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/3.svg" alt="shape img">
                </div>
                <div class="hero-four__img-4">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/1.svg" alt="shape img">
                </div>
                <div class="hero-four__img-5">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/10.svg" alt="shape img">
                </div>
                <div class="hero-four__img-6">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-6.png" alt="shape">
                </div>
                <div class="hero-four__img-7">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-7.png" alt="shape">
                </div>
            <?php endif; ?>

            <div class="container">
                <div class="row align-items-end">
                    <div class="col-xxl-6 col-xl-7">
                        <div class="hero-four__content">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>

                            <?php if ( !empty($settings['seoq_description']) ) : ?>
                            <p class="wow fadeInUp" data-wow-delay=".5s"><?php echo rrdevs_kses( $settings['seoq_description'] ); ?></p>
                            <?php endif; ?>

                            <form method="get" action="<?php print esc_url( home_url( '/' ) );?>" class="wow fadeInUp" data-wow-delay=".7s">
                                <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php echo rrdevs_kses( $settings['form_03_placeholder_text'] ); ?>">

                                <?php if (!empty($settings['seoq_form_03_btn_text'])) : ?>
                                <button type="submit" class="rr-btn-style-1"><?php echo $settings['seoq_form_03_btn_text']; ?></button>
                                <?php endif; ?>
                            </form>
                        </div>
                    </div>
                    <div class="col-xxl-6 col-xl-5 text-center text-xl-end">
                        <div class="hero-four__right">
                            <div class="hero-four__img wow fadeInRight" data-wow-delay=".7s">

                                <div class="hero-four__img0">
                                    <img src="<?php echo esc_url($seoq_hero_04_image); ?>" alt="hero img">
                                </div>

                                <?php if(!empty($settings['seoq_shape_image_switch'])) : ?>
                                <div class="hero-four__img1">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-1.png" alt="shape">
                                </div>
                                <div class="hero-four__img2">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-2.png" alt="shape">
                                </div>
                                <div class="hero-four__img3">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-3.png" alt="shape">
                                </div>
                                <div class="hero-four__img4">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-4.png" alt="shape">
                                </div>
                                <div class="hero-four__img5">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/hero/hero-4-5.png" alt="shape">
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- hero four end -->


        <?php endif; ?>

		<?php
	}
}

$widgets_manager->register( new SEOQ_Hero() );