<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Control_Media;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Horizontal_Accordion extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_horizontal_accordion';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Horizontal Accordion', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_title_button',
            [
                'label' => esc_html__('Tittle & Button', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('We Have 25 Years Of Experience In This Field', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        ); 
        
        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_control(
			'seoq_all_project_button',
			[
				'label' => esc_html__( 'Additional Options', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
			'seoq_all_project_button_title',
			[
				'label' => esc_html__( 'Button Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'seoq-core' ),
			]
		);

        $this->add_control(
			'seoq_all_project_link',
			[
				'label' => esc_html__( 'Link', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'options' => [ 'url', 'is_external', 'nofollow' ],
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'label_block' => true,
			]
		);


        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_project_lists',
            [
                'label' => esc_html__('Project Lists', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
			'seoq_category',
			[
				'label' => esc_html__( 'Category Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'seoq-core' ),
			]
		);

        $repeater->add_control(
            'seoq_image_slider',
            [
                'label' => esc_html__( 'Featured Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
			'seoq_project_title',
			[
				'label' => esc_html__( 'Project Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'seoq-core' ),
                'label_block' => true,
			]
		);
     
        $this->add_control(
            'seoq_projects_list',
            [
                'label' => esc_html__('Info List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_image_slider' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_image_slider' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_image_slider' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_image_slider' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_image_slider' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ],
                'title_field' => '{{{ seoq_category }}}',
            ]
        );
        $this->end_controls_section();


        // Style tab
        $this->start_controls_section(
            'content_style',
            [
                'label' => __( 'Content', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .horizontal-accordion' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
					'top' => 120,
					'right' => 0,
					'bottom' => 120,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false,
				],
            ]
        );

        $this->add_control(
            'content_bg_color',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .horizontal-accordion' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        // Button Style
        $this->start_controls_section(
            '_section_title_button_style',
            [
                'label' => __( 'Title & Button', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'seoq_title_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'seoq_title_typography',
				'selector' => '{{WRAPPER}} .section-title__two-title',
			]
		);

        $this->add_control(
			'seoq_button_heading',
			[
				'label' => esc_html__( 'Button Style', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->start_controls_tabs(
            'seoq_button_style_tabs'
        );
        
        $this->start_controls_tab(
            'seoq_button_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'seoq_button_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-right a.rr-bounce-up' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'seoq_button_bg_color',
            [
                'label' => __( 'Backgrund', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-right a.rr-bounce-up' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'seoq_button_typography',
				'selector' => '{{WRAPPER}} .section-title__two-right a.rr-bounce-up',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'seoq_button_border',
				'selector' => '{{WRAPPER}} .section-title__two-right a.rr-bounce-up',
			]
		);

        $this->add_responsive_control(
            'seoq_button_padding',
            [
                'label' => __( 'Button Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-right a.rr-bounce-up' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
					'top' => 21,
					'right' => 43,
					'bottom' => 21,
					'left' => 43,
					'unit' => 'px',
					'isLinked' => false,
				],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'seoq_button_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'seoq_button_color_hover',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-right a.rr-bounce-up:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'seoq_button_bg_color_hover',
            [
                'label' => __( 'Backgrund', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-right a.rr-bounce-up:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'seoq_button_typography_hover',
				'selector' => '{{WRAPPER}} .section-title__two-right a.rr-bounce-up:hover',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'seoq_button_border_hover',
				'selector' => '{{WRAPPER}} .section-title__two-right a.rr-bounce-up:hover',
			]
		);

        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->end_controls_section();

        // Projects Style
        $this->start_controls_section(
            '_projects_list_style',
            [
                'label' => __( 'Projects List', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'projects_list_title',
			[
				'label' => esc_html__( 'List Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

        $this->add_control(
            'projects_list_title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-panel-content .rr-panel-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'projects_list_title_typography',
				'selector' => '{{WRAPPER}} .rr-panel-content .rr-panel-title',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'projects_list_title_border',
				'selector' => '{{WRAPPER}} .col-custom',
			]
		);

        $this->add_control(
            '_content_project_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Project Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'project_title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-panel-content-2 .rr-panel-content__img h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'project_title_typography',
				'selector' => '{{WRAPPER}} .rr-panel-content-2 .rr-panel-content__img h3',
			]
		);

        $this->add_control(
            'project_category_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Category', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'project_category_title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .col-custom.active .rr-panel-title-2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'project_category_title_bg_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .col-custom.active .rr-panel-title-2' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'project_category_title_typography',
				'selector' => '{{WRAPPER}} .col-custom.active .rr-panel-title-2',
			]
		);

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $this->add_render_attribute('title_args', 'class', 'section-title__two-title');

		?>

        <div class="horizontal-accordion">
            <div class="container">
                <div class="row">
                    <div class="col-xxl-12">
                        <div class="section-title__two d__column-two mb-50 wow fadeInUp" data-wow-delay=".3s">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>
                            <div class="section-title__two-right">
                                <?php if(!empty($settings['seoq_all_project_button_title'])): ?>
                                    <a href="<?php echo rrdevs_kses($settings['seoq_all_project_link']['url']); ?>" class="thm-btn-2 rr-bounce-up"><?php echo rrdevs_kses($settings['seoq_all_project_button_title']); ?></a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <div class="row-custom-wrapper wow fadeInUp" data-wow-delay=".5s">
                        <div class="row-custom">
                            <?php 
                                if($settings['seoq_projects_list']):
                                    foreach ($settings['seoq_projects_list'] as $index => $item) :
                            ?>
                                <div class="col-custom <?php echo ($index==0) ? "active" : ""; ?>">
                                    <div class="rr-panel-item">
                                        <div class="rr-panel-content">
                                            <?php if(!empty($item['seoq_category'])):
                                                $num = '0' . $index + 1 . ". ";
                                                ?>
                                                <h4 class="rr-panel-title child-one"><?php echo $num . rrdevs_kses($item['seoq_category']); ?></h4>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <div class="rr-panel-item-2">
                                        <div class="rr-panel-content-2">
                                            <?php if(!empty($item['seoq_category'])): ?>
                                                <h4 class="rr-panel-title-2"><?php echo rrdevs_kses($item['seoq_category']); ?></h4>
                                            <?php endif; ?>
                                            <div class="rr-panel-content__img">
                                                <?php if ( !empty($item['seoq_image_slider']['url']) ): ?>
                                                    <img src="<?php echo $item['seoq_image_slider']['url']; ?>" alt="<?php echo $item['seoq_image_slider']['alt']; ?>">
                                                <?php endif; ?>
                                                <?php if ( !empty($item['seoq_project_title']) ): ?>
                                                    <h3><?php echo  rrdevs_kses($item['seoq_project_title']); ?></h3>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Horizontal_Accordion() );