<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Control_Media;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Image extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Image', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_image_content',
            [
                'label' => esc_html__('Image', 'seoq-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'seoq_image_two',
            [
                'label' => esc_html__( 'Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_image_style',
            [
                'label' => __( 'Image', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' => __( 'Border Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-two__img2::before' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'large') : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

        if ( !empty($settings['seoq_image_two']['url']) ) {
            $seoq_image_two = !empty($settings['seoq_image_two']['id']) ? wp_get_attachment_image_url( $settings['seoq_image_two']['id'], 'large') : $settings['seoq_image_two']['url'];
            $seoq_image_two_alt = get_post_meta($settings["seoq_image_two"]["id"], "_wp_attachment_image_alt", true);
        }

		?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>

            <div class="service-details__top-img">
                <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_url($seoq_image_alt); ?>" />
            </div>
        
        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>

            <div class="about-two__img clearfix">
                <div class="about-two__img1 wow slideInLeft" data-wow-delay="100ms" data-wow-duration="2500ms">
                    <div class="about-two__img1-inner">
                        <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_url($seoq_image_alt); ?>" />
                    </div>
                </div>
                <div class="about-two__img2 wow zoomIn" data-wow-delay="100ms" data-wow-duration="3500ms">
                    <div class="about-two__img2-inner">
                        <img src="<?php echo esc_url($seoq_image_two); ?>" alt="<?php echo esc_url($seoq_image_two_alt); ?>" />
                    </div>
                </div>
            </div>

        <?php endif; ?>

        <?php 
	}
}

$widgets_manager->register( new seoq_Image() );