<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Integrations extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_integrations';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Integrations', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_integrations',
            [
                'label' => esc_html__('Gallery Info', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_integrations_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__('SEO Ranking Integrations
                ', 'seoq-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_integrations_gallery_title', [
                'label' => esc_html__('Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
			'seoq_integrations_gallery_image',
			[
				'label' => esc_html__( 'Choose Image', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);

        $this->add_control(
            'seoq_integrations_gallery_list',
            [
                'label' => esc_html__('Gallery', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Google', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Hubspot', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Slack', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Github', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Dropbox', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Star', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Wix', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Zoom', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Interlock', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Quickbooks', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    [
                        'seoq_integrations_gallery_title' => esc_html__('Mailchimp', 'seoq-core'),
                        'seoq_integrations_gallery_image' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                ],
                'title_field' => '{{{ seoq_integrations_gallery_title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_layout_style',
            [
                'label' => __( 'Design Layout', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'integrations_bg_image',
			[
				'label' => esc_html__( 'Choose Background Image', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);  

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_gallery_style',
            [
                'label' => __( 'Content Style', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'integrations_title',
			[
				'label' => esc_html__( 'Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

        $this->add_control(
            'integrations_title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .integrations-map-one .section-title__one-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'integrations_title_typography',
                'selector' => '{{WRAPPER}} .integrations-map-one .section-title__one-title',
            ]
        );

        $this->add_control(
			'integrations_logo',
			[
				'label' => esc_html__( 'Logo Background', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_control(
            'integrations_logo_bg_color',
            [
                'label' => __( 'Logo Background Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .integrations-map-one__wrapper .img_div' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>
        <div class="integrations-map-one">
            <div class="integrations-map-one__wrapper">
                <div class="integrations-map-one__img">
                    <?php if(!empty($settings['integrations_bg_image'])): ?>
                        <img src="<?php echo $settings['integrations_bg_image']['url'] ?>" alt="<?php echo $settings['integrations_bg_image']['url'] ?>">
                    <?php endif; ?>
                </div>
                <div class="section-title__one text-center mb-70 integrations-heading">
                    <?php if(!empty($settings['seoq_integrations_title'])): ?>
                        <h2 class="section-title__one-title"><?php echo rrdevs_kses($settings['seoq_integrations_title' ]); ?></h2>
                    <?php endif; ?>
                </div>
                <?php 
                    if(!empty($settings['seoq_integrations_gallery_list'])):
                        foreach ($settings['seoq_integrations_gallery_list'] as $x => $item):
                            
                ?>
                    <div class="integrations-map-one__item<?php echo $x; ?> img_div wow fadeInUp" data-wow-delay=".3s">
                        <?php 
                            if($item['seoq_integrations_gallery_image']['url']):
                        ?>
                            <img src="<?php echo $item['seoq_integrations_gallery_image']['url']; ?>" alt="<?php echo $item['seoq_integrations_gallery_image']['alt']; ?>">
                        <?php endif; ?>
                        <div class="ripple"></div>
                    </div>
                <?php endforeach; endif; ?>
            </div>
        </div>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Integrations() );