<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Post_List extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_post_list';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Post', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                    'layout-3' => esc_html__('Layout 3', 'seoq-core'),
                    'layout-4' => esc_html__('Layout 4', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();

        // Blog Query
		$this->start_controls_section(
            'seoq_post_query',
            [
                'label' => esc_html__('Blog Query', 'seoq-core'),
            ]
        );

        $post_type = 'post';
        $taxonomy = 'category';

        $this->add_control(
            'posts_per_page',
            [
                'label' => esc_html__('Posts Per Page', 'seoq-core'),
                'description' => esc_html__('Leave blank or enter -1 for all.', 'seoq-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => '3',
            ]
        );

        $this->add_control(
            'category',
            [
                'label' => esc_html__('Include Categories', 'seoq-core'),
                'description' => esc_html__('Select a category to include or leave blank for all.', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => seoq_get_categories($taxonomy),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'exclude_category',
            [
                'label' => esc_html__('Exclude Categories', 'seoq-core'),
                'description' => esc_html__('Select a category to exclude', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => seoq_get_categories($taxonomy),
                'label_block' => true
            ]
        );

        $this->add_control(
            'post__not_in',
            [
                'label' => esc_html__('Exclude Item', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'options' => seoq_get_all_types_post($post_type),
                'multiple' => true,
                'label_block' => true
            ]
        );

        $this->add_control(
            'offset',
            [
                'label' => esc_html__('Offset', 'seoq-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => '0',
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => array(
			        'ID' => 'Post ID',
			        'author' => 'Post Author',
			        'title' => 'Title',
			        'date' => 'Date',
			        'modified' => 'Last Modified Date',
			        'parent' => 'Parent Id',
			        'rand' => 'Random',
			        'comment_count' => 'Comment Count',
			        'menu_order' => 'Menu Order',
			    ),
                'default' => 'date',
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__('Order', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', 'seoq-core' ),
                    'desc' 	=> esc_html__( 'Descending', 'seoq-core' )
                ],
                'default' => 'desc',

            ]
        );
        $this->add_control(
            'ignore_sticky_posts',
            [
                'label' => esc_html__( 'Ignore Sticky Posts', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_blog_title_word',
            [
                'label' => esc_html__('Title Word Count', 'seoq-core'),
                'description' => esc_html__('Set how many word you want to displa!', 'seoq-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );

        $this->add_control(
            'seoq_post_content',
            [
                'label' => __('Content', 'seoq-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'seoq-core'),
                'label_off' => __('Hide', 'seoq-core'),
                'return_value' => 'yes',
                'default' => '',
            ]
        );

        $this->add_control(
            'seoq_post_content_limit',
            [
                'label' => __('Content Limit', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => '14',
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'seoq_post_content' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'seoq_btn_button_show',
            [
                'label' => esc_html__( 'Show Button', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'seoq-core'),
                'title' => esc_html__('Enter button text here', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_btn_button_show' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'seoq_social_switch',
            [
                'label' => esc_html__( 'Show/Hide Social', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'seoq-core' ),
                'label_off' => esc_html__( 'Hide', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'seoq_design_style' => ['layout-1'],
                ],
            ]
        );

        $this->end_controls_section();

        // Social Icon
		$this->start_controls_section(
            'seoq_blog_social_icon',
            [
                'label' => esc_html__('Blog Social', 'seoq-core'),
                'condition' => [
                    'seoq_design_style' => ['layout-1'],
                ],
            ]
        );

        $this->add_control(
            'web_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Website Address', 'seoq-core' ),
                'placeholder' => __( 'Add your profile link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'email_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Email', 'seoq-core' ),
                'placeholder' => __( 'Add your email link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'phone_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Phone', 'seoq-core' ),
                'placeholder' => __( 'Add your phone link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'facebook_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Facebook', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Add your facebook link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'twitter_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Twitter', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Add your twitter link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'instagram_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Instagram', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Add your instagram link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'linkedin_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'LinkedIn', 'seoq-core' ),
                'placeholder' => __( 'Add your linkedin link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'youtube_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Youtube', 'seoq-core' ),
                'placeholder' => __( 'Add your youtube link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'flickr_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Flickr', 'seoq-core' ),
                'placeholder' => __( 'Add your flickr link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'vimeo_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Vimeo', 'seoq-core' ),
                'placeholder' => __( 'Add your vimeo link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'behance_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Behance', 'seoq-core' ),
                'placeholder' => __( 'Add your hehance link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'dribble_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Dribbble', 'seoq-core' ),
                'placeholder' => __( 'Add your dribbble link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'pinterest_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Pinterest', 'seoq-core' ),
                'placeholder' => __( 'Add your pinterest link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'gitub_title',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => false,
                'label' => __( 'Github', 'seoq-core' ),
                'placeholder' => __( 'Add your github link', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->end_controls_section();


        // Style Control Start
        $this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'seoq_design_style' => ['layout-1','layout-2','layout-3'],
                ],
			]
		);

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .hm-news-latter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .hm-3-new-articles__item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'condition' => [
                        'seoq_design_style' => ['layout-1','layout-2','layout-3'],
                    ],
                ],
            ]
        );

        $this->add_responsive_control(
            'content_margin',
            [
                'label' => __( 'Content Margin', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .hm-news-latter' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .hm-3-new-articles__item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'condition' => [
                        'seoq_design_style' => ['layout-1','layout-2','layout-3'],
                    ],
                ],
            ]
        );

        $this->add_control(
            'content_background_color',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hm-news-latter' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .hm-3-new-articles__item' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => ['layout-1','layout-2','layout-3'],
                ],
            ]
        );

        $this->end_controls_section();

        // Blog Query Style Control
		$this->start_controls_section(
			'seoq_post_query_style',
			[
				'label' => __( 'Blog Query', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		// Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .blog-one__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .blog__item h4 a' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blog-one__title a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .blog__item h4 a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_color_hover',
            [
                'label' => __( 'Color (Hover)', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hm-news-latter__card:hover .blog-one__title a' => 'color: {{VALUE}}!important',
                    '{{WRAPPER}} .blog-one__title:hover' => 'color: {{VALUE}}!important',
                    '{{WRAPPER}} .blog__item h4 a:hover' => 'color: {{VALUE}}!important',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .blog-one__title, .blog__item h4 a',
            ]
        );

		// Meta
        $this->add_control(
            '_heading_meta',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Meta', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'meta_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .icon-wrapper i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .icon-wrapper i span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hm-3-new-articles__item .info p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .hm-3-new-articles__item .info span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .post-author a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'meta_typography',
                'selector' => '
                {{WRAPPER}} .icon-wrapper i,
                {{WRAPPER}} .post-author a,
                {{WRAPPER}} .icon-wrapper i span,
                {{WRAPPER}} .hm-3-new-articles__item .info p,
                {{WRAPPER}} .hm-3-new-articles__item .info span',
            ]
        );

        // Button
        $this->add_control(
            '_content_link',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Button', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'link_color',
            [
                'label' => __( 'Button Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-green' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .red-more' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .blog__item .btn-link-share a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'link_color_hover',
            [
                'label' => __( 'Button Hover Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-green:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .red-more:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .blog__item .btn-link-share a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label'     => esc_html__( 'Button Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-green' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .red-more' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .blog__item .btn-link-share a' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Button Hover Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-green:hover::after' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .red-more:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .blog__item .btn-link-share a:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'selector' =>
                '{{WRAPPER}} .btn-green',
                '{{WRAPPER}} .red-more',
                '{{WRAPPER}} .blog__item .btn-link-share a',
            ]
        );

		$this->end_controls_section();
	}


	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		if (get_query_var('paged')) {
            $paged = get_query_var('paged');
        } else if (get_query_var('page')) {
            $paged = get_query_var('page');
        } else {
            $paged = 1;
        }

        // include_categories
        $category_list = '';
        if (!empty($settings['category'])) {
            $category_list = implode(", ", $settings['category']);
        }
        $category_list_value = explode(" ", $category_list);

        // exclude_categories
        $exclude_categories = '';
        if(!empty($settings['exclude_category'])){
            $exclude_categories = implode(", ", $settings['exclude_category']);
        }
        $exclude_category_list_value = explode(" ", $exclude_categories);

        $post__not_in = '';
        if (!empty($settings['post__not_in'])) {
            $post__not_in = $settings['post__not_in'];
            $args['post__not_in'] = $post__not_in;
        }
        $posts_per_page = (!empty($settings['posts_per_page'])) ? $settings['posts_per_page'] : '-1';
        $orderby = (!empty($settings['orderby'])) ? $settings['orderby'] : 'post_date';
        $order = (!empty($settings['order'])) ? $settings['order'] : 'desc';
        $offset_value = (!empty($settings['offset'])) ? $settings['offset'] : '0';
        $ignore_sticky_posts = (! empty( $settings['ignore_sticky_posts'] ) && 'yes' == $settings['ignore_sticky_posts']) ? true : false ;


        // number
        $off = (!empty($offset_value)) ? $offset_value : 0;
        $offset = $off + (($paged - 1) * $posts_per_page);
        $p_ids = array();

        // build up the array
        if (!empty($settings['post__not_in'])) {
            foreach ($settings['post__not_in'] as $p_idsn) {
                $p_ids[] = $p_idsn;
            }
        }

        $args = array(
            'post_type' => 'post',
            'post_status' => 'publish',
            'posts_per_page' => $posts_per_page,
            'orderby' => $orderby,
            'order' => $order,
            'offset' => $offset,
            'paged' => $paged,
            'post__not_in' => $p_ids,
            'ignore_sticky_posts' => $ignore_sticky_posts
        );

        // exclude_categories
        if ( !empty($settings['exclude_category'])) {

            // Exclude the correct cats from tax_query
            $args['tax_query'] = array(
                array(
                    'taxonomy'	=> 'category',
                    'field'	 	=> 'slug',
                    'terms'		=> $exclude_category_list_value,
                    'operator'	=> 'NOT IN'
                )
            );

            // Include the correct cats in tax_query
            if ( !empty($settings['category'])) {
                $args['tax_query']['relation'] = 'AND';
                $args['tax_query'][] = array(
                    'taxonomy'	=> 'category',
                    'field'		=> 'slug',
                    'terms'		=> $category_list_value,
                    'operator'	=> 'IN'
                );
            }

        } else {
            // Include the cats from $cat_slugs in tax_query
            if (!empty($settings['category'])) {
                $args['tax_query'][] = [
                    'taxonomy' => 'category',
                    'field' => 'slug',
                    'terms' => $category_list_value,
                ];
            }
        }

        $filter_list = $settings['category'];

        // The Query
        $query = new \WP_Query($args);

        $this->add_render_attribute('title_args', 'class', 'sectionTitle__big seoq-el-title');
        $this->add_render_attribute('section_title_args', 'class', 'section-title__title');
        ?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
        <!-- blog two start -->
        <div class="blog-two">
            <div class="container">
                <div class="row">
                    <?php if ($query->have_posts()) : ?>
                        <?php while ($query->have_posts()) :
                        $query->the_post();
                        global $post;
                        $categories = get_the_category($post->ID);
                    ?>
                    <div class="col-xxl-4 col-xl-4 col-lg-6 col-md-12 col-sm-12">
                        <div class="blog-two__single mb-30 wow fadeInUp" data-wow-delay=".3s">
                            <div class="blog-two__single-content">

                                <div class="postbox__meta">
                                    <span><i class="fa-light fa-calendar-lines"></i><?php echo get_the_date("M d, Y"); ?></span>
                                </div>

                                <h2 class="blog-two__title"><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['seoq_blog_title_word'], ''); ?></a></h2>

                                <div class="row">
                                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-6">
                                        <?php if (!empty($settings['seoq_btn_button_show'])): ?>
                                        <a href="<?php the_permalink();?>" class="blog-two__btn"><?php print esc_html($settings['seoq_btn_text']);?> <i class="fa-solid fa-arrow-right"></i></a>
                                        <?php endif; ?>
                                    </div>

                                    <?php if(!empty($settings['seoq_social_switch'])) : ?>
                                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-6 text-end">
                                        <div class="share-icon">
                                            <a href="#"><i class="fa-light fa-share-nodes"></i></a>
                                            <div class="share-option__hover">
                                                <ul>
                                <?php if( !empty($settings['facebook_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['facebook_title'] ); ?>"><i class="fab fa-facebook"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['twitter_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['twitter_title'] ); ?>"><i class="fab fa-twitter"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['pinterest_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['pinterest_title'] ); ?>"><i class="fab fa-pinterest-p"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['instagram_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['instagram_title'] ); ?>"><i class="fab fa-instagram"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['linkedin_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['linkedin_title'] ); ?>"><i class="fab fa-linkedin-in"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['youtube_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['youtube_title'] ); ?>"><i class="fab fa-youtube"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['flickr_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['flickr_title'] ); ?>"><i class="fab fa-flickr"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['vimeo_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['vimeo_title'] ); ?>"><i class="fab fa-vimeo-v"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['behance_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['behance_title'] ); ?>"><i class="fab fa-behance"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['dribble_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['dribble_title'] ); ?>"><i class="fab fa-dribbble"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['phone_title'] ) ) : ?>
                                    <li><a href="tel:<?php echo esc_url( $settings['phone_title'] ); ?>"><i class="fas fa-phone-alt"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['gitub_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['gitub_title'] ); ?>"><i class="fab fa-github"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['web_title'] ) ) : ?>
                                    <li><a href="<?php echo esc_url( $settings['web_title'] ); ?>"><i class="fas fa-globe"></i></a></li>
                                <?php endif; ?>

                                <?php if( !empty($settings['email_title'] ) ) : ?>
                                    <li><a href="mailto:<?php echo esc_url( $settings['email_title'] ); ?>"><i class="fas fa-envelope"></i></a></li>
                                <?php endif; ?>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                        <?php endwhile; wp_reset_query(); ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- blog two end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ) : ?>
        <!-- blog three start -->
        <div class="blog-three">
            <div class="container">
                <div class="row">
                    <?php if ($query->have_posts()) : ?>
                    <?php while ($query->have_posts()) :
                        $query->the_post();
                        global $post;
                        $categories = get_the_category($post->ID);
                    ?>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6 col-sm-12 wow fadeInUp" data-wow-delay=".3s">
                        <div class="blog-three__single mb-30">
                            <div class="blog-three__img">
                                <?php the_post_thumbnail( $post->ID );?>
                                <div class="icon">
                                    <a href="<?php the_permalink(); ?>"><i class="fa-regular fa-arrow-up-right"></i></a>
                                </div>
                            </div>
                            <div class="blog-three__content">
                                <div class="post-meta">
                                    <ul>
                                        <li><?php echo get_the_date("M d, Y"); ?></li>
                                        <?php if ( ! empty( $categories ) ) {
                                             echo '<li> <a href="' . esc_url( get_category_link($categories[0]->term_id ) ) . '">' . esc_html( $categories[0]->name ) . '</a> </li>';
                                            }
                                        ?>
                                    </ul>
                                </div>
                                <h2 class="blog-three_title"><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['seoq_blog_title_word'], ''); ?></a></h2>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; wp_reset_query(); ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- blog three end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-3' ) : ?>
        <!-- blog four start -->
        <div class="blog-four">
            <div class="container">
                <div class="row">
                    <?php if ($query->have_posts()) : ?>
                        <?php while ($query->have_posts()) :
                        $query->the_post();
                        global $post;
                        $categories = get_the_category($post->ID);
                    ?>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12 wow fadeInUp" data-wow-delay=".3s">
                        <div class="blog-four__single mb-30">
                            <div class="blog-four__img">
                                <?php the_post_thumbnail( $post->ID );?>
                                <div class="category">
                                <?php if ( ! empty( $categories ) ) {
                                    echo '<a href="' . esc_url( get_category_link($categories[0]->term_id ) ) . '">' . esc_html( $categories[0]->name ) . '</a>';
                                    }
                                ?>
                                </div>
                            </div>

                            <div class="blog-four__content">
                                <div class="post-meta">
                                    <ul>
                                        <li><i class="fa-light fa-calendar-lines"></i><?php echo get_the_date("M d, Y"); ?></li>
                                    </ul>
                                </div>
                                <h2 class="blog-four_title">
                                    <a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['seoq_blog_title_word'], ''); ?></a>
                                </h2>
                                <?php if (!empty($settings['seoq_btn_button_show'])): ?>
                                <a href="<?php the_permalink(); ?>" class="tp-btn postbox__more-btn"><?php print esc_html($settings['seoq_btn_text']);?> <i class="fa-solid fa-arrow-right"></i></a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                        <?php endwhile; wp_reset_query(); ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- blog four end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-4' ) : ?>
        <!-- blog one start -->
        <div class="blog-one">
            <div class="container">
                <div class="row">
                    <?php if ($query->have_posts()) : ?>
                        <?php while ($query->have_posts()) :
                        $query->the_post();
                        global $post;
                        $categories = get_the_category($post->ID);
                    ?>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6 col-sm-12 wow fadeInUp" data-wow-delay=".3s">
                        <div class="blog-grid__single mb-30">
                            <div class="blog-grid__single-img">
                                <a href="<?php the_permalink();?>">
                                    <?php the_post_thumbnail( $post->ID );?>
                                </a>
                            </div>
                            <div class="blog-grid__single-content blog-style-4">
                                <div class="postbox__meta">
                                    <span><i class="fa-light fa-calendar-lines"></i><?php echo get_the_date("M d, Y"); ?></span>
                                </div>

                                <h2><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['seoq_blog_title_word'], ''); ?></a></h2>

                                <?php if (!empty($settings['seoq_btn_button_show'])): ?>
                                <div class="btn-box postbox__read-more">
                                    <a href="<?php the_permalink();?>" class="rr-btn postbox__more-btn"><?php print esc_html($settings['seoq_btn_text']);?> <i class="fa-solid fa-arrow-right"></i></a>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; wp_reset_query(); ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- blog one end -->
        <?php endif; ?>
       <?php
	}

}

$widgets_manager->register( new SEOQ_Post_List() );