<?php
namespace SEOQCore\Widgets;

use Elementor\Widget_Base;
use \Elementor\Repeater;
use \Elementor\Control_Media;
use \Elementor\Utils;
Use \Elementor\Core\Schemes\Typography;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Image_Size;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Pricing extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_pricing';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // Header
        $this->start_controls_section(
            '_section_header',
            [
                'label' => __('Header', 'seoq-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __('Title', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => __('Silver Pack', 'seoq-core'),
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $this->add_control(
            'trail',
            [
                'label' => __('Trail', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => __('Get 7 Days Free Trial', 'seoq-core'),
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_pricing',
            [
                'label' => __('Pricing', 'seoq-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'currency',
            [
                'label' => __('Currency', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    '' => __('None', 'seoq-core'),
                    'baht' => '&#3647; ' . _x('Baht', 'Currency Symbol', 'seoq-core'),
                    'bdt' => '&#2547; ' . _x('BD Taka', 'Currency Symbol', 'seoq-core'),
                    'dollar' => '&#36; ' . _x('Dollar', 'Currency Symbol', 'seoq-core'),
                    'euro' => '&#128; ' . _x('Euro', 'Currency Symbol', 'seoq-core'),
                    'franc' => '&#8355; ' . _x('Franc', 'Currency Symbol', 'seoq-core'),
                    'guilder' => '&fnof; ' . _x('Guilder', 'Currency Symbol', 'seoq-core'),
                    'krona' => 'kr ' . _x('Krona', 'Currency Symbol', 'seoq-core'),
                    'lira' => '&#8356; ' . _x('Lira', 'Currency Symbol', 'seoq-core'),
                    'peseta' => '&#8359 ' . _x('Peseta', 'Currency Symbol', 'seoq-core'),
                    'peso' => '&#8369; ' . _x('Peso', 'Currency Symbol', 'seoq-core'),
                    'pound' => '&#163; ' . _x('Pound Sterling', 'Currency Symbol', 'seoq-core'),
                    'real' => 'R$ ' . _x('Real', 'Currency Symbol', 'seoq-core'),
                    'ruble' => '&#8381; ' . _x('Ruble', 'Currency Symbol', 'seoq-core'),
                    'rupee' => '&#8360; ' . _x('Rupee', 'Currency Symbol', 'seoq-core'),
                    'indian_rupee' => '&#8377; ' . _x('Rupee (Indian)', 'Currency Symbol', 'seoq-core'),
                    'shekel' => '&#8362; ' . _x('Shekel', 'Currency Symbol', 'seoq-core'),
                    'won' => '&#8361; ' . _x('Won', 'Currency Symbol', 'seoq-core'),
                    'yen' => '&#165; ' . _x('Yen/Yuan', 'Currency Symbol', 'seoq-core'),
                    'custom' => __('Custom', 'seoq-core'),
                ],
                'default' => 'dollar',
            ]
        );

        $this->add_control(
            'currency_custom',
            [
                'label' => __('Custom Symbol', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'currency' => 'custom',
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'price',
            [
                'label' => __('Price', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => '11.99',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $this->add_control(
            'period',
            [
                'label' => __('Period', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Per Hour', 'seoq-core'),
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_features',
            [
                'label' => __('Features', 'seoq-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'single_features_icon',
            [
                'label'       => esc_html__( 'Icon', 'mentor-pricing-table' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-check-circle',
                    'library' => 'solid',
                ],
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'single_features_icon_color',
            [
                'label'       => esc_html__( 'Icon Color', 'mentor-pricing-table' ),
                'type'        => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'text',
            [
                'label' => __('Text', 'seoq-core'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Exciting Feature', 'seoq-core'),
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $repeater->add_control(
            'single_features_del',
            [
                'label'       => esc_html__( 'Delete Sign', 'mentor-pricing-table' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'no',
                'label_block' => false,
                'options'     => [
                    'no'  => esc_html__( 'No', 'mentor-pricing-table' ),
                    'del' => esc_html__( 'Yes', 'mentor-pricing-table' ),
                ],
            ]
        );

        $repeater->add_control(
            'single_features_del_color',
            [
                'label'       => esc_html__( 'Delete Color', 'mentor-pricing-table' ),
                'type'        => Controls_Manager::COLOR,
                'default'     => "#222",
                'selectors'   => [
                    '{{WRAPPER}} .del' => 'text-decoration-color: {{VALUE}};',
                ],
                'condition'   => [
                    'single_features_del' => ['del'],
                ],
            ]
        );

        $repeater->add_control(
            'single_features_color',
            [
                'label'     => esc_html__( 'Color', 'mentor-pricing-table' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} > span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'features_list',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'show_label' => false,
                'default' => [
                    [
                        'text' => __('Trained Cleane', 'seoq-core'),
                    ],
                    [
                        'text' => __('Maintenance Cleaning', 'seoq-core'),
                    ],
                    [
                        'text' => __('Liability Insurance', 'seoq-core'),
                    ],
                    [
                        'text' => __('Planned Holiday', 'seoq-core'),
                    ],
                    [
                        'text' => __('Feedback Centre Access', 'seoq-core'),
                    ],
                ],
                'title_field' => '<# print((text)); #>',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'ribbon_content',
            [
                'label' => esc_html__( 'Ribbon', 'mentor-pricing-table' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'ribbon_switch',
            [
                'label' => esc_html__( 'Ribbon', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'ribbon_text',
            [
                'label' => __('Text', 'seoq-core'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Most Popular', 'seoq-core'),
                'dynamic' => [
                    'active' => true
                ],
                'condition' => [
                    'ribbon_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

		// seoq_btn_button_group
        $this->start_controls_section(
            'seoq_btn_button_group',
            [
                'label' => esc_html__('Button', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Get Started', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'seoq_btn_link_type',
            [
                'label' => esc_html__('Button Link Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_link',
            [
                'label' => esc_html__('Button link', 'seoq-core'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'seoq-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'seoq_btn_link_type' => '1',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'seoq_btn_page_link',
            [
                'label' => esc_html__('Select Button Page', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_btn_link_type' => '2',
                ]
            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_margin',
            [
                'label' => __( 'Content Margin', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_background_color',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'content_border',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_header_style',
            [
                'label' => esc_html__('Header', 'seoq-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'header_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header span'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'header_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-header span',
            ]
        );

        $this->add_responsive_control(
            'header_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header span' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_pricing_style',
            [
                'label' => esc_html__('Pricing', 'seoq-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'pricing_options',
            [
                'label' => esc_html__( 'Pricing Options', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'pricing_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header h2'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'pricing_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-header h2',
            ]
        );

        $this->add_responsive_control(
            'pricing_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'pricing_duration_options',
            [
                'label' => esc_html__( 'Duration Options', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'pricing_duration_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header h2 span'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'pricing_duration_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-header h2 span',
            ]
        );

        $this->add_responsive_control(
            'pricing_duration_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .table-header h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'pricing_trial_options',
            [
                'label' => esc_html__( 'Trial Options', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'pricing_trial_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header p'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'pricing_trial_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-header p',
            ]
        );

        $this->add_responsive_control(
            'pricing_trial_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'pricing_duration_border',
            [
                'label'     => esc_html__( 'Border Bottom', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header' => 'border-bottom-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pricing_trial_border_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-header' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_features_list_style',
			[
				'label' => __( 'Features List', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'features_list_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-feature-list ul li' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'features_list_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-feature-list ul li span',
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
			'seoq_ribbon_style',
			[
				'label' => __( 'Ribbon', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'ribbon_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-badge' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'ribbon_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-badge' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'ribbon_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-badge',
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
			'seoq_button_style',
			[
				'label' => __( 'Button', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'button_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background_color',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a'    => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'button_border',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-bounce-up:hover' => 'color: {{VALUE}}!important;',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-bounce-up:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'button_border_hover',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .pricing-plan-one__single .pricing-btn a',
            ]
        );

		$this->end_controls_section();

	}

    private static function get_currency_symbol($symbol_name)
    {
        $symbols = [
            'baht' => '&#3647;',
            'bdt' => '&#2547;',
            'dollar' => '&#36;',
            'euro' => '&#128;',
            'franc' => '&#8355;',
            'guilder' => '&fnof;',
            'indian_rupee' => '&#8377;',
            'pound' => '&#163;',
            'peso' => '&#8369;',
            'peseta' => '&#8359',
            'lira' => '&#8356;',
            'ruble' => '&#8381;',
            'shekel' => '&#8362;',
            'rupee' => '&#8360;',
            'real' => 'R$',
            'krona' => 'kr',
            'won' => '&#8361;',
            'yen' => '&#165;',
        ];

        return isset($symbols[$symbol_name]) ? $symbols[$symbol_name] : '';
    }


	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

            // Link
            if ('2' == $settings['seoq_btn_link_type']) {
                $this->add_render_attribute('seoq-button-arg', 'href', get_permalink($settings['seoq_btn_page_link']));
                $this->add_render_attribute('seoq-button-arg', 'target', '_self');
                $this->add_render_attribute('seoq-button-arg', 'rel', 'nofollow');
                $this->add_render_attribute('seoq-button-arg', 'class', 'rr-bounce-up');
            } else {
                if ( ! empty( $settings['seoq_btn_link']['url'] ) ) {
                    $this->add_link_attributes( 'seoq-button-arg', $settings['seoq_btn_link'] );
                    $this->add_render_attribute('seoq-button-arg', 'class', 'rr-bounce-up');
                }
            }

	        if ($settings['currency'] === 'custom') {
	            $currency = $settings['currency_custom'];
	        } else {
	            $currency = self::get_currency_symbol($settings['currency']);
	        }
	        

		?>

            <div class="pricing-plan-one__single mb-30 text-start">
                <?php if ($settings['ribbon_switch']) : ?>
                    <div class="pricing-badge"><?php echo rrdevs_kses($settings['ribbon_text']); ?></div>
                <?php endif; ?>
                <div class="pricing-header">
                    <?php if ( !empty( $settings['title'] )) : ?>
                        <span><?php echo rrdevs_kses($settings['title']); ?></span>
                    <?php endif; ?>
                    <h2>
                        <?php echo esc_html($currency); ?><?php echo rrdevs_kses($settings['price']); ?>
                        <?php if ($settings['period']) : ?>
                            <span><?php echo rrdevs_kses($settings['period']); ?></span>
                        <?php endif; ?>
                    </h2>
                    <?php if ($settings['trail']) : ?>
                        <p><?php echo rrdevs_kses($settings['trail']); ?></p>
                    <?php endif; ?>
                </div>
                <div class="pricing-feature-list">
                    <ul class="list-unstyled">
                        <?php foreach ($settings['features_list'] as $index => $item) : ?>
                            <li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">
                                <span style="color: <?php echo esc_attr( $item['single_features_icon_color'] ); ?>">
                                    <?php \Elementor\Icons_Manager::render_icon( $item['single_features_icon'], ['aria-hidden' => 'true'] );?>
                                </span>
                                <span class="<?php echo esc_attr( $item['single_features_del'] ); ?>"><?php echo rrdevs_kses($item['text']); ?></span>
                            </li>
                        <?php endforeach; ?>
                        
                    </ul>
                </div>
                <div class="pricing-btn">
                    <a <?php echo $this->get_render_attribute_string( 'seoq-button-arg' ); ?>>
                        <?php echo $settings['seoq_btn_text']; ?>
                        <i class="fa-regular fa-arrow-right"></i>
                    </a>
                </div>
            </div>

        <?php
	}

}

$widgets_manager->register( new SEOQ_Pricing() );