<?php
namespace SEOQCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
Use \Elementor\Core\Schemes\Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Scroll_Card extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'scroll-card';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Scroll Card', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    // 'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                    // 'layout-3' => esc_html__('Layout 3', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();


        // Features group
        $this->start_controls_section(
            'seoq_scroll_card',
            [
                'label' => esc_html__('Scroll Card List', 'seoq-core'),
                'description' => esc_html__( 'Scroll Card List', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'repeater_condition',
            [
                'label' => __( 'Field condition', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __( 'Style 1', 'seoq-core' ),
                    // 'style_2' => __( 'Style 2', 'seoq-core' ),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'seoq_card_image',
            [
                'label' => esc_html__('Card Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ]
            ]
        );

        $repeater->add_control(
            'seoq_card_title', [
                'label' => esc_html__('Card Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Card Title', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'seoq_services_link_switcher',
            [
                'label' => esc_html__( 'Add link', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'seoq_services_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Button Text', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_services_link_switcher' => 'yes'
                ],
            ]
        );

        $repeater->add_control(
            'seoq_services_link_type',
            [
                'label' => esc_html__( 'Button Link Type', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'condition' => [
                    'seoq_services_link_switcher' => 'yes'
                ]
            ]
        );

        $repeater->add_control(
            'seoq_services_link',
            [
                'label' => esc_html__( 'Button Link', 'seoq-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'seoq-core' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'seoq_services_link_type' => '1',
                    'seoq_services_link_switcher' => 'yes',
                ]
            ]
        );

        $repeater->add_control(
            'seoq_services_page_link',
            [
                'label' => esc_html__( 'Select Button Link Page', 'seoq-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_services_link_type' => '2',
                    'seoq_services_link_switcher' => 'yes',
                ]
            ]
        );

        $this->add_control(
            'seoq_features_list',
            [
                'label' => esc_html__('Scroll Card - List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_card_title' => esc_html__('Unleashing Unmatched Power with Seamless Simplicity', 'seoq-core'),
                    ],
                    [
                        'seoq_card_title' => esc_html__('Unparalleled Power, Effortless Mastery', 'seoq-core')
                    ],
                    [
                        'seoq_card_title' => esc_html__('Insanely Powerfull. Easy to use', 'seoq-core')
                    ]
                ],
                'title_field' => '{{{ seoq_card_title }}}',
            ]
        );
        $this->end_controls_section();

        // Style Control
		$this->start_controls_section(
			'seoq_title_style',
			[
				'label' => __( 'Scroll Card Style Control', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .about-one__content .section-title' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__title',
            ]
        );

		$this->end_controls_section();


        // Button Style
        $this->start_controls_section(
			'seoq_button_style',
			[
				'label' => __( 'Button', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'button_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'button_box_shadow',
                'selector' => '{{WRAPPER}} .stack-card .stack-card__inner a',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a:after, .stack-card .stack-card__inner a:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'button_box_shadow_hover',
                'selector' => '{{WRAPPER}} .stack-card .stack-card__inner a:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .stack-card .stack-card__inner a',
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label'      => esc_html__( 'Padding', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button_margin',
            [
                'label'      => esc_html__( 'Margin', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .stack-card .stack-card__inner a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		    $settings = $this->get_settings_for_display();
		?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
        <!-- stack card one start -->
        <div class="stack-card">
            <div class="container">
                <div class="row">
                    <div class="col-12 fix-scroll">
                        <?php foreach ($settings['seoq_features_list'] as $item) :
                            if ( !empty($item['seoq_card_image']['url']) ) {
                                $seoq_card_image_url = !empty($item['seoq_card_image']['id']) ? wp_get_attachment_image_url( $item['seoq_card_image']['id'], 'full') : $item['seoq_card_image']['url'];
                                $seoq_card_image_alt = get_post_meta($item["seoq_card_image"]["id"], "_wp_attachment_image_alt", true);
                            }

                            // Link
                            if ('2' == $item['seoq_services_link_type']) {
                                $link = get_permalink($item['seoq_services_page_link']);
                                $target = '_self';
                                $rel = 'nofollow';
                            } else {
                                $link = !empty($item['seoq_services_link']['url']) ? $item['seoq_services_link']['url'] : '';
                                $target = !empty($item['seoq_services_link']['is_external']) ? '_blank' : '';
                                $rel = !empty($item['seoq_services_link']['nofollow']) ? 'nofollow' : '';
                            }
                        ?>
                        <div class="stack-card__inner wow fadeInUp" data-wow-duration="600ms" data-background="<?php echo esc_url($seoq_card_image_url); ?>">
                            <div class="row">
                                <div class="col-12 col-xl-8 col-xxl-7">
                                    <div class="stack-card__inner-content">
                                        <h2 class="section-title__title"><?php echo rrdevs_kses($item['seoq_card_title' ]); ?></h2>

                                        <a href="<?php echo esc_url($link); ?>">
                                        <?php echo rrdevs_kses( $item['seoq_services_btn_text'] ); ?> <i class="fa-regular fa-arrow-up-right"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
        <!-- stack card one end -->
        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>
            <section>

            </section>

        <?php
            endif;
	}
}

$widgets_manager->register( new SEOQ_Scroll_Card() );