<?php

namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Services extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'seoq_services';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Services', 'seoq-core' );
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'seoq-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'seoq_core' ];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends() {
        return [ 'seoq-services' ];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls() {

        // layout Panel
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );
        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__('Select Layout', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'seoq-core'),
                    'layout-2' => esc_html__('Layout 2', 'seoq-core'),
                    'layout-3' => esc_html__('Layout 3', 'seoq-core'),
                ],
                'default' => 'layout-1',
            ]
        );

        $this->end_controls_section();

        // Service lists for layout-1
        $this->start_controls_section(
            'seoq_services_1',
            [
                'label' => esc_html__('Services List', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => 'layout-1',
                ],
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'seoq_service_image',
            [
                'label' => esc_html__('Upload Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
			'seoq_service_image_bg',
			[
				'label' => esc_html__( 'Image Background', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);

		$repeater->add_control(
			'seoq_services_list_title',
			[
				'label' => esc_html__( 'Title', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'List Title' , 'seoq-core' ),
				'label_block' => true,
			]
		);

        $repeater->add_control(
            'template',
            [
                'label' => __('Section Template', 'seoq-core'),
                'placeholder' => __('Select a section template for as tab content', 'seoq-core'),
  
                'type' => Controls_Manager::SELECT2,
                'options' => get_elementor_templates()
            ]
        );

        $repeater->add_control(
			'seoq_button',
			[
				'label' => esc_html__( 'Button', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $repeater->add_control(
            'seoq_services_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Learn More', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
            ]
        );

        $repeater->add_control(
            'seoq_services_link_type',
            [
                'label' => esc_html__( 'Service Link Type', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
            ]
        );
        $repeater->add_control(
            'seoq_services_link',
            [
                'label' => esc_html__( 'Service Link link', 'seoq-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'seoq-core' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'seoq_services_link_type' => '1',
                ]
            ]
        );
        $repeater->add_control(
            'seoq_services_page_link',
            [
                'label' => esc_html__( 'Select Service Link Page', 'seoq-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_services_link_type' => '2',
                ]
            ]
        );

        $repeater->add_responsive_control(
            'seoq_services_border_radius',
            [
                'label' => __( 'Content Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .service-one__single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
			'seoq_service_lists',
			[
				'label' => esc_html__( 'Repeater List', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'seoq_services_list_title' => esc_html__( 'Title #1', 'seoq-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'seoq-core' ),
					],
					[
						'seoq_services_list_title' => esc_html__( 'Title #2', 'seoq-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'seoq-core' ),
					],
					[
						'seoq_services_list_title' => esc_html__( 'Title #2', 'seoq-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'seoq-core' ),
					],
					[
						'seoq_services_list_title' => esc_html__( 'Title #2', 'seoq-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'seoq-core' ),
					],
				],
				'title_field' => '{{{ seoq_services_list_title }}}',
			]
		);

        $this->end_controls_section();

        // Service group
        $this->start_controls_section(
            'seoq_services',
            [
                'label' => esc_html__('Services List', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'seoq_design_style' => ['layout-2', 'layout-3'],
                ],
            ]
        );

        $this->add_control(
			'seoq_service_image_icon_switcher',
			[
				'label' => esc_html__( 'Image Type', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'image' => esc_html__( 'Image', 'seoq-core' ),
					'icon' => esc_html__( 'Icon', 'seoq-core' ),
				],
			]
		);

        $this->add_control(
            'seoq_service_image',
            [
                'label' => esc_html__('Upload Image', 'seoq-core'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'seoq_service_image_icon_switcher' => 'image',
                ],
            ]
        );

        if (seoq_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'seoq_service_icon',
                [
                    'label' => esc_html__('Icon', 'seoq-core'),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'icon-house',
                    'condition' => [
                        'seoq_service_image_icon_switcher' => 'icon',
                    ],
                ]
            );
        } else {
            $this->add_control(
                'seoq_service_selected_icon',
                [
                    'label' => esc_html__('Icon', 'seoq-core'),
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'icon-house',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'seoq_service_image_icon_switcher' => 'icon',
                    ],
                ]
            );
        }
        $this->add_control(
            'seoq_service_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Bedroom Cleaning', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_service_description',
            [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('We provide janitorial and this <br> specialized is services.', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        ); 

        $this->add_control(
			'seoq_services_number',
			[
				'label' => esc_html__( 'Service Number', 'seoq-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '01', 'seoq-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
			]
		);

        $this->add_control(
            'seoq_services_link_switcher',
            [
                'label' => esc_html__( 'Add Services link', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'seoq_services_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_services_link_switcher' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'seoq_services_link_type',
            [
                'label' => esc_html__( 'Service Link Type', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'condition' => [
                    'seoq_services_link_switcher' => 'yes'
                ]
            ]
        );
        $this->add_control(
            'seoq_services_link',
            [
                'label' => esc_html__( 'Service Link link', 'seoq-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'seoq-core' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'seoq_services_link_type' => '1',
                    'seoq_services_link_switcher' => 'yes',
                ]
            ]
        );
        $this->add_control(
            'seoq_services_page_link',
            [
                'label' => esc_html__( 'Select Service Link Page', 'seoq-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_services_link_type' => '2',
                    'seoq_services_link_switcher' => 'yes',
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .service-two__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs(
            'content_background_color_tabs'
        );
        
        $this->start_controls_tab(
            'content_background_color_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'content_background_color_normal',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_border_radius',
            [
                'label' => __( 'Content Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .service-two__single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'content_background_color_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'content_background_color_hover',
            [
                'label' => __( 'Content Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_border_radius_hover',
            [
                'label' => __( 'Content Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .service-two__single:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // TAB_STYLE
        $this->start_controls_section(
            'seoq_services_list_style',
            [
                'label' => __( 'Services List', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            '_icon_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Icon', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => __( 'Icon Size', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'default' => [
					'unit' => 'px',
					'size' => 60,
				],
                'selectors' => [
                    '{{WRAPPER}} .service-two__single .icon-box' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single .service-three__single-img' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single .service-three__single-img img' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_button_style', [
            'condition' => [
                'seoq_design_style' => [ 'layout-2', 'layout-3' ],
            ],
        ]
        );

        $this->start_controls_tab(
            'icon_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ],
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-two__single .icon-box svg' => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single .service-three__single-img svg' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_background_color',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-two__single-img .icon-box' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single .service-three__single-img' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'icon_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'icon_color_hover',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one__single .service-one__icon:hover svg' => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single .icon-box:hover svg' => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .services-three__single:hover .services-three__single-icon' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single .service-three__single-img:hover svg' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_background_color_hover',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .services-one__single-img .icon::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single-img .icon-box:before' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2' ],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_responsive_control(
            'icon_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
					'unit' => 'px',
					'size' => 60,
				],
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single .service-one__icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-two__single .icon-box' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single .service-three__single-img' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single h3' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-two__single-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single .service-two__single-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single .service-two__single-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .service-one .service-one__single h3, .service-two__single .service-two__single-title, .service-three__single .service-two__single-title a',
            ]
        );

        // Description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .services-one__single-content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-two__single p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-three__single p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'services_list_description_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .services-one__single-content p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single p' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .services-one__single-content p, .service-two__single p, .service-three__single p',
                'condition' => [
                    'seoq_design_style' => [ 'layout-2', 'layout-3' ],
                ],
            ]
        );

        // Link
        $this->add_control(
            '_content_link',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Link', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-2' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'link_spacing',
            [
                'label' => __( 'Top Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .service-two__single a' => 'margin-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-one .service-one__single .service-one__btn' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'default' => [
					'unit' => 'px',
					'size' => 60,
				],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-2' ],
                ],
            ]
        );

        $this->start_controls_tabs(
            'services_list_link_tabs', [
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-2' ],
                ],
            ]
        );
        
        $this->start_controls_tab(
            'services_list_link_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'services_list_link_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-two__single a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single a:after' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-one .service-one__single .service-one__btn a.rr-bounce-up' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'services_list_link_bg_color',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single .service-one__btn a.rr-bounce-up' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'services_list_link_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'services_list_link_color_hover',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-two__single a:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-two__single a:hover:after' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .service-one .service-one__single .service-one__btn a.rr-bounce-up:hover' => 'color: {{VALUE}}!important',
                ],
            ]
        );

        $this->add_control(
            'services_list_link_bg_color_hover',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-one .service-one__single .service-one__btn a.rr-bounce-up:before' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1' ],
                ],
            ]
        );

        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'selector' => '{{WRAPPER}} .service-two__single a',
                'selector' => '{{WRAPPER}} .service-one .service-one__single .service-one__btn a.rr-bounce-up',
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-2' ],
                ],
            ],
        );

        // Service Number
        $this->add_control(
            '_content_service_number',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Service Number', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->start_controls_tabs(
            '_content_service_number_style_tabs',[
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );
        
        $this->start_controls_tab(
            '_content_service_number_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            '_content_service_number_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-three__single span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single span:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            '_content_service_number_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            '_content_service_number_color_hover',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-three__single:hover span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .service-three__single:hover span:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => '_content_service_number_typo',
                'selector' => '{{WRAPPER}} service-three__single>span',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        // Link
        if ('2' == $settings['seoq_services_link_type']) {
            $link = get_permalink($settings['seoq_services_page_link']);
            $target = '_self';
            $rel = 'nofollow';
        } else {
            $link = !empty($settings['seoq_services_link']['url']) ? $settings['seoq_services_link']['url'] : '';
            $target = !empty($settings['seoq_services_link']['is_external']) ? '_blank' : '';
            $rel = !empty($settings['seoq_services_link']['nofollow']) ? 'nofollow' : '';
        }

        ?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>
            
            <!-- service one start -->
            <div class="service-one">
                <div class="container">
                    <div class="row g-0">
                        <?php 
                            if($settings['seoq_service_lists']):
                                foreach ($settings['seoq_service_lists'] as $index => $item) :
                        ?>
                        <div class="col-xxl-3 col-xl-3 col-lg-6 col-md-6 col-sm-12 wow fadeInUp elementor-repeater-item-'<?php print esc_attr( $item['_id'] );?> '" data-wow-delay=".3s">
                            <div class="service-one__single style-1 mb-30 elementor-repeater-item-'<?php print esc_attr( $item['_id'] );?> '">
                                <div class="service-one__icon bg-1 mb-30" style="background-color: <?php print ( $item['seoq_service_image_bg'] ); ?>">
                                <?php if($item['seoq_service_image']['url']): ?>
                                    <img src="<?php echo $item['seoq_service_image']['url']; ?>" alt="image">
                                <?php endif; ?>
                                </div>
                                <?php if(!empty($item['seoq_services_list_title'])): ?>
                                    <h3 class="mb-35"><?php echo esc_html($item['seoq_services_list_title']); ?></h3>
                                <?php endif; ?>
                                <?php echo \Elementor\Plugin::instance()->frontend->get_builder_content($item['template'], true); ?>
                                <div class="service-one__btn mt-50">
                                    <?php 
                                        if ('2' == $item['seoq_services_link_type']) {
                                            $link = get_permalink($item['seoq_services_page_link']);
                                            $target = '_self';
                                            $rel = 'nofollow';
                                        } else {
                                            $link = !empty($item['seoq_services_link']['url']) ? $item['seoq_services_link']['url'] : '';
                                            $target = !empty($item['seoq_services_link']['is_external']) ? '_blank' : '';
                                            $rel = !empty($item['seoq_services_link']['nofollow']) ? 'nofollow' : '';
                                        }
                                        
                                    ?>
                                        <a target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($rel); ?>" href="<?php echo esc_url($link); ?>" class="rr-bounce-up"><?php echo rrdevs_kses($item['seoq_services_btn_text']); ?></a>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; endif; ?>
                    </div>
                </div>
            </div>
            <!-- service one end -->

        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>

            <div class="service-two__single">
                <?php if (!empty($settings['seoq_service_image']['url'])): ?>
                    <div class="icon-box">
                        <img src="<?php echo $settings['seoq_service_image']['url']; ?>" alt="<?php echo get_post_meta(attachment_url_to_postid($settings['seoq_service_image']['url']), '_wp_attachment_image_alt', true); ?>">
                    </div>
                <?php endif; ?>
                <?php if (!empty($settings['seoq_service_icon']) || !empty($settings['seoq_service_selected_icon']['value'])) : ?>
                    <div class="icon-box">
                        <?php seoq_render_icon($settings, 'seoq_service_icon', 'seoq_service_selected_icon'); ?>
                    </div>
                <?php endif; ?>
                
                <?php if (!empty($settings['seoq_service_title' ])): ?>
                    <h3 class="service-two__single-title"><?php echo rrdevs_kses($settings['seoq_service_title' ]); ?></h3>
                <?php endif; ?>
                <?php if (!empty($settings['seoq_service_description' ])): ?>
                    <p><?php echo rrdevs_kses($settings['seoq_service_description']); ?></p>
                <?php endif; ?>

                <?php 
                     if ('2' == $settings['seoq_services_link_type']) {
                        $link = get_permalink($settings['seoq_services_page_link']);
                        $target = '_self';
                        $rel = 'nofollow';
                    } else {
                        $link = !empty($settings['seoq_services_link']['url']) ? $settings['seoq_services_link']['url'] : '';
                        $target = !empty($settings['seoq_services_link']['is_external']) ? '_blank' : '';
                        $rel = !empty($settings['seoq_services_link']['nofollow']) ? 'nofollow' : '';
                    }
                    if($settings['seoq_services_link_switcher'] == 'yes'):
                ?>
                    <a target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($rel); ?>" href="<?php echo esc_url($link); ?>"><?php echo rrdevs_kses($settings['seoq_services_btn_text']); ?> <i class="fa-solid fa-arrow-right"></i></a>
                <?php endif; ?>
            </div>

        <?php elseif ( $settings['seoq_design_style']  == 'layout-3' ): ?>
            <div class="service-three">
                <div class="service-three__single">
                    <?php if (!empty($settings['seoq_service_image']['url'])): ?>
                        <div class="service-three__single-img">
                            <img src="<?php echo $settings['seoq_service_image']['url']; ?>" alt="<?php echo get_post_meta(attachment_url_to_postid($settings['seoq_service_image']['url']), '_wp_attachment_image_alt', true); ?>">
                        </div>
                    <?php endif; ?>
                    <?php if (!empty($settings['seoq_service_icon']) || !empty($settings['seoq_service_selected_icon']['value'])) : ?>
                        <div class="service-three__single-img">
                            <?php seoq_render_icon($settings, 'seoq_service_icon', 'seoq_service_selected_icon'); ?>
                        </div>
                    <?php endif; ?>
                    <?php if (!empty($settings['seoq_service_title' ])): 
                    ?>
                        <h3 class="service-two__single-title">
                            <?php 
                                    if ('2' == $settings['seoq_services_link_type']) {
                                        $link = get_permalink($settings['seoq_services_page_link']);
                                        $target = '_self';
                                        $rel = 'nofollow';
                                    } else {
                                        $link = !empty($settings['seoq_services_link']['url']) ? $settings['seoq_services_link']['url'] : '';
                                        $target = !empty($settings['seoq_services_link']['is_external']) ? '_blank' : '';
                                        $rel = !empty($settings['seoq_services_link']['nofollow']) ? 'nofollow' : '';
                                    }     
                                    
                                ?>
                                <a href="<?php echo esc_url($link); ?>"><?php echo rrdevs_kses($settings['seoq_service_title' ]); ?></a>
                        </h3>
                    <?php endif; ?>
                    <?php if (!empty($settings['seoq_service_description' ])): ?>
                        <p><?php echo rrdevs_kses($settings['seoq_service_description']); ?></p>
                    <?php endif; ?>

                    <?php if($settings['seoq_services_number']): ?>
                        <span class="service_number"><?php echo esc_html($settings['seoq_services_number']); ?></span>
                    <?php endif; ?>
                </div>
            </div>
        <?php endif; ?>

        <?php 
    }
}

$widgets_manager->register( new SEOQ_Services() );