<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Css_Filter;
use \Elementor\Repeater;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Box_Shadow;
use SEOQCore\Elementor\Controls\Group_Control_SEOQBGGradient;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Skill extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_skill_bar';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Skill', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        
        $this->start_controls_section(
            'seoq_layout',
            [
                'label' => esc_html__('Design Layout', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Choose Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_shape_img',
            [
                'label' => esc_html__( 'Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__('Title & Content', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('The SEO Story Behind Our Success.', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_description',
            [
                'label' => esc_html__('Description', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Projects case study environmental stewardship has impacted economical viability into the creation of places with distinct beauty and identity.', 'seoq-core'),
                'placeholder' => esc_html__('Type section description here', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_progress_bar',
            [
                'label' => esc_html__('Skill Bar', 'seoq-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->start_controls_tabs( '_progressbar_tabs' );
        
        $repeater->start_controls_tab(
            'progressbar_content_tab',
            [
                'label' => esc_html__( 'Content', 'text-domain' ),
            ]
        );
        
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__( 'Name', 'seoq-core' ),
                'default' => esc_html__( 'Design', 'seoq-core' ),
                'placeholder' => esc_html__( 'Type a skill name', 'seoq-core' ),
            ]
        );

        $repeater->add_control(
			'level',
			[
				'label' => esc_html__( 'Price', 'textdomain' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 5,
				'max' => 100,
				'step' => 1,
				'default' => 70,
			]
		);
        
        $repeater->end_controls_tab();
        
        $repeater->start_controls_tab(
            'progressbar_style_tab',
            [
                'label' => esc_html__( 'Style', 'text-domain' ),
            ]
        );
        
        $repeater->add_control(
            '_heading_bar',
            [
                'label' => esc_html__( 'Bar', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

		$repeater->add_responsive_control(
            'bar_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .skill-one__progress-single' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $repeater->add_control(
            'bar_fill_color',
            [
                'label' => __( 'Bar Fill Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
            ]
        );

        $repeater->add_control(
            'bar_color',
            [
                'label' => __( 'Bar Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
            ]
        );

		$repeater->add_responsive_control(
            'bar_size',
            [
                'label' => __( 'Bar Height', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .skill-one__progress .bar' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .skill-one__progress .bar-inner' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $repeater->add_control(
            '_heading_bar_text',
            [
                'label' => esc_html__( 'Text & Percent', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'bar_text_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .skill-one__progress-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .skill-one__progress .count-text' => 'color: {{VALUE}}',
                ],
            ]
        );

        $repeater->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'percent_typography',
                'selector' => '{{WRAPPER}} .skill-one__progress-title, .skill-one__progress .count-text',
            ]
        );
        
        $repeater->end_controls_tab();
        
        $repeater->end_controls_tabs();

        $this->add_control(
            'skills',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{name}}',
                'default' => [
                    [
                        'name' => 'SEO Analysis',
                        'level' => '84',
                        'bar_fill_color' => '#4A5FE1',
                    ],
                    [
                        'name' => 'SEO Audit',
                        'level' => '95',
                        'bar_fill_color' => '#E1A54A',
                    ],
                    [
                        'name' => 'Optimization',
                        'level' => '65',
                        'bar_fill_color' => '#E14AB7',
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_btn_button_group',
            [
                'label' => esc_html__('Button', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Analyze Your Site', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_link_type',
            [
                'label' => esc_html__('Button Link Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_link',
            [
                'label' => esc_html__('Button link', 'seoq-core'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'seoq-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'seoq_btn_link_type' => '1',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'seoq_btn_page_link',
            [
                'label' => esc_html__('Select Button Page', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_btn_link_type' => '2',
                ]
            ]
        );
        
        $this->end_controls_section();

        // TAB_STYLE
        $this->start_controls_section(
			'design_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            '_image_heading',
            [
                'label' => esc_html__( 'Image', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'content_img_background',
            [
                'label' => esc_html__( 'Background', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .skill-side__left' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_img_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .skill-side__left' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            '_content_heading',
            [
                'label' => esc_html__( 'Content', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'content_background',
            [
                'label' => esc_html__( 'Content Background', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .skill-side__right' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .skill-side__right' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'title_style',
			[
				'label' => __( 'Title & Content', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            '_title_heading',
            [
                'label' => esc_html__( 'Title', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Color', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__one-title',
            ]
        );

        $this->add_control(
            '_description_heading',
            [
                'label' => esc_html__( 'Description', 'text-domain' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-tagline' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => esc_html__( 'Color', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-tagline' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .section-title__one-tagline',
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
			'seoq_button_style',
			[
				'label' => __( 'Button', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'button_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn-2'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn-2' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'button_border',
                'selector' => '{{WRAPPER}} .thm-btn-2',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label'     => esc_html__( 'Text', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-bounce-up:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rr-bounce-up:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'label'    => esc_html__( 'Border', 'seoq-core' ),
                'name'     => 'button_border_hover',
                'selector' => '{{WRAPPER}} .thm-btn-2:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn-2' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .thm-btn-2',
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label'      => esc_html__( 'Padding', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .thm-btn-2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button_margin',
            [
                'label'      => esc_html__( 'Margin', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .thm-btn-2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();
        
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        $this->add_render_attribute('title_args', 'class', 'section-title__title');
        $this->add_render_attribute('title_args', 'data-wow-delay', '.3s');

        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full' ) : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

        // Link
        if ('2' == $settings['seoq_btn_link_type']) {
            $this->add_render_attribute('seoq-button-arg', 'href', get_permalink($settings['seoq_btn_page_link']));
            $this->add_render_attribute('seoq-button-arg', 'target', '_self');
            $this->add_render_attribute('seoq-button-arg', 'rel', 'nofollow');
            $this->add_render_attribute('seoq-button-arg', 'class', 'thm-btn-2 rr-bounce-up mt-55 wow fadeInUp');
            $this->add_render_attribute('seoq-button-arg', 'data-wow-delay', '.9s');
        } else {
            if ( ! empty( $settings['seoq_btn_link']['url'] ) ) {
                $this->add_link_attributes( 'seoq-button-arg', $settings['seoq_btn_link'] );
                $this->add_render_attribute('seoq-button-arg', 'class', 'thm-btn-2 rr-bounce-up mt-55 wow fadeInUp');
                $this->add_render_attribute('seoq-button-arg', 'data-wow-delay', '.9s');
            }
        }
        
		?>

        <div class="skill-one">
            <div class="row no-gutters">
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 col-sm-12">
                    <div class="skill-side__left wow fadeInLeft" data-wow-delay=".3s">
                        <?php if ( !empty($settings['seoq_shape_img']) ) : ?>
                            <div class="skill__img-animation1">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/skill/round-top.png" alt="animation1">
                            </div>
                        <?php endif;?>  
                        <?php if(!empty($seoq_image)) : ?>
                            <div class="skill-left__img">
                                <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_attr($seoq_image_alt); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-12 col-sm-12">
                    <div class="skill-side__right">
                        <?php if ( !empty($settings['seoq_shape_img']) ) : ?>
                            <div class="skill__img-animation2">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/skill/angle-right.png" alt="animation2">
                            </div>
                            <div class="skill__img-animation3">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/skill/close-1.png" alt="animation3">
                            </div>
                            <div class="skill__img-animation4">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/skill/close-2.png" alt="animation4">
                            </div>
                            <div class="skill__img-animation5">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/skill/angle-bottom.png" alt="animation5">
                            </div>
                        <?php endif;?>
                        <?php
                            if ( !empty($settings['seoq_title' ]) ) :
                                printf( '<%1$s %2$s>%3$s</%1$s>',
                                    tag_escape( $settings['seoq_title_tag'] ),
                                    $this->get_render_attribute_string( 'title_args' ),
                                    rrdevs_kses( $settings['seoq_title' ] )
                                    );
                            endif;
                        ?>
                        <?php if ( !empty($settings['seoq_description']) ) : ?>
                            <p class="section-title__one-tagline wow fadeInUp" data-wow-delay=".5s"><?php echo rrdevs_kses( $settings['seoq_description'] ); ?></p>
                        <?php endif; ?>
                        <div class="skill-one__progress wow fadeInUp" data-wow-delay=".7s">
                            <?php foreach ( $settings['skills'] as $index => $skill ) : ?>
                                <div class="skill-one__progress-single">
                                    <h4 class="skill-one__progress-title"><?php echo esc_html( $skill['name'] ); ?></h4>
                                    <div class="bar" style="background-color: <?php echo esc_attr( $skill['bar_color'] ); ?>">
                                        <div class="bar-inner count-bar counted" style="background-color: <?php echo esc_attr( $skill['bar_fill_color'] ); ?>" data-percent="<?php echo esc_attr( $skill['level'] ); ?>%">
                                            <div class="count-text"><?php echo esc_attr( $skill['level'] ); ?>%</div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <?php if (!empty($settings['seoq_btn_text'])) : ?>
                            <a <?php echo $this->get_render_attribute_string( 'seoq-button-arg' ); ?>>
                                <?php echo $settings['seoq_btn_text']; ?>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>

		<?php
	}

}

$widgets_manager->register( new SEOQ_Skill() );