<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Tab_Info extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_tab_info';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Tab Info', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_info',
            [
                'label' => esc_html__('Info List', 'seoq-core'),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_shape_switch',
            [
                'label' => esc_html__( 'Shape', 'seoq-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'seoq-core' ),
                'label_off' => esc_html__( 'No', 'seoq-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'seoq_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => __('Tailored SEO Solutions Boost Your Business.', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_info_title', [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'basic' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
     
        $this->add_control(
            'seoq_info_list',
            [
                'label' => esc_html__('Info List', 'seoq-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'seoq_info_title' => esc_html__( 'Nulla vel dolor accumsan neque vestibulum', 'seoq-core' ),
                    ],
                    [
                        'seoq_info_title' => esc_html__( 'Cras lacinia elit a turpis ultricies bibendum', 'seoq-core' ),
                    ],
                    [
                        'seoq_info_title' => esc_html__( 'posuere a ligula molestie, suscipit ullamcorper velit', 'seoq-core' ),
                    ],
                    [
                        'seoq_info_title' => esc_html__( 'Nulla ac varius tellus, in laoreet libero', 'seoq-core' ),
                    ],
                ],
                'title_field' => '{{{ seoq_info_title }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'seoq_btn_button_group',
            [
                'label' => esc_html__('Button', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_btn_text',
            [
                'label' => esc_html__('Button Text', 'seoq-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Learn More', 'seoq-core'),
                'title' => esc_html__('Enter button text', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_link_type',
            [
                'label' => esc_html__('Button Link Type', 'seoq-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_btn_link',
            [
                'label' => esc_html__('Button link', 'seoq-core'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'seoq-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                    'custom_attributes' => '',
                ],
                'condition' => [
                    'seoq_btn_link_type' => '1',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'seoq_btn_page_link',
            [
                'label' => esc_html__('Select Button Page', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => seoq_get_all_pages(),
                'condition' => [
                    'seoq_btn_link_type' => '2',
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_layout_style',
            [
                'label' => __( 'Design Layout', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .about-three__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_info_list_style',
            [
                'label' => __( 'Info List', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content h2',
            ]
        );

        $this->add_control(
            '_content_info_list',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Info List', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'info_list_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .list ul li' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'info_list_typography',
                'selector' => '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .list ul li',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_button_style',
			[
				'label' => __( 'Button', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'button_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn'    => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'button_color_hover',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn' => 'border-radius: {{SIZE}}px;',
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn:before' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'seoq-core' ),
                'name'     => 'button_typography',
                'selector' => '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn',
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label'      => esc_html__( 'Padding', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button_margin',
            [
                'label'      => esc_html__( 'Margin', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .about-three__wrapper .about-three__single .about-three__single-content .about-three-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'large') : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

        // Link
        if ('2' == $settings['seoq_btn_link_type']) {
            $this->add_render_attribute('seoq-button-arg', 'href', get_permalink($settings['seoq_btn_page_link']));
            $this->add_render_attribute('seoq-button-arg', 'target', '_self');
            $this->add_render_attribute('seoq-button-arg', 'rel', 'nofollow');
            $this->add_render_attribute('seoq-button-arg', 'class', 'about-three-btn rr-btn-style-1 mt-45');
        } else {
            if ( ! empty( $settings['seoq_btn_link']['url'] ) ) {
                $this->add_link_attributes( 'seoq-button-arg', $settings['seoq_btn_link'] );
                $this->add_render_attribute('seoq-button-arg', 'class', 'about-three-btn rr-btn-style-1 mt-45');
            }
        }

		?>

            <div class="about-three__single">
                <?php if ( !empty($settings['seoq_shape_switch']) ) : ?>
                    <div class="about-three__animation-1">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/12.svg" alt="shape icon">
                    </div>
                    <div class="about-three__animation-2">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/14.svg" alt="shape icon">
                    </div>
                    <div class="about-three__animation-3">
                        <img src="<?php echo get_template_directory_uri(); ?>/assets/img/shape/11.svg" alt="shape icon">
                    </div>
                <?php endif;?>
                <div class="row">
                    <div class="col-xxl-6 col-xl-7 col-lg-6 col-md-12 col-sm-12">
                        <div class="about-three__single-content">
                            <?php if ( !empty($settings['seoq_title']) ) : ?>
                                <h2><?php echo rrdevs_kses($settings['seoq_title' ]); ?></h2>
                            <?php endif; ?>
                            <div class="list">
                                <ul class="list-unstyled">
                                    <?php foreach ($settings['seoq_info_list'] as $item) : ?>
                                        <li><?php echo rrdevs_kses($item['seoq_info_title' ]); ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                            <a <?php echo $this->get_render_attribute_string( 'seoq-button-arg' ); ?>>
                                <?php echo $settings['seoq_btn_text']; ?>
                                <i class="fa-solid fa-arrow-right"></i>
                            </a>
                        </div>
                    </div>
                    <div class="col-xxl-6 col-xl-5 col-lg-6 col-md-12 col-sm-12 text-end text-md-center">
                        <div class="about-three__single-img">
                            <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_url($seoq_image_alt); ?>">
                        </div>
                    </div>
                </div>
            </div>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Tab_Info() );