<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Control_Media;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Css_Filter;
use \Elementor\Repeater;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Box_Shadow;
use SEOQCore\Elementor\Controls\Group_Control_SEOQBGGradient;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Team_Details extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_team_details';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team Details', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */

    protected static function get_profile_names()
    {
        return [
            '500px' => esc_html__('500px', 'seoq-core'),
            'apple' => esc_html__('Apple', 'seoq-core'),
            'behance' => esc_html__('Behance', 'seoq-core'),
            'bitbucket' => esc_html__('BitBucket', 'seoq-core'),
            'codepen' => esc_html__('CodePen', 'seoq-core'),
            'delicious' => esc_html__('Delicious', 'seoq-core'),
            'deviantart' => esc_html__('DeviantArt', 'seoq-core'),
            'digg' => esc_html__('Digg', 'seoq-core'),
            'dribbble' => esc_html__('Dribbble', 'seoq-core'),
            'email' => esc_html__('Email', 'seoq-core'),
            'facebook' => esc_html__('Facebook', 'seoq-core'),
            'flickr' => esc_html__('Flicker', 'seoq-core'),
            'foursquare' => esc_html__('FourSquare', 'seoq-core'),
            'github' => esc_html__('Github', 'seoq-core'),
            'houzz' => esc_html__('Houzz', 'seoq-core'),
            'instagram' => esc_html__('Instagram', 'seoq-core'),
            'jsfiddle' => esc_html__('JS Fiddle', 'seoq-core'),
            'linkedin' => esc_html__('LinkedIn', 'seoq-core'),
            'medium' => esc_html__('Medium', 'seoq-core'),
            'pinterest' => esc_html__('Pinterest', 'seoq-core'),
            'product-hunt' => esc_html__('Product Hunt', 'seoq-core'),
            'reddit' => esc_html__('Reddit', 'seoq-core'),
            'slideshare' => esc_html__('Slide Share', 'seoq-core'),
            'snapchat' => esc_html__('Snapchat', 'seoq-core'),
            'soundcloud' => esc_html__('SoundCloud', 'seoq-core'),
            'spotify' => esc_html__('Spotify', 'seoq-core'),
            'stack-overflow' => esc_html__('StackOverflow', 'seoq-core'),
            'tripadvisor' => esc_html__('TripAdvisor', 'seoq-core'),
            'tumblr' => esc_html__('Tumblr', 'seoq-core'),
            'twitch' => esc_html__('Twitch', 'seoq-core'),
            'twitter' => esc_html__('Twitter', 'seoq-core'),
            'vimeo' => esc_html__('Vimeo', 'seoq-core'),
            'vk' => esc_html__('VK', 'seoq-core'),
            'website' => esc_html__('Website', 'seoq-core'),
            'whatsapp' => esc_html__('WhatsApp', 'seoq-core'),
            'wordpress' => esc_html__('WordPress', 'seoq-core'),
            'xing' => esc_html__('Xing', 'seoq-core'),
            'yelp' => esc_html__('Yelp', 'seoq-core'),
            'youtube' => esc_html__('YouTube', 'seoq-core'),
        ];
    }


	protected function register_controls() {

        $this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__('Title & Content', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_image',
            [
                'label' => esc_html__( 'Choose Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Team Details', 'seoq-core'),
            ]
        );       

        $this->add_control(
            'seoq_name_label',
            [
                'label' => esc_html__('Name Label', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Name:', 'seoq-core'),
            ]
        );       

        $this->add_control(
            'seoq_name',
            [
                'label' => esc_html__('Name', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Md Imran Hossain', 'seoq-core'),
                'label_block' => true,
            ]
        );       

        $this->add_control(
            'seoq_about_label',
            [
                'label' => esc_html__('About Label', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('About:', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_about',
            [
                'label' => esc_html__('About', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Phis are bound to ensue; and equal blame belongs to those who through weakness of will, which is the same as through.We have the and industry expertise to develop solutions that can connect.', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_phone_label',
            [
                'label' => esc_html__('Phone Label', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Call:', 'seoq-core'),
            ]
        );

        $this->add_control(
            'seoq_phone',
            [
                'label' => esc_html__('Phone', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('++0822155421', 'seoq-core'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_social',
            [
                'label' => esc_html__('Social Profiles', 'seoq-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_profiles',
            [
                'label' => esc_html__('Show Profiles', 'seoq-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'seoq-core'),
                'label_off' => esc_html__('Hide', 'seoq-core'),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'seoq_profile_label',
            [
                'label' => esc_html__('Social Label', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Follow us:', 'seoq-core'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Profile Name', 'seoq-core'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'select2options' => [
                    'allowClear' => false,
                ],
                'options' => self::get_profile_names()
            ]
        );

        $repeater->add_control(
            'link', [
                'label' => esc_html__('Profile Link', 'seoq-core'),
                'placeholder' => esc_html__('Add your profile link', 'seoq-core'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'autocomplete' => false,
                'show_external' => false,
                'condition' => [
                    'name!' => 'email'
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $this->add_control(
            'profiles',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(name.slice(0,1).toUpperCase() + name.slice(1)) #>',
                'default' => [
                    [
                        'link' => ['url' => 'https://facebook.com/'],
                        'name' => 'facebook'
                    ],
                    [
                        'link' => ['url' => 'https://linkedin.com/'],
                        'name' => 'linkedin'
                    ],
                    [
                        'link' => ['url' => 'https://twitter.com/'],
                        'name' => 'twitter'
                    ]
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_layout_style',
			[
				'label' => __( 'Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .team-details' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
            'content_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_title_style',
			[
				'label' => __( 'Title & Content', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_bottom_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .title h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .team-details__content .title h2',
            ]
        );

        // Name
        $this->add_control(
            '_heading_name',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Name', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __( 'Text', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .name h6' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .team-details__content .name h6',
            ]
        );

        // About
        $this->add_control(
            '_heading_about',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'About', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'about_color',
            [
                'label' => __( 'About Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .text p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'about_typography',
                'selector' => '{{WRAPPER}} .team-details__content .text p',
            ]
        );

        // Phone
        $this->add_control(
            '_heading_phone',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Phone', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'phone_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .number p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .team-details__content .number p a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'phone_typography',
                'selector' => '{{WRAPPER}} .team-details__content .number p, .team-details__content .number p a',
            ]
        );

        // Follow
        $this->add_control(
            '_heading_follow',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Follow', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'follow_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .social-icon .title h6' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'follow_typography',
                'selector' => '{{WRAPPER}} .team-details__content .social-icon .title h6',
            ]
        );

        $this->add_responsive_control(
            'follow_icon_size',
            [
                'label' => __( 'Icon Size', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .social-icon ul li a' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'follow_icon_color',
            [
                'label' => __( 'Icon Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .social-icon ul li a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'follow_icon_color_hover',
            [
                'label' => __( 'Icon Color (Hover)', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content .social-icon ul li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        // Phone
        $this->add_control(
            '_heading_layout',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Layout', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'layout_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'layout_border_bottom_color',
            [
                'label' => __( 'Border Bottom', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-details__content::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

            if ( !empty($settings['seoq_image']['url']) ) {
                $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id'], 'full' ) : $settings['seoq_image']['url'];
                $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
            }

            if ( !empty($settings['seoq_signature_image']['url']) ) {
                $seoq_signature_image = !empty($settings['seoq_signature_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_signature_image']['id'], 'full' ) : $settings['seoq_signature_image']['url'];
                $seoq_signature_image_alt = get_post_meta($settings["seoq_signature_image"]["id"], "_wp_attachment_image_alt", true);
            }

		?>

            <section class="team-details">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-5">
                            <?php if ( !empty ( $settings['seoq_image']['url'] ) ) : ?>  
                                <div class="team-details__img js-tilt">
                                    <img src="<?php echo esc_url($seoq_image); ?>" alt="<?php echo esc_attr($seoq_image_alt); ?>" />
                                </div>
                            <?php endif; ?>
                        </div>

                        <div class="col-xl-7">
                            <div class="team-details__content">
                                <?php if ( !empty($settings['seoq_title' ]) ) : ?>
                                    <div class="title">
                                        <h2><?php echo rrdevs_kses( $settings['seoq_title'] ); ?></h2>
                                    </div>
                                <?php endif; ?>
                                
                                <?php if ( !empty($settings['seoq_name' ]) ) : ?>
                                    <div class="name">
                                        <h6><?php echo rrdevs_kses( $settings['seoq_name_label'] ); ?> <?php echo rrdevs_kses( $settings['seoq_name'] ); ?></h6>
                                    </div>
                                <?php endif; ?>
                                <?php if ( !empty($settings['seoq_about']) ) : ?>
                                    <div class="text">
                                        <p><?php echo rrdevs_kses( $settings['seoq_about_label'] ); ?> <?php echo rrdevs_kses( $settings['seoq_about'] ); ?></p>
                                    </div>
                                <?php endif; ?>
                                <?php if ( !empty($settings['seoq_phone']) ) : ?>
                                    <div class="number">
                                        <p><?php echo rrdevs_kses( $settings['seoq_phone_label'] ); ?> <a href="tel:<?php echo rrdevs_kses( $settings['seoq_phone'] ); ?>"><?php echo rrdevs_kses( $settings['seoq_phone'] ); ?></a></p>
                                    </div>
                                <?php endif; ?>

                                <?php if ($settings['show_profiles'] && is_array($settings['profiles'])) : ?>
                                    <div class="social-icon">
                                        <div class="title">
                                            <h6><?php echo rrdevs_kses( $settings['seoq_profile_label'] ); ?></h6>
                                        </div>
                                        <ul class="mb-0">
                                            <?php
                                            foreach ($settings['profiles'] as $profile) :
                                                $icon = $profile['name'];
                                                $url = esc_url($profile['link']['url']);

                                                printf('<li><a target="_blank" rel="noopener"  href="%s" class="elementor-repeater-item-%s"><i class="fab fa-%s" aria-hidden="true"></i></a></li>',
                                                    $url,
                                                    esc_attr($profile['_id']),
                                                    esc_attr($icon)
                                                );
                                            endforeach; ?>
                                        </ul>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </section>

        <?php
	}

}

$widgets_manager->register( new SEOQ_Team_Details() );