<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Testimonial_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_testimonial_slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonial', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

        $this->start_controls_section(
            'seoq_section_title',
            [
                'label' => esc_html__( 'Title & Content', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'seoq_design_style',
            [
                'label' => esc_html__( 'Style', 'seoq-core' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'layout-1',
                'options' => [
                    'layout-1' => esc_html__( 'Layout 1', 'seoq-core' ),
                    'layout-2'  => esc_html__( 'Layout 2', 'seoq-core' ),
                    'layout-3'  => esc_html__( 'Layout 3', 'seoq-core' ),
                ],
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('What Our Clients Say', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'seoq_rating_title',
            [
                'label' => esc_html__('Rating Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('What Our Clients Say', 'seoq-core'),
                'label_block' => true,
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
			'seoq_star_rating',
			[
				'label'                 => esc_html__( 'Star Rating', 'plugin-domain' ),
				'type'                  => Controls_Manager::SELECT,
				'default'               => 'four-star',
				'options' => [
					'one-star'          => esc_html__( 'One', 'plugin-domain' ),
					'two-star'          => esc_html__( 'Two', 'plugin-domain' ),
					'three-star'        => esc_html__( 'Three', 'plugin-domain' ),
					'four-star'         => esc_html__( 'Four', 'plugin-domain' ),
					'five-star'         => esc_html__( 'Five', 'plugin-domain' ),
                ],
			]
        );
        
        $this->end_controls_section();

        // Testimonial List
        $this->start_controls_section(
            'testimonial_list_content',
            [
                'label' => esc_html__( 'Testimonial List', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'testimonial_image',
            [
                'label' => esc_html__( 'Testimonial Image', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'testimonial_logo',
            [
                'label' => esc_html__( 'Logo', 'seoq-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'testimonial_name', [
                'label' => esc_html__( 'Name', 'seoq-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Rashal Khan' , 'seoq-core' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'testimonial_position', [
                'label' => esc_html__( 'Position', 'seoq-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Founder' , 'seoq-core' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'testimonial_description',
            [
                'label' => esc_html__( 'Description', 'seoq-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 10,
                'default' => esc_html__( 'Hiring managers are busy people, so you need to make yourout the crowd as quickly as possible. In the first section. This should headline achievements', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'testimonial_list',
            [
                'label' => esc_html__( 'Testimonial List', 'seoq-core' ),
                'type' => Controls_Manager::REPEATER,
                'fields' =>  $repeater->get_controls(),
                'default' => [
                    [
                        'testimonial_name' => esc_html__( 'Indigo Violet', 'seoq-core' ),
                        'testimonial_position' => esc_html__( 'Director, Thump Coffee', 'seoq-core' ),
                        'testimonial_description' => esc_html__( '“Morbi consectetur elementum purus mattis cursus purus metus iaculis sagittis. Vestibulum molestie bibendum turpis luctus sem lacinia quis. Quisque amet velit sit amet dui hendrerit ultricies a id ipsum Mauris sit amet lacinia
                        est”', 'seoq-core' ),
                    ],
                    [
                        'testimonial_name' => esc_html__( 'Michael Thomas', 'seoq-core' ),
                        'testimonial_position' => esc_html__( 'Director, Plan4Demand', 'seoq-core' ),
                        'testimonial_description' => esc_html__( '“Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Donec euismod, sapien ac fringilla tincidunt, eros nisl ultricies justo, a tincidunt eros mi ut velit. Mauris semper, massa eu semper
                        mollis, tortor eros tristique erat, id lacinia lectus quam eu arcu.”', 'seoq-core' ),
                    ],
                    [
                        'testimonial_name' => esc_html__( 'Matthew Martin', 'seoq-core' ),
                        'testimonial_position' => esc_html__( 'Director, Hobby Lobby', 'seoq-core' ),
                        'testimonial_description' => esc_html__( '“Vivamus sit amet risus vitae leo semper semper. Nullam vel ligula et purus egestas semper. Phasellus ac elit eget quam pulvinar gravida. Sed mattis, nisi vel ullamcorper semper, tortor mauris fringilla sem, a gravida eros nulla
                        sed augue. Donec elementum.”', 'seoq-core' ),
                    ],
                    [
                        'testimonial_name' => esc_html__( 'Julian Walker', 'seoq-core' ),
                        'testimonial_position' => esc_html__( 'Director, 7Eleven', 'seoq-core' ),
                        'testimonial_description' => esc_html__( '“Vestibulum quis magna sed ligula lacinia vehicula. Nunc ac semper dolor. Donec ut quam eget augue semper iaculis. Vivamus egestas quam erat, eu tincidunt eros ultrices et. Donec iaculis, tellus a semper ultricies, enim tortor
                        luctus nunc, et aliquam quam urna eu quam.”', 'seoq-core' ),
                    ],
                    [
                        'testimonial_name' => esc_html__( 'Henry Baker', 'seoq-core' ),
                        'testimonial_position' => esc_html__( 'Director, Puzzle Huddle', 'seoq-core' ),
                        'testimonial_description' => esc_html__( '“Sed ac sapien eu enim ultricies faucibus. Nulla facilisi. Nunc et orci id sem interdum congue. Sed ac felis sit amet nisi faucibus bibendum. In hac habitasse platea dictumst.”', 'seoq-core' ),
                    ],

                ],
                'title_field' => '{{{ testimonial_name }}}',
            ]
        );

        $this->end_controls_section();

        // TAB_STYLE
		$this->start_controls_section(
			'seoq_testimonial_layout_style',
			[
				'label' => __( 'Design Layout', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
            'content_margin',
            [
                'label' => __( 'Content Margin', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-two' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_background',
            [
                'label' => esc_html__( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-two' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            '_arrows_heading',
            [
                'label' => esc_html__( 'Arrows', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( '_arrow_tabs' );
        
        $this->start_controls_tab(
            'arrow_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-prev i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-next i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_background',
            [
                'label' => __( 'Backgorund', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-prev i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-next i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_border',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'arrow_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );
        
        $this->add_control(
            'arrow_color_hover',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-prev:hover i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-next:hover i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_background_hover',
            [
                'label' => __( 'Backgorund', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-prev:hover i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-one .testimonial-one__active .owl-next:hover i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'arrow_border_hover',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-prev:hover' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__active button.slick-next:hover' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->add_control(
            '_dots_heading',
            [
                'label' => esc_html__( 'Dots', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->start_controls_tabs( '_dots_tabs' );

        $this->start_controls_tab(
            'dots_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'dots_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .slick-dots li' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'dots_border',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .slick-dots li' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'dots_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'dots_background_hover',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .slick-dots li.slick-active' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'dots_border_hover',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .slick-dots li.slick-active' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

		$this->end_controls_section();

        $this->start_controls_section(
            '_section_style_content',
            [
                'label' => __( 'Title & Content', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Heading', 'seoq-core' ),
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'section_title_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .section-title__two-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three_section__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .section-title__two-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three_section__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__one-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .section-title__two-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three_section__title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__one-title, .section-title__two-title, .testimonial-three_section__title',
            ]
        );

        // Rating
        $this->add_control(
            '_rating_heading',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Rating', 'seoq-core' ),
                'separator' => 'before',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'rating_spacing',
            [
                'label' => __( 'Top Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-rating span' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'rating_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-rating span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'rating_background',
            [
                'label' => __( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-rating' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'rating_border_color',
            [
                'label' => __( 'Border', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-border' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rating_typography',
                'selector' => '{{WRAPPER}} .testimonial-three .testimonial-rating span',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'rating_border_radius',
            [
                'label' => __( 'Border Radius', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-rating' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'rating_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-rating' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'seoq_testimonial_list_style',
			[
				'label' => __( 'Testimonial List', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        // Logo
        $this->add_control(
            '_logo_heading',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Logo', 'seoq-core' ),
                'separator' => 'after',
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'testimonial_logo_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single > img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        $this->add_control(
            'testimonial_logo_border_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single > img' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-3' ],
                ],
            ]
        );

        // Name
        $this->add_control(
            '_heading_name',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Name', 'seoq-core' ),
            ]
        );

        $this->add_responsive_control(
            'name_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single-content h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper .testimonial-two__single h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single .author-info .content h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single-content h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper .testimonial-two__single h4' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single .author-info .content h4' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .testimonial-one .testimonial-one__single-content h4, .testimonial-two .testimonial-two__wrapper .testimonial-two__single h4, .testimonial-three .testimonial-three__wrapper .testimonial-three__single .author-info .content h4',
            ]
        );

        // Position
        $this->add_control(
            '_heading_position',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Position', 'seoq-core' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'position_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single-content span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper .testimonial-two__single span' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single .author-info .content span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'position_typography',
                'selector' => '{{WRAPPER}} .testimonial-one .testimonial-one__single-content span, .testimonial-two .testimonial-two__wrapper .testimonial-two__single span, .testimonial-three .testimonial-three__wrapper .testimonial-three__single .author-info .content span',
            ]
        );

        // Description
        $this->add_control(
            '_content_description',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Description', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'description_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single-content p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper .testimonial-two__single p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label' => __( 'Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single-content p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper .testimonial-two__single p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-three .testimonial-three__wrapper .testimonial-three__single p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'selector' => '{{WRAPPER}} .testimonial-one .testimonial-one__single-content p, .testimonial-two .testimonial-two__wrapper .testimonial-two__single p, .testimonial-three .testimonial-three__wrapper .testimonial-three__single p',
            ]
        );

        $this->add_control(
            '_heading_layout_testimonial_list',
            [
                'label' => esc_html__( 'Layout', 'seoq-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'testimonial_list_background',
            [
                'label' => esc_html__( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'seoq_design_style' => [ 'layout-1', 'layout-2' ],
                ],
            ]
        );

        $this->add_responsive_control(
            'testimonial_list_padding',
            [
                'label' => __( 'Padding', 'seoq-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .testimonial-one .testimonial-one__single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-two .testimonial-two__wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

        $this->add_render_attribute('title_args_one', 'class', 'section-title__one-title' );
        $this->add_render_attribute('title_args_two', 'class', 'section-title__two-title text-center wow fadeInUp' );
        $this->add_render_attribute('title_args_two', 'data-wow-delay', '.3s' );
        $this->add_render_attribute('title_args_three', 'class', 'testimonial-three_section__title wow fadeInUp' );
        $this->add_render_attribute('title_args_three', 'data-wow-delay', '.3s' );
        if ( !empty($settings['seoq_image']['url']) ) {
            $seoq_image = !empty($settings['seoq_image']['id']) ? wp_get_attachment_image_url( $settings['seoq_image']['id']) : $settings['seoq_image']['url'];
            $seoq_image_alt = get_post_meta($settings["seoq_image"]["id"], "_wp_attachment_image_alt", true);
        }

		?>

        <?php if ( $settings['seoq_design_style']  == 'layout-1' ): ?>

            <div class="testimonial-one pt-160">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="section-title__one text-center mb-60 wow fadeInUp" data-wow-delay=".3s">
                                <?php
                                    if ( !empty($settings['seoq_title' ]) ) :
                                        printf( '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape( $settings['seoq_title_tag'] ),
                                            $this->get_render_attribute_string( 'title_args_one' ),
                                            rrdevs_kses( $settings['seoq_title' ] )
                                            );
                                    endif;
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="testimonial-one__active owl-carousel owl-theme">
                    <?php foreach ($settings['testimonial_list'] as $index => $item) : 
                        if ( !empty($item['testimonial_image']['url']) ) {
                            $seoq_testimonial_image = !empty($item['testimonial_image']['id']) ? wp_get_attachment_image_url( $item['testimonial_image']['id']) : $item['testimonial_image']['url'];
                            $seoq_testimonial_image_alt = get_post_meta($item["testimonial_image"]["id"], "_wp_attachment_image_alt", true);
                        }
                    ?>
                    <div class="testimonial-one__single wow fadeInUp" data-wow-delay=".3s">
                        <div class="testimonial-one__single-wrapper">
                            <?php if ( !empty($seoq_testimonial_image) ) : ?>
                                <div class="testimonial-one__single-img">
                                    <img src="<?php echo esc_url($seoq_testimonial_image); ?>" alt="<?php echo esc_url($seoq_testimonial_image_alt); ?>">
                                </div>
                            <?php endif; ?>
                            <div class="testimonial-one__single-content">
                                <div class="testimonial-one__video">
                                    <div class="icon">
                                        <a href="https://www.youtube.com/watch?v=3JB5BQfcIQc" class="popup-video">
                                            <img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/play-icon.svg" alt="<?php print esc_attr('play icon') ?>"> Watch The Video
                                        </a>
                                    </div>
                                </div>
                                <?php if ( !empty($item['testimonial_description']) ) : ?>
                                    <p><?php echo rrdevs_kses($item['testimonial_description']); ?></p>
                                <?php endif; ?>
                                <?php if ( !empty($item['testimonial_name']) ) : ?>
                                    <h4><?php echo rrdevs_kses($item['testimonial_name']); ?></h4>
                                <?php endif; ?>
                                <?php if ( !empty($item['testimonial_position']) ) : ?>
                                    <span><?php echo rrdevs_kses($item['testimonial_position']); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
            </div>
        
        <?php elseif ( $settings['seoq_design_style']  == 'layout-2' ): ?>

            <div class="testimonial-two">
                <div class="container">
                    <div class="row">
                        <div class="col-12">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args_two' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xl-12 wow fadeInUp" data-wow-delay=".5s">
                            <div class="testimonial-two__wrapper">
                                <div class="testimonial-two__img">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/testimonial/quote-icon.svg" alt="quote icon">
                                </div>
                                <div class="testimonial-two__active owl-carousel">
                                    <?php foreach ($settings['testimonial_list'] as $index => $item) : 
                                        if ( !empty($item['testimonial_image']['url']) ) {
                                            $seoq_testimonial_image = !empty($item['testimonial_image']['id']) ? wp_get_attachment_image_url( $item['testimonial_image']['id']) : $item['testimonial_image']['url'];
                                            $seoq_testimonial_image_alt = get_post_meta($item["testimonial_image"]["id"], "_wp_attachment_image_alt", true);
                                        }
                                    ?>
                                    <div data-dot="<img src='<?php echo esc_url($seoq_testimonial_image); ?>' />" class="testimonial-two__single">
                                        <?php if ( !empty($item['testimonial_description']) ) : ?>
                                            <p><?php echo rrdevs_kses($item['testimonial_description']); ?></p>
                                        <?php endif; ?>
                                        <?php if ( !empty($item['testimonial_name']) ) : ?>
                                            <h4><?php echo rrdevs_kses($item['testimonial_name']); ?></h4>
                                        <?php endif; ?>
                                        <?php if ( !empty($item['testimonial_position']) ) : ?>
                                            <span><?php echo rrdevs_kses($item['testimonial_position']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        <?php elseif ( $settings['seoq_design_style']  == 'layout-3' ): ?>

            <div class="testimonial-three">
                <div class="container">
                    <div class="row">
                        <div class="col-xxl-12">
                            <div class="d__column-two testimonial-border">
                                <?php
                                    if ( !empty($settings['seoq_title' ]) ) :
                                        printf( '<%1$s %2$s>%3$s</%1$s>',
                                            tag_escape( $settings['seoq_title_tag'] ),
                                            $this->get_render_attribute_string( 'title_args_three' ),
                                            rrdevs_kses( $settings['seoq_title' ] )
                                            );
                                    endif;
                                ?>
                                <div class="testimonial-rating wow fadeInUp" data-wow-delay=".5s">
                                    <div class="star-rating seoq-star-rating <?php esc_attr_e( $settings['seoq_star_rating'] ); ?>">
                                        <i class="fa-solid fa-star"></i>
                                        <i class="fa-solid fa-star"></i>
                                        <i class="fa-solid fa-star"></i>
                                        <i class="fa-solid fa-star"></i>
                                        <i class="fa-solid fa-star"></i>
                                    </div>
                                    <span><?php print rrdevs_kses( $settings['seoq_rating_title' ] ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="testimonial-three__wrapper">
                                <div class="testimonial-three__active">
                                    <?php foreach ($settings['testimonial_list'] as $index => $item) : 
                                        if ( !empty($item['testimonial_image']['url']) ) {
                                            $seoq_testimonial_image = !empty($item['testimonial_image']['id']) ? wp_get_attachment_image_url( $item['testimonial_image']['id']) : $item['testimonial_image']['url'];
                                            $seoq_testimonial_image_alt = get_post_meta($item["testimonial_image"]["id"], "_wp_attachment_image_alt", true);
                                        }
                                        if ( !empty($item['testimonial_logo']['url']) ) {
                                            $seoq_testimonial_logo = !empty($item['testimonial_logo']['id']) ? wp_get_attachment_image_url( $item['testimonial_logo']['id']) : $item['testimonial_logo']['url'];
                                            $seoq_testimonial_logo_alt = get_post_meta($item["testimonial_logo"]["id"], "_wp_attachment_image_alt", true);
                                        }
                                    ?>
                                    <div class="testimonial-three__single wow fadeInUp" data-wow-delay=".3s">
                                        <img src="<?php echo esc_url($seoq_testimonial_logo); ?>" alt="<?php echo esc_url($seoq_testimonial_logo_alt); ?>">
                                        <?php if ( !empty($item['testimonial_description']) ) : ?>
                                            <p><?php echo rrdevs_kses($item['testimonial_description']); ?></p>
                                        <?php endif; ?>
                                        <div class="author-info">
                                            <?php if ( !empty($seoq_testimonial_image) ) : ?>
                                                <div class="img">
                                                    <img src="<?php echo esc_url($seoq_testimonial_image); ?>" alt="<?php echo esc_url($seoq_testimonial_image_alt); ?>">
                                                </div>
                                            <?php endif; ?>
                                            
                                            <div class="content">
                                                <?php if ( !empty($item['testimonial_name']) ) : ?>
                                                    <h4><?php echo rrdevs_kses($item['testimonial_name']); ?></h4>
                                                <?php endif; ?>
                                                <?php if ( !empty($item['testimonial_position']) ) : ?>
                                                    <span><?php echo rrdevs_kses($item['testimonial_position']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                                <div class="testimonial-three__img wow fadeInUp" data-wow-delay=".9s">
                                    <img src="<?php echo get_template_directory_uri(); ?>/assets/img/testimonial/quote-right.png" alt="quote icon">
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        <?php endif; ?>

        <?php 
	}
}

$widgets_manager->register( new SEOQ_Testimonial_Slider() );