<?php
/**
 * Breadcrumbs for seoq theme.
 *
 * @package     seoq
 * @author      RRdevs
 * @copyright   Copyright (c) 2022, RRdevs
 * @link        https://weblearnbd.net
 * @since       seoq 1.0.0
 */


function seoq_breadcrumb_func() {
    global $post;  
    $breadcrumb_class = '';
    $breadcrumb_show = 1;


    if ( is_front_page() && is_home() ) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog','seoq'));
        $breadcrumb_class = 'home_front_page';
    }
    elseif ( is_front_page() ) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog','seoq'));
        $breadcrumb_show = 0;
    }
    elseif ( is_home() ) {
        if ( get_option( 'page_for_posts' ) ) {
            $title = get_the_title( get_option( 'page_for_posts') );
        }
    }

    elseif ( is_single() && 'post' == get_post_type() ) {
      $title = get_the_title();
    } 
    elseif ( is_single() && 'product' == get_post_type() ) {
        $title = get_theme_mod( 'breadcrumb_product_details', __( 'Shop', 'seoq' ) );
    } 
    elseif ( is_single() && 'courses' == get_post_type() ) {
      $title = esc_html__( 'Course Details', 'seoq' );
    } 
    elseif ( 'courses' == get_post_type() ) {
      $title = esc_html__( 'Courses', 'seoq' );
    } 
    elseif ( is_search() ) {
        $title = esc_html__( 'Search Results for : ', 'seoq' ) . get_search_query();
    } 
    elseif ( is_404() ) {
        $title = esc_html__( 'Page Not Found', 'seoq' );
    } 
    elseif ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
        $title = get_theme_mod( 'breadcrumb_shop', __( 'Shop', 'seoq' ) );
    } 
    elseif ( is_archive() ) {
        $title = get_the_archive_title();
    } 
    else {
        $title = get_the_title();
    }
 


    $_id = get_the_ID();

    if ( is_single() && 'product' == get_post_type() ) { 
        $_id = $post->ID;
    } 
    elseif ( function_exists("is_shop") AND is_shop()  ) { 
        $_id = wc_get_page_id('shop');
    } 
    elseif ( is_home() && get_option( 'page_for_posts' ) ) {
        $_id = get_option( 'page_for_posts' );
    }

    $is_breadcrumb = function_exists( 'get_field' ) ? get_field( 'is_it_invisible_breadcrumb', $_id ) : '';
    if( !empty($_GET['s']) ) {
      $is_breadcrumb = null;
    }

      if ( empty( $is_breadcrumb ) && $breadcrumb_show == 1 ) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image',$_id) : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image',$_id) : '';
        $breadcrumb_bg_color = get_theme_mod( 'seoq_breadcrumb_bg_color' );

        // get_theme_mod
        $breadcrumb_img = get_template_directory_uri() . '/assets/img/backgrounds/breadcrumb.jpg';
        $bg_img = get_theme_mod( 'breadcrumb_bg_img', $breadcrumb_img );
        $breadcrumb_img_1 = get_template_directory_uri() . '//assets/img/shape/1.svg';
        $breadcrumb_img_2 = get_template_directory_uri() . '//assets/img/shape/2.svg';
        $breadcrumb_img_3 = get_template_directory_uri() . '//assets/img/shape/3.svg';
        $breadcrumb_img_4 = get_template_directory_uri() . '//assets/img/shape/4.svg';
        $breadcrumb_animation_one_img = get_theme_mod( 'breadcrumb_animation_one_img', $breadcrumb_img_1 );
        $breadcrumb_animation_two_img = get_theme_mod( 'breadcrumb_animation_two_img', $breadcrumb_img_2 );
        $breadcrumb_animation_three_img = get_theme_mod( 'breadcrumb_animation_three_img', $breadcrumb_img_3 );
        $breadcrumb_animation_four_img = get_theme_mod( 'breadcrumb_animation_four_img', $breadcrumb_img_4 );
        $seoq_breadcrumb_shape_switch = get_theme_mod( 'seoq_breadcrumb_shape_switch', true );
        $breadcrumb_info_switch = get_theme_mod( 'breadcrumb_info_switch', true );
        $breadcrumb_switch = get_theme_mod( 'breadcrumb_switch', true );

        if ( $hide_bg_img && empty($_GET['s']) ) {
            $bg_img = '';
        } else {
            $bg_img = !empty( $bg_img_from_page ) ? $bg_img_from_page['url'] : $bg_img;
        }?>

        <!-- breadcrumb start -->
        <div class="page-header">
            <div class="page-header__img1">
                <img src="<?php print esc_attr($breadcrumb_animation_one_img);?>" alt="<?php print esc_attr__( 'breadcrumb animation', 'seoq' );?>">
            </div>
            <div class="page-header__img2">
                <img src="<?php print esc_attr($breadcrumb_animation_two_img);?>" alt="<?php print esc_attr__( 'breadcrumb animation', 'seoq' );?>">
            </div>
            <div class="page-header__img3">
                <img src="<?php print esc_attr($breadcrumb_animation_three_img);?>" alt="<?php print esc_attr__( 'breadcrumb animation', 'seoq' );?>">
            </div>
            <div class="page-header__img4">
                <img src="<?php print esc_attr($breadcrumb_animation_four_img);?>" alt="<?php print esc_attr__( 'breadcrumb animation', 'seoq' );?>">
            </div>
            <div class="page-header__bg <?php print esc_attr( $breadcrumb_class );?>" data-background="<?php print esc_attr($bg_img);?>" data-bg-color="<?php print esc_attr($breadcrumb_bg_color);?>"></div>
            <?php if($breadcrumb_info_switch): ?>
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="page-header__wrapper">
                                <div class="page-header__content">
                                    <h2><?php echo wp_kses_post( $title ); ?></h2>
                                    <div class="page-header__menu">
                                        <?php if(function_exists('bcn_display')) {
                                            bcn_display();
                                        } ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </div>
        <!-- breadcrumb end -->
        <?php
      }
}

add_action( 'seoq_before_main_content', 'seoq_breadcrumb_func' );

// seoq_search_form
function seoq_search_form() {
    ?>
     <div class="search-wrapper p-relative transition-3 d-none">
         <div class="search-form transition-3">
             <form method="get" action="<?php print esc_url( home_url( '/' ) );?>" >
                 <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php print esc_attr__( 'Enter Your Keyword', 'seoq' );?>" >
                 <button type="submit" class="search-btn"><i class="far fa-search"></i></button>
             </form>
             <a href="javascript:void(0);" class="search-close"><i class="far fa-times"></i></a>
         </div>
     </div>
   <?php
}

add_action( 'seoq_before_main_content', 'seoq_search_form' );