<?php 

/**
 * Template part for displaying footer layout one
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package seoq
*/

$footer_shape_switch = get_theme_mod( 'footer_shape_switch', true );
$seoq_footer_bg_url_from_page = function_exists( 'get_field' ) ? get_field( 'seoq_footer_bg' ) : '';
$seoq_footer_bg_color_from_page = function_exists( 'get_field' ) ? get_field( 'seoq_footer_bg_color' ) : '';
$footer_bg_color = get_theme_mod( 'seoq_footer_bg_color', '#fff' );

// bg color
$bg_color = !empty( $seoq_footer_bg_color_from_page ) ? $seoq_footer_bg_color_from_page : $footer_bg_color;


// footer_columns
$footer_columns = 0;
$footer_widgets = get_theme_mod( 'footer_widget_number', 4 );

for ( $num = 1; $num <= $footer_widgets; $num++ ) {
    if ( is_active_sidebar( 'footer-' . $num ) ) {
        $footer_columns++;
    }
}

switch ( $footer_columns ) {
case '1':
    $footer_class[1] = 'col-lg-12';
    break;
case '2':
    $footer_class[1] = 'col-lg-6 col-md-6';
    $footer_class[2] = 'col-lg-6 col-md-6';
    break;
case '3':
    $footer_class[1] = 'col-xl-4 col-lg-6 col-md-6';
    $footer_class[2] = 'col-xl-4 col-lg-6 col-md-6';
    $footer_class[3] = 'col-xl-4 col-lg-6 col-md-6';
    break;
case '4':
    $footer_class[1] = 'col-xxl-3 col-xl-3 col-lg-3 col-md-6 col-sm-7';
    $footer_class[2] = 'col-xxl-3 col-xl-3 col-lg-3 col-md-6 col-sm-5';
    $footer_class[3] = 'col-xxl-3 col-xl-3 col-lg-3 col-md-6 col-sm-5';
    $footer_class[4] = 'col-xxl-3 col-xl-3 col-lg-3 col-md-6 col-sm-7';
    break;
default:
    $footer_class = 'col-xl-3 col-lg-3 col-md-6';
    break;
}

?>

<footer>
    <div class="footer-style-1" data-bg-color="<?php print esc_attr( $bg_color );?>">
        <?php if ( $footer_shape_switch ) : ?>
            <div class="footer-style-1__animation1">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/footer/dot-line.svg" alt="<?php print esc_attr__( 'footer animation', 'seoq' );?>">
            </div>
            <div class="footer-style-1__animation2">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/footer/angle.svg" alt="<?php print esc_attr__( 'footer animation', 'seoq' );?>">
            </div>
            <div class="footer-style-1__animation3">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/footer/squre.svg" alt="<?php print esc_attr__( 'footer animation', 'seoq' );?>">
            </div>
            <div class="footer-style-1__animation4">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/footer/star.svg" alt="<?php print esc_attr__( 'footer animation', 'seoq' );?>">
            </div>
            <div class="footer-style-1__animation5">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/footer/dot-line-2.svg" alt="<?php print esc_attr__( 'footer animation', 'seoq' );?>">
            </div>
        <?php endif; ?>
        <div class="container">
            <?php if ( is_active_sidebar('footer-1') OR is_active_sidebar('footer-2') OR is_active_sidebar('footer-3') OR is_active_sidebar('footer-4') ): ?>
                <div class="footer-top pt-120 pb-55">
                    <div class="row">
                        <?php if ( $footer_columns > 4 ) {
                            print '<div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6 col-sm-7">';
                            dynamic_sidebar( 'footer-1' );
                            print '</div>';

                            print '<div class="col-xxl-2 col-xl-2 col-lg-2 col-md-6 col-sm-5">';
                            dynamic_sidebar( 'footer-2' );
                            print '</div>';

                            print '<div class="col-xxl-2 col-xl-2 col-lg-2 col-md-6 col-sm-5">';
                            dynamic_sidebar( 'footer-3' );
                            print '</div>';

                            print '<div class="col-xxl-4 col-xl-4 col-lg-4 col-md-6 col-sm-7">';
                            dynamic_sidebar( 'footer-4' );
                            print '</div>';
                            } else {
                                for ( $num = 1; $num <= $footer_columns; $num++ ) {
                                    if ( !is_active_sidebar( 'footer-' . $num ) ) {
                                        continue;
                                    }
                                    print '<div class="' . esc_attr( $footer_class[$num] ) . '">';
                                    dynamic_sidebar( 'footer-' . $num );
                                    print '</div>';
                                }
                            }
                        ?>
                    </div>
                </div>
            <?php endif; ?>
            <div class="footer-bottom">
                <div class="row">
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <div class="copyright">
                            <p><?php print seoq_copyright_text(); ?></p>
                        </div>
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <div class="footer-bottom-menu">
                            <?php seoq_footer_bottom_menu(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</footer>